Documentation
¶
Overview ¶
Package adexchangebuyer provides access to the Ad Exchange Buyer API.
See https://developers.google.com/ad-exchange/buyer-rest
Usage example:
import "google.golang.org/api/adexchangebuyer/v1.2" ... adexchangebuyerService, err := adexchangebuyer.New(oauthHttpClient)
Index ¶
- Constants
- type Account
- type AccountBidderLocation
- type AccountsGetCall
- type AccountsList
- type AccountsListCall
- type AccountsPatchCall
- type AccountsService
- type AccountsUpdateCall
- type Creative
- type CreativeCorrections
- type CreativeDisapprovalReasons
- type CreativeFilteringReasons
- type CreativeFilteringReasonsReasons
- type CreativesGetCall
- type CreativesInsertCall
- type CreativesList
- type CreativesListCall
- func (c *CreativesListCall) Do() (*CreativesList, error)
- func (c *CreativesListCall) Fields(s ...googleapi.Field) *CreativesListCall
- func (c *CreativesListCall) MaxResults(maxResults int64) *CreativesListCall
- func (c *CreativesListCall) PageToken(pageToken string) *CreativesListCall
- func (c *CreativesListCall) StatusFilter(statusFilter string) *CreativesListCall
- type CreativesService
- type Service
Constants ¶
const (
// Manage your Ad Exchange buyer account configuration
AdexchangeBuyerScope = "https://www.googleapis.com/auth/adexchange.buyer"
)
OAuth2 scopes used by this API.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Account ¶
type Account struct {
// BidderLocation: Your bidder locations that have distinct URLs.
BidderLocation []*AccountBidderLocation `json:"bidderLocation,omitempty"`
// CookieMatchingNid: The nid parameter value used in cookie match
// requests. Please contact your technical account manager if you need
// to change this.
CookieMatchingNid string `json:"cookieMatchingNid,omitempty"`
// CookieMatchingUrl: The base URL used in cookie match requests.
CookieMatchingUrl string `json:"cookieMatchingUrl,omitempty"`
// Id: Account id.
Id int64 `json:"id,omitempty"`
// Kind: Resource type.
Kind string `json:"kind,omitempty"`
// MaximumActiveCreatives: The maximum number of active creatives that
// an account can have, where a creative is active if it was inserted or
// bid with in the last 30 days. Please contact your technical account
// manager if you need to change this.
MaximumActiveCreatives int64 `json:"maximumActiveCreatives,omitempty"`
// MaximumTotalQps: The sum of all bidderLocation.maximumQps values
// cannot exceed this. Please contact your technical account manager if
// you need to change this.
MaximumTotalQps int64 `json:"maximumTotalQps,omitempty"`
// NumberActiveCreatives: The number of creatives that this account
// inserted or bid with in the last 30 days.
NumberActiveCreatives int64 `json:"numberActiveCreatives,omitempty"`
}
Account: Configuration data for an Ad Exchange buyer account.
type AccountBidderLocation ¶
type AccountBidderLocation struct {
// MaximumQps: The maximum queries per second the Ad Exchange will send.
MaximumQps int64 `json:"maximumQps,omitempty"`
// Region: The geographical region the Ad Exchange should send requests
// from. Only used by some quota systems, but always setting the value
// is recommended. Allowed values:
// - ASIA
// - EUROPE
// - US_EAST
// - US_WEST
Region string `json:"region,omitempty"`
// Url: The URL to which the Ad Exchange will send bid requests.
Url string `json:"url,omitempty"`
}
type AccountsGetCall ¶
type AccountsGetCall struct {
// contains filtered or unexported fields
}
func (*AccountsGetCall) Do ¶
func (c *AccountsGetCall) Do() (*Account, error)
func (*AccountsGetCall) Fields ¶
func (c *AccountsGetCall) Fields(s ...googleapi.Field) *AccountsGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type AccountsList ¶
type AccountsList struct {
// Items: A list of accounts.
Items []*Account `json:"items,omitempty"`
// Kind: Resource type.
Kind string `json:"kind,omitempty"`
}
AccountsList: An account feed lists Ad Exchange buyer accounts that the user has access to. Each entry in the feed corresponds to a single buyer account.
type AccountsListCall ¶
type AccountsListCall struct {
// contains filtered or unexported fields
}
func (*AccountsListCall) Do ¶
func (c *AccountsListCall) Do() (*AccountsList, error)
func (*AccountsListCall) Fields ¶
func (c *AccountsListCall) Fields(s ...googleapi.Field) *AccountsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type AccountsPatchCall ¶
type AccountsPatchCall struct {
// contains filtered or unexported fields
}
func (*AccountsPatchCall) Do ¶
func (c *AccountsPatchCall) Do() (*Account, error)
func (*AccountsPatchCall) Fields ¶
func (c *AccountsPatchCall) Fields(s ...googleapi.Field) *AccountsPatchCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type AccountsService ¶
type AccountsService struct {
// contains filtered or unexported fields
}
func NewAccountsService ¶
func NewAccountsService(s *Service) *AccountsService
func (*AccountsService) Get ¶
func (r *AccountsService) Get(id int64) *AccountsGetCall
Get: Gets one account by ID.
func (*AccountsService) List ¶
func (r *AccountsService) List() *AccountsListCall
List: Retrieves the authenticated user's list of accounts.
func (*AccountsService) Patch ¶
func (r *AccountsService) Patch(id int64, account *Account) *AccountsPatchCall
Patch: Updates an existing account. This method supports patch semantics.
func (*AccountsService) Update ¶
func (r *AccountsService) Update(id int64, account *Account) *AccountsUpdateCall
Update: Updates an existing account.
type AccountsUpdateCall ¶
type AccountsUpdateCall struct {
// contains filtered or unexported fields
}
func (*AccountsUpdateCall) Do ¶
func (c *AccountsUpdateCall) Do() (*Account, error)
func (*AccountsUpdateCall) Fields ¶
func (c *AccountsUpdateCall) Fields(s ...googleapi.Field) *AccountsUpdateCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type Creative ¶
type Creative struct {
// HTMLSnippet: The HTML snippet that displays the ad when inserted in
// the web page. If set, videoURL should not be set.
HTMLSnippet string `json:"HTMLSnippet,omitempty"`
// AccountId: Account id.
AccountId int64 `json:"accountId,omitempty"`
// AdvertiserId: Detected advertiser id, if any. Read-only. This field
// should not be set in requests.
AdvertiserId googleapi.Int64s `json:"advertiserId,omitempty"`
// AdvertiserName: The name of the company being advertised in the
// creative.
AdvertiserName string `json:"advertiserName,omitempty"`
// AgencyId: The agency id for this creative.
AgencyId int64 `json:"agencyId,omitempty,string"`
// ApiUploadTimestamp: The last upload timestamp of this creative if it
// was uploaded via API. Read-only. The value of this field is
// generated, and will be ignored for uploads. (formatted RFC 3339
// timestamp).
ApiUploadTimestamp string `json:"api_upload_timestamp,omitempty"`
// Attribute: All attributes for the ads that may be shown from this
// snippet.
Attribute []int64 `json:"attribute,omitempty"`
// BuyerCreativeId: A buyer-specific id identifying the creative in this
// ad.
BuyerCreativeId string `json:"buyerCreativeId,omitempty"`
// ClickThroughUrl: The set of destination urls for the snippet.
ClickThroughUrl []string `json:"clickThroughUrl,omitempty"`
// Corrections: Shows any corrections that were applied to this
// creative. Read-only. This field should not be set in requests.
Corrections []*CreativeCorrections `json:"corrections,omitempty"`
// DisapprovalReasons: The reasons for disapproval, if any. Note that
// not all disapproval reasons may be categorized, so it is possible for
// the creative to have a status of DISAPPROVED with an empty list for
// disapproval_reasons. In this case, please reach out to your TAM to
// help debug the issue. Read-only. This field should not be set in
// requests.
DisapprovalReasons []*CreativeDisapprovalReasons `json:"disapprovalReasons,omitempty"`
// FilteringReasons: The filtering reasons for the creative. Read-only.
// This field should not be set in requests.
FilteringReasons *CreativeFilteringReasons `json:"filteringReasons,omitempty"`
// Height: Ad height.
Height int64 `json:"height,omitempty"`
// ImpressionTrackingUrl: The set of urls to be called to record an
// impression.
ImpressionTrackingUrl []string `json:"impressionTrackingUrl,omitempty"`
// Kind: Resource type.
Kind string `json:"kind,omitempty"`
// ProductCategories: Detected product categories, if any. Read-only.
// This field should not be set in requests.
ProductCategories []int64 `json:"productCategories,omitempty"`
// RestrictedCategories: All restricted categories for the ads that may
// be shown from this snippet.
RestrictedCategories []int64 `json:"restrictedCategories,omitempty"`
// SensitiveCategories: Detected sensitive categories, if any.
// Read-only. This field should not be set in requests.
SensitiveCategories []int64 `json:"sensitiveCategories,omitempty"`
// Status: Creative serving status. Read-only. This field should not be
// set in requests.
Status string `json:"status,omitempty"`
// VendorType: All vendor types for the ads that may be shown from this
// snippet.
VendorType []int64 `json:"vendorType,omitempty"`
// Version: The version for this creative. Read-only. This field should
// not be set in requests.
Version int64 `json:"version,omitempty"`
// VideoURL: The url to fetch a video ad. If set, HTMLSnippet should not
// be set.
VideoURL string `json:"videoURL,omitempty"`
// Width: Ad width.
Width int64 `json:"width,omitempty"`
}
Creative: A creative and its classification data.
type CreativeCorrections ¶
type CreativeFilteringReasons ¶
type CreativeFilteringReasons struct {
// Date: The date in ISO 8601 format for the data. The data is collected
// from 00:00:00 to 23:59:59 in PST.
Date string `json:"date,omitempty"`
// Reasons: The filtering reasons.
Reasons []*CreativeFilteringReasonsReasons `json:"reasons,omitempty"`
}
CreativeFilteringReasons: The filtering reasons for the creative. Read-only. This field should not be set in requests.
type CreativeFilteringReasonsReasons ¶
type CreativeFilteringReasonsReasons struct {
// FilteringCount: The number of times the creative was filtered for the
// status. The count is aggregated across all publishers on the
// exchange.
FilteringCount int64 `json:"filteringCount,omitempty,string"`
// FilteringStatus: The filtering status code. Please refer to the
// creative-status-codes.txt file for different statuses.
FilteringStatus int64 `json:"filteringStatus,omitempty"`
}
type CreativesGetCall ¶
type CreativesGetCall struct {
// contains filtered or unexported fields
}
func (*CreativesGetCall) Do ¶
func (c *CreativesGetCall) Do() (*Creative, error)
func (*CreativesGetCall) Fields ¶
func (c *CreativesGetCall) Fields(s ...googleapi.Field) *CreativesGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type CreativesInsertCall ¶
type CreativesInsertCall struct {
// contains filtered or unexported fields
}
func (*CreativesInsertCall) Do ¶
func (c *CreativesInsertCall) Do() (*Creative, error)
func (*CreativesInsertCall) Fields ¶
func (c *CreativesInsertCall) Fields(s ...googleapi.Field) *CreativesInsertCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type CreativesList ¶
type CreativesList struct {
// Items: A list of creatives.
Items []*Creative `json:"items,omitempty"`
// Kind: Resource type.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through creatives. To
// retrieve the next page of results, set the next request's "pageToken"
// value to this.
NextPageToken string `json:"nextPageToken,omitempty"`
}
CreativesList: The creatives feed lists the active creatives for the Ad Exchange buyer accounts that the user has access to. Each entry in the feed corresponds to a single creative.
type CreativesListCall ¶
type CreativesListCall struct {
// contains filtered or unexported fields
}
func (*CreativesListCall) Do ¶
func (c *CreativesListCall) Do() (*CreativesList, error)
func (*CreativesListCall) Fields ¶
func (c *CreativesListCall) Fields(s ...googleapi.Field) *CreativesListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*CreativesListCall) MaxResults ¶
func (c *CreativesListCall) MaxResults(maxResults int64) *CreativesListCall
MaxResults sets the optional parameter "maxResults": Maximum number of entries returned on one result page. If not set, the default is 100.
func (*CreativesListCall) PageToken ¶
func (c *CreativesListCall) PageToken(pageToken string) *CreativesListCall
PageToken sets the optional parameter "pageToken": A continuation token, used to page through ad clients. To retrieve the next page, set this parameter to the value of "nextPageToken" from the previous response.
func (*CreativesListCall) StatusFilter ¶
func (c *CreativesListCall) StatusFilter(statusFilter string) *CreativesListCall
StatusFilter sets the optional parameter "statusFilter": When specified, only creatives having the given status are returned.
Possible values:
"approved" - Creatives which have been approved. "disapproved" - Creatives which have been disapproved. "not_checked" - Creatives whose status is not yet checked.
type CreativesService ¶
type CreativesService struct {
// contains filtered or unexported fields
}
func NewCreativesService ¶
func NewCreativesService(s *Service) *CreativesService
func (*CreativesService) Get ¶
func (r *CreativesService) Get(accountId int64, buyerCreativeId string) *CreativesGetCall
Get: Gets the status for a single creative. A creative will be available 30-40 minutes after submission.
func (*CreativesService) Insert ¶
func (r *CreativesService) Insert(creative *Creative) *CreativesInsertCall
Insert: Submit a new creative.
func (*CreativesService) List ¶
func (r *CreativesService) List() *CreativesListCall
List: Retrieves a list of the authenticated user's active creatives. A creative will be available 30-40 minutes after submission.