Documentation
¶
Overview ¶
Package adexchangeseller provides access to the Ad Exchange Seller API.
See https://developers.google.com/ad-exchange/seller-rest/
Usage example:
import "google.golang.org/api/adexchangeseller/v1" ... adexchangesellerService, err := adexchangeseller.New(oauthHttpClient)
Index ¶
- Constants
- type AdClient
- type AdClients
- type AdUnit
- type AdUnits
- type AdclientsListCall
- type AdclientsService
- type AdunitsCustomchannelsListCall
- func (c *AdunitsCustomchannelsListCall) Do() (*CustomChannels, error)
- func (c *AdunitsCustomchannelsListCall) Fields(s ...googleapi.Field) *AdunitsCustomchannelsListCall
- func (c *AdunitsCustomchannelsListCall) MaxResults(maxResults int64) *AdunitsCustomchannelsListCall
- func (c *AdunitsCustomchannelsListCall) PageToken(pageToken string) *AdunitsCustomchannelsListCall
- type AdunitsCustomchannelsService
- type AdunitsGetCall
- type AdunitsListCall
- func (c *AdunitsListCall) Do() (*AdUnits, error)
- func (c *AdunitsListCall) Fields(s ...googleapi.Field) *AdunitsListCall
- func (c *AdunitsListCall) IncludeInactive(includeInactive bool) *AdunitsListCall
- func (c *AdunitsListCall) MaxResults(maxResults int64) *AdunitsListCall
- func (c *AdunitsListCall) PageToken(pageToken string) *AdunitsListCall
- type AdunitsService
- type CustomChannel
- type CustomChannelTargetingInfo
- type CustomChannels
- type CustomchannelsAdunitsListCall
- func (c *CustomchannelsAdunitsListCall) Do() (*AdUnits, error)
- func (c *CustomchannelsAdunitsListCall) Fields(s ...googleapi.Field) *CustomchannelsAdunitsListCall
- func (c *CustomchannelsAdunitsListCall) IncludeInactive(includeInactive bool) *CustomchannelsAdunitsListCall
- func (c *CustomchannelsAdunitsListCall) MaxResults(maxResults int64) *CustomchannelsAdunitsListCall
- func (c *CustomchannelsAdunitsListCall) PageToken(pageToken string) *CustomchannelsAdunitsListCall
- type CustomchannelsAdunitsService
- type CustomchannelsGetCall
- type CustomchannelsListCall
- func (c *CustomchannelsListCall) Do() (*CustomChannels, error)
- func (c *CustomchannelsListCall) Fields(s ...googleapi.Field) *CustomchannelsListCall
- func (c *CustomchannelsListCall) MaxResults(maxResults int64) *CustomchannelsListCall
- func (c *CustomchannelsListCall) PageToken(pageToken string) *CustomchannelsListCall
- type CustomchannelsService
- type Report
- type ReportHeaders
- type ReportsGenerateCall
- func (c *ReportsGenerateCall) Dimension(dimension string) *ReportsGenerateCall
- func (c *ReportsGenerateCall) Do() (*Report, error)
- func (c *ReportsGenerateCall) Download() (*http.Response, error)
- func (c *ReportsGenerateCall) Fields(s ...googleapi.Field) *ReportsGenerateCall
- func (c *ReportsGenerateCall) Filter(filter string) *ReportsGenerateCall
- func (c *ReportsGenerateCall) Locale(locale string) *ReportsGenerateCall
- func (c *ReportsGenerateCall) MaxResults(maxResults int64) *ReportsGenerateCall
- func (c *ReportsGenerateCall) Metric(metric string) *ReportsGenerateCall
- func (c *ReportsGenerateCall) Sort(sort string) *ReportsGenerateCall
- func (c *ReportsGenerateCall) StartIndex(startIndex int64) *ReportsGenerateCall
- type ReportsSavedGenerateCall
- func (c *ReportsSavedGenerateCall) Do() (*Report, error)
- func (c *ReportsSavedGenerateCall) Fields(s ...googleapi.Field) *ReportsSavedGenerateCall
- func (c *ReportsSavedGenerateCall) Locale(locale string) *ReportsSavedGenerateCall
- func (c *ReportsSavedGenerateCall) MaxResults(maxResults int64) *ReportsSavedGenerateCall
- func (c *ReportsSavedGenerateCall) StartIndex(startIndex int64) *ReportsSavedGenerateCall
- type ReportsSavedListCall
- func (c *ReportsSavedListCall) Do() (*SavedReports, error)
- func (c *ReportsSavedListCall) Fields(s ...googleapi.Field) *ReportsSavedListCall
- func (c *ReportsSavedListCall) MaxResults(maxResults int64) *ReportsSavedListCall
- func (c *ReportsSavedListCall) PageToken(pageToken string) *ReportsSavedListCall
- type ReportsSavedService
- type ReportsService
- type SavedReport
- type SavedReports
- type Service
- type UrlChannel
- type UrlChannels
- type UrlchannelsListCall
- type UrlchannelsService
Constants ¶
const ( // View and manage your Ad Exchange data AdexchangeSellerScope = "https://www.googleapis.com/auth/adexchange.seller" // View your Ad Exchange data AdexchangeSellerReadonlyScope = "https://www.googleapis.com/auth/adexchange.seller.readonly" )
OAuth2 scopes used by this API.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AdClient ¶
type AdClient struct {
// ArcOptIn: Whether this ad client is opted in to ARC.
ArcOptIn bool `json:"arcOptIn,omitempty"`
// Id: Unique identifier of this ad client.
Id string `json:"id,omitempty"`
// Kind: Kind of resource this is, in this case
// adexchangeseller#adClient.
Kind string `json:"kind,omitempty"`
// ProductCode: This ad client's product code, which corresponds to the
// PRODUCT_CODE report dimension.
ProductCode string `json:"productCode,omitempty"`
// SupportsReporting: Whether this ad client supports being reported on.
SupportsReporting bool `json:"supportsReporting,omitempty"`
}
type AdClients ¶
type AdClients struct {
// Etag: ETag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The ad clients returned in this list response.
Items []*AdClient `json:"items,omitempty"`
// Kind: Kind of list this is, in this case adexchangeseller#adClients.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through ad clients. To
// retrieve the next page of results, set the next request's "pageToken"
// value to this.
NextPageToken string `json:"nextPageToken,omitempty"`
}
type AdUnit ¶
type AdUnit struct {
// Code: Identity code of this ad unit, not necessarily unique across ad
// clients.
Code string `json:"code,omitempty"`
// Id: Unique identifier of this ad unit. This should be considered an
// opaque identifier; it is not safe to rely on it being in any
// particular format.
Id string `json:"id,omitempty"`
// Kind: Kind of resource this is, in this case adexchangeseller#adUnit.
Kind string `json:"kind,omitempty"`
// Name: Name of this ad unit.
Name string `json:"name,omitempty"`
// Status: Status of this ad unit. Possible values are:
// NEW: Indicates that the ad unit was created within the last seven
// days and does not yet have any activity associated with it.
//
// ACTIVE: Indicates that there has been activity on this ad unit in the
// last seven days.
//
// INACTIVE: Indicates that there has been no activity on this ad unit
// in the last seven days.
Status string `json:"status,omitempty"`
}
type AdUnits ¶
type AdUnits struct {
// Etag: ETag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The ad units returned in this list response.
Items []*AdUnit `json:"items,omitempty"`
// Kind: Kind of list this is, in this case adexchangeseller#adUnits.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through ad units. To
// retrieve the next page of results, set the next request's "pageToken"
// value to this.
NextPageToken string `json:"nextPageToken,omitempty"`
}
type AdclientsListCall ¶
type AdclientsListCall struct {
// contains filtered or unexported fields
}
func (*AdclientsListCall) Do ¶
func (c *AdclientsListCall) Do() (*AdClients, error)
func (*AdclientsListCall) Fields ¶
func (c *AdclientsListCall) Fields(s ...googleapi.Field) *AdclientsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*AdclientsListCall) MaxResults ¶
func (c *AdclientsListCall) MaxResults(maxResults int64) *AdclientsListCall
MaxResults sets the optional parameter "maxResults": The maximum number of ad clients to include in the response, used for paging.
func (*AdclientsListCall) PageToken ¶
func (c *AdclientsListCall) PageToken(pageToken string) *AdclientsListCall
PageToken sets the optional parameter "pageToken": A continuation token, used to page through ad clients. To retrieve the next page, set this parameter to the value of "nextPageToken" from the previous response.
type AdclientsService ¶
type AdclientsService struct {
// contains filtered or unexported fields
}
func NewAdclientsService ¶
func NewAdclientsService(s *Service) *AdclientsService
func (*AdclientsService) List ¶
func (r *AdclientsService) List() *AdclientsListCall
List: List all ad clients in this Ad Exchange account.
type AdunitsCustomchannelsListCall ¶
type AdunitsCustomchannelsListCall struct {
// contains filtered or unexported fields
}
func (*AdunitsCustomchannelsListCall) Do ¶
func (c *AdunitsCustomchannelsListCall) Do() (*CustomChannels, error)
func (*AdunitsCustomchannelsListCall) Fields ¶
func (c *AdunitsCustomchannelsListCall) Fields(s ...googleapi.Field) *AdunitsCustomchannelsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*AdunitsCustomchannelsListCall) MaxResults ¶
func (c *AdunitsCustomchannelsListCall) MaxResults(maxResults int64) *AdunitsCustomchannelsListCall
MaxResults sets the optional parameter "maxResults": The maximum number of custom channels to include in the response, used for paging.
func (*AdunitsCustomchannelsListCall) PageToken ¶
func (c *AdunitsCustomchannelsListCall) PageToken(pageToken string) *AdunitsCustomchannelsListCall
PageToken sets the optional parameter "pageToken": A continuation token, used to page through custom channels. To retrieve the next page, set this parameter to the value of "nextPageToken" from the previous response.
type AdunitsCustomchannelsService ¶
type AdunitsCustomchannelsService struct {
// contains filtered or unexported fields
}
func NewAdunitsCustomchannelsService ¶
func NewAdunitsCustomchannelsService(s *Service) *AdunitsCustomchannelsService
func (*AdunitsCustomchannelsService) List ¶
func (r *AdunitsCustomchannelsService) List(adClientId string, adUnitId string) *AdunitsCustomchannelsListCall
List: List all custom channels which the specified ad unit belongs to.
type AdunitsGetCall ¶
type AdunitsGetCall struct {
// contains filtered or unexported fields
}
func (*AdunitsGetCall) Do ¶
func (c *AdunitsGetCall) Do() (*AdUnit, error)
func (*AdunitsGetCall) Fields ¶
func (c *AdunitsGetCall) Fields(s ...googleapi.Field) *AdunitsGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type AdunitsListCall ¶
type AdunitsListCall struct {
// contains filtered or unexported fields
}
func (*AdunitsListCall) Do ¶
func (c *AdunitsListCall) Do() (*AdUnits, error)
func (*AdunitsListCall) Fields ¶
func (c *AdunitsListCall) Fields(s ...googleapi.Field) *AdunitsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*AdunitsListCall) IncludeInactive ¶
func (c *AdunitsListCall) IncludeInactive(includeInactive bool) *AdunitsListCall
IncludeInactive sets the optional parameter "includeInactive": Whether to include inactive ad units. Default: true.
func (*AdunitsListCall) MaxResults ¶
func (c *AdunitsListCall) MaxResults(maxResults int64) *AdunitsListCall
MaxResults sets the optional parameter "maxResults": The maximum number of ad units to include in the response, used for paging.
func (*AdunitsListCall) PageToken ¶
func (c *AdunitsListCall) PageToken(pageToken string) *AdunitsListCall
PageToken sets the optional parameter "pageToken": A continuation token, used to page through ad units. To retrieve the next page, set this parameter to the value of "nextPageToken" from the previous response.
type AdunitsService ¶
type AdunitsService struct {
Customchannels *AdunitsCustomchannelsService
// contains filtered or unexported fields
}
func NewAdunitsService ¶
func NewAdunitsService(s *Service) *AdunitsService
func (*AdunitsService) Get ¶
func (r *AdunitsService) Get(adClientId string, adUnitId string) *AdunitsGetCall
Get: Gets the specified ad unit in the specified ad client.
func (*AdunitsService) List ¶
func (r *AdunitsService) List(adClientId string) *AdunitsListCall
List: List all ad units in the specified ad client for this Ad Exchange account.
type CustomChannel ¶
type CustomChannel struct {
// Code: Code of this custom channel, not necessarily unique across ad
// clients.
Code string `json:"code,omitempty"`
// Id: Unique identifier of this custom channel. This should be
// considered an opaque identifier; it is not safe to rely on it being
// in any particular format.
Id string `json:"id,omitempty"`
// Kind: Kind of resource this is, in this case
// adexchangeseller#customChannel.
Kind string `json:"kind,omitempty"`
// Name: Name of this custom channel.
Name string `json:"name,omitempty"`
// TargetingInfo: The targeting information of this custom channel, if
// activated.
TargetingInfo *CustomChannelTargetingInfo `json:"targetingInfo,omitempty"`
}
type CustomChannelTargetingInfo ¶
type CustomChannelTargetingInfo struct {
// AdsAppearOn: The name used to describe this channel externally.
AdsAppearOn string `json:"adsAppearOn,omitempty"`
// Description: The external description of the channel.
Description string `json:"description,omitempty"`
// Location: The locations in which ads appear. (Only valid for content
// and mobile content ads). Acceptable values for content ads are:
// TOP_LEFT, TOP_CENTER, TOP_RIGHT, MIDDLE_LEFT, MIDDLE_CENTER,
// MIDDLE_RIGHT, BOTTOM_LEFT, BOTTOM_CENTER, BOTTOM_RIGHT,
// MULTIPLE_LOCATIONS. Acceptable values for mobile content ads are:
// TOP, MIDDLE, BOTTOM, MULTIPLE_LOCATIONS.
Location string `json:"location,omitempty"`
// SiteLanguage: The language of the sites ads will be displayed on.
SiteLanguage string `json:"siteLanguage,omitempty"`
}
CustomChannelTargetingInfo: The targeting information of this custom channel, if activated.
type CustomChannels ¶
type CustomChannels struct {
// Etag: ETag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The custom channels returned in this list response.
Items []*CustomChannel `json:"items,omitempty"`
// Kind: Kind of list this is, in this case
// adexchangeseller#customChannels.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through custom
// channels. To retrieve the next page of results, set the next
// request's "pageToken" value to this.
NextPageToken string `json:"nextPageToken,omitempty"`
}
type CustomchannelsAdunitsListCall ¶
type CustomchannelsAdunitsListCall struct {
// contains filtered or unexported fields
}
func (*CustomchannelsAdunitsListCall) Do ¶
func (c *CustomchannelsAdunitsListCall) Do() (*AdUnits, error)
func (*CustomchannelsAdunitsListCall) Fields ¶
func (c *CustomchannelsAdunitsListCall) Fields(s ...googleapi.Field) *CustomchannelsAdunitsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*CustomchannelsAdunitsListCall) IncludeInactive ¶
func (c *CustomchannelsAdunitsListCall) IncludeInactive(includeInactive bool) *CustomchannelsAdunitsListCall
IncludeInactive sets the optional parameter "includeInactive": Whether to include inactive ad units. Default: true.
func (*CustomchannelsAdunitsListCall) MaxResults ¶
func (c *CustomchannelsAdunitsListCall) MaxResults(maxResults int64) *CustomchannelsAdunitsListCall
MaxResults sets the optional parameter "maxResults": The maximum number of ad units to include in the response, used for paging.
func (*CustomchannelsAdunitsListCall) PageToken ¶
func (c *CustomchannelsAdunitsListCall) PageToken(pageToken string) *CustomchannelsAdunitsListCall
PageToken sets the optional parameter "pageToken": A continuation token, used to page through ad units. To retrieve the next page, set this parameter to the value of "nextPageToken" from the previous response.
type CustomchannelsAdunitsService ¶
type CustomchannelsAdunitsService struct {
// contains filtered or unexported fields
}
func NewCustomchannelsAdunitsService ¶
func NewCustomchannelsAdunitsService(s *Service) *CustomchannelsAdunitsService
func (*CustomchannelsAdunitsService) List ¶
func (r *CustomchannelsAdunitsService) List(adClientId string, customChannelId string) *CustomchannelsAdunitsListCall
List: List all ad units in the specified custom channel.
type CustomchannelsGetCall ¶
type CustomchannelsGetCall struct {
// contains filtered or unexported fields
}
func (*CustomchannelsGetCall) Do ¶
func (c *CustomchannelsGetCall) Do() (*CustomChannel, error)
func (*CustomchannelsGetCall) Fields ¶
func (c *CustomchannelsGetCall) Fields(s ...googleapi.Field) *CustomchannelsGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type CustomchannelsListCall ¶
type CustomchannelsListCall struct {
// contains filtered or unexported fields
}
func (*CustomchannelsListCall) Do ¶
func (c *CustomchannelsListCall) Do() (*CustomChannels, error)
func (*CustomchannelsListCall) Fields ¶
func (c *CustomchannelsListCall) Fields(s ...googleapi.Field) *CustomchannelsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*CustomchannelsListCall) MaxResults ¶
func (c *CustomchannelsListCall) MaxResults(maxResults int64) *CustomchannelsListCall
MaxResults sets the optional parameter "maxResults": The maximum number of custom channels to include in the response, used for paging.
func (*CustomchannelsListCall) PageToken ¶
func (c *CustomchannelsListCall) PageToken(pageToken string) *CustomchannelsListCall
PageToken sets the optional parameter "pageToken": A continuation token, used to page through custom channels. To retrieve the next page, set this parameter to the value of "nextPageToken" from the previous response.
type CustomchannelsService ¶
type CustomchannelsService struct {
Adunits *CustomchannelsAdunitsService
// contains filtered or unexported fields
}
func NewCustomchannelsService ¶
func NewCustomchannelsService(s *Service) *CustomchannelsService
func (*CustomchannelsService) Get ¶
func (r *CustomchannelsService) Get(adClientId string, customChannelId string) *CustomchannelsGetCall
Get: Get the specified custom channel from the specified ad client.
func (*CustomchannelsService) List ¶
func (r *CustomchannelsService) List(adClientId string) *CustomchannelsListCall
List: List all custom channels in the specified ad client for this Ad Exchange account.
type Report ¶
type Report struct {
// Averages: The averages of the report. This is the same length as any
// other row in the report; cells corresponding to dimension columns are
// empty.
Averages []string `json:"averages,omitempty"`
// Headers: The header information of the columns requested in the
// report. This is a list of headers; one for each dimension in the
// request, followed by one for each metric in the request.
Headers []*ReportHeaders `json:"headers,omitempty"`
// Kind: Kind this is, in this case adexchangeseller#report.
Kind string `json:"kind,omitempty"`
// Rows: The output rows of the report. Each row is a list of cells; one
// for each dimension in the request, followed by one for each metric in
// the request. The dimension cells contain strings, and the metric
// cells contain numbers.
Rows [][]string `json:"rows,omitempty"`
// TotalMatchedRows: The total number of rows matched by the report
// request. Fewer rows may be returned in the response due to being
// limited by the row count requested or the report row limit.
TotalMatchedRows int64 `json:"totalMatchedRows,omitempty,string"`
// Totals: The totals of the report. This is the same length as any
// other row in the report; cells corresponding to dimension columns are
// empty.
Totals []string `json:"totals,omitempty"`
// Warnings: Any warnings associated with generation of the report.
Warnings []string `json:"warnings,omitempty"`
}
type ReportHeaders ¶
type ReportHeaders struct {
// Currency: The currency of this column. Only present if the header
// type is METRIC_CURRENCY.
Currency string `json:"currency,omitempty"`
// Name: The name of the header.
Name string `json:"name,omitempty"`
// Type: The type of the header; one of DIMENSION, METRIC_TALLY,
// METRIC_RATIO, or METRIC_CURRENCY.
Type string `json:"type,omitempty"`
}
type ReportsGenerateCall ¶
type ReportsGenerateCall struct {
// contains filtered or unexported fields
}
func (*ReportsGenerateCall) Dimension ¶
func (c *ReportsGenerateCall) Dimension(dimension string) *ReportsGenerateCall
Dimension sets the optional parameter "dimension": Dimensions to base the report on.
func (*ReportsGenerateCall) Do ¶
func (c *ReportsGenerateCall) Do() (*Report, error)
func (*ReportsGenerateCall) Download ¶
func (c *ReportsGenerateCall) Download() (*http.Response, error)
Download fetches the API endpoint's "media" value, instead of the normal API response value. If the returned error is nil, the Response is guaranteed to have a 2xx status code. Callers must close the Response.Body as usual.
func (*ReportsGenerateCall) Fields ¶
func (c *ReportsGenerateCall) Fields(s ...googleapi.Field) *ReportsGenerateCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*ReportsGenerateCall) Filter ¶
func (c *ReportsGenerateCall) Filter(filter string) *ReportsGenerateCall
Filter sets the optional parameter "filter": Filters to be run on the report.
func (*ReportsGenerateCall) Locale ¶
func (c *ReportsGenerateCall) Locale(locale string) *ReportsGenerateCall
Locale sets the optional parameter "locale": Optional locale to use for translating report output to a local language. Defaults to "en_US" if not specified.
func (*ReportsGenerateCall) MaxResults ¶
func (c *ReportsGenerateCall) MaxResults(maxResults int64) *ReportsGenerateCall
MaxResults sets the optional parameter "maxResults": The maximum number of rows of report data to return.
func (*ReportsGenerateCall) Metric ¶
func (c *ReportsGenerateCall) Metric(metric string) *ReportsGenerateCall
Metric sets the optional parameter "metric": Numeric columns to include in the report.
func (*ReportsGenerateCall) Sort ¶
func (c *ReportsGenerateCall) Sort(sort string) *ReportsGenerateCall
Sort sets the optional parameter "sort": The name of a dimension or metric to sort the resulting report on, optionally prefixed with "+" to sort ascending or "-" to sort descending. If no prefix is specified, the column is sorted ascending.
func (*ReportsGenerateCall) StartIndex ¶
func (c *ReportsGenerateCall) StartIndex(startIndex int64) *ReportsGenerateCall
StartIndex sets the optional parameter "startIndex": Index of the first row of report data to return.
type ReportsSavedGenerateCall ¶
type ReportsSavedGenerateCall struct {
// contains filtered or unexported fields
}
func (*ReportsSavedGenerateCall) Do ¶
func (c *ReportsSavedGenerateCall) Do() (*Report, error)
func (*ReportsSavedGenerateCall) Fields ¶
func (c *ReportsSavedGenerateCall) Fields(s ...googleapi.Field) *ReportsSavedGenerateCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*ReportsSavedGenerateCall) Locale ¶
func (c *ReportsSavedGenerateCall) Locale(locale string) *ReportsSavedGenerateCall
Locale sets the optional parameter "locale": Optional locale to use for translating report output to a local language. Defaults to "en_US" if not specified.
func (*ReportsSavedGenerateCall) MaxResults ¶
func (c *ReportsSavedGenerateCall) MaxResults(maxResults int64) *ReportsSavedGenerateCall
MaxResults sets the optional parameter "maxResults": The maximum number of rows of report data to return.
func (*ReportsSavedGenerateCall) StartIndex ¶
func (c *ReportsSavedGenerateCall) StartIndex(startIndex int64) *ReportsSavedGenerateCall
StartIndex sets the optional parameter "startIndex": Index of the first row of report data to return.
type ReportsSavedListCall ¶
type ReportsSavedListCall struct {
// contains filtered or unexported fields
}
func (*ReportsSavedListCall) Do ¶
func (c *ReportsSavedListCall) Do() (*SavedReports, error)
func (*ReportsSavedListCall) Fields ¶
func (c *ReportsSavedListCall) Fields(s ...googleapi.Field) *ReportsSavedListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*ReportsSavedListCall) MaxResults ¶
func (c *ReportsSavedListCall) MaxResults(maxResults int64) *ReportsSavedListCall
MaxResults sets the optional parameter "maxResults": The maximum number of saved reports to include in the response, used for paging.
func (*ReportsSavedListCall) PageToken ¶
func (c *ReportsSavedListCall) PageToken(pageToken string) *ReportsSavedListCall
PageToken sets the optional parameter "pageToken": A continuation token, used to page through saved reports. To retrieve the next page, set this parameter to the value of "nextPageToken" from the previous response.
type ReportsSavedService ¶
type ReportsSavedService struct {
// contains filtered or unexported fields
}
func NewReportsSavedService ¶
func NewReportsSavedService(s *Service) *ReportsSavedService
func (*ReportsSavedService) Generate ¶
func (r *ReportsSavedService) Generate(savedReportId string) *ReportsSavedGenerateCall
Generate: Generate an Ad Exchange report based on the saved report ID sent in the query parameters.
func (*ReportsSavedService) List ¶
func (r *ReportsSavedService) List() *ReportsSavedListCall
List: List all saved reports in this Ad Exchange account.
type ReportsService ¶
type ReportsService struct {
Saved *ReportsSavedService
// contains filtered or unexported fields
}
func NewReportsService ¶
func NewReportsService(s *Service) *ReportsService
func (*ReportsService) Generate ¶
func (r *ReportsService) Generate(startDate string, endDate string) *ReportsGenerateCall
Generate: Generate an Ad Exchange report based on the report request sent in the query parameters. Returns the result as JSON; to retrieve output in CSV format specify "alt=csv" as a query parameter.
type SavedReport ¶
type SavedReports ¶
type SavedReports struct {
// Etag: ETag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The saved reports returned in this list response.
Items []*SavedReport `json:"items,omitempty"`
// Kind: Kind of list this is, in this case
// adexchangeseller#savedReports.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through saved reports.
// To retrieve the next page of results, set the next request's
// "pageToken" value to this.
NextPageToken string `json:"nextPageToken,omitempty"`
}
type Service ¶
type Service struct {
BasePath string // API endpoint base URL
UserAgent string // optional additional User-Agent fragment
Adclients *AdclientsService
Adunits *AdunitsService
Customchannels *CustomchannelsService
Reports *ReportsService
Urlchannels *UrlchannelsService
// contains filtered or unexported fields
}
type UrlChannel ¶
type UrlChannel struct {
// Id: Unique identifier of this URL channel. This should be considered
// an opaque identifier; it is not safe to rely on it being in any
// particular format.
Id string `json:"id,omitempty"`
// Kind: Kind of resource this is, in this case
// adexchangeseller#urlChannel.
Kind string `json:"kind,omitempty"`
// UrlPattern: URL Pattern of this URL channel. Does not include
// "http://" or "https://". Example: www.example.com/home
UrlPattern string `json:"urlPattern,omitempty"`
}
type UrlChannels ¶
type UrlChannels struct {
// Etag: ETag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The URL channels returned in this list response.
Items []*UrlChannel `json:"items,omitempty"`
// Kind: Kind of list this is, in this case
// adexchangeseller#urlChannels.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through URL channels.
// To retrieve the next page of results, set the next request's
// "pageToken" value to this.
NextPageToken string `json:"nextPageToken,omitempty"`
}
type UrlchannelsListCall ¶
type UrlchannelsListCall struct {
// contains filtered or unexported fields
}
func (*UrlchannelsListCall) Do ¶
func (c *UrlchannelsListCall) Do() (*UrlChannels, error)
func (*UrlchannelsListCall) Fields ¶
func (c *UrlchannelsListCall) Fields(s ...googleapi.Field) *UrlchannelsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*UrlchannelsListCall) MaxResults ¶
func (c *UrlchannelsListCall) MaxResults(maxResults int64) *UrlchannelsListCall
MaxResults sets the optional parameter "maxResults": The maximum number of URL channels to include in the response, used for paging.
func (*UrlchannelsListCall) PageToken ¶
func (c *UrlchannelsListCall) PageToken(pageToken string) *UrlchannelsListCall
PageToken sets the optional parameter "pageToken": A continuation token, used to page through URL channels. To retrieve the next page, set this parameter to the value of "nextPageToken" from the previous response.
type UrlchannelsService ¶
type UrlchannelsService struct {
// contains filtered or unexported fields
}
func NewUrlchannelsService ¶
func NewUrlchannelsService(s *Service) *UrlchannelsService
func (*UrlchannelsService) List ¶
func (r *UrlchannelsService) List(adClientId string) *UrlchannelsListCall
List: List all URL channels in the specified ad client for this Ad Exchange account.