Documentation
¶
Overview ¶
Package androidpublisher provides access to the Google Play Developer API.
See https://developers.google.com/android-publisher
Usage example:
import "google.golang.org/api/androidpublisher/v1.1" ... androidpublisherService, err := androidpublisher.New(oauthHttpClient)
Index ¶
Constants ¶
const (
// View and manage your Google Play Developer account
AndroidpublisherScope = "https://www.googleapis.com/auth/androidpublisher"
)
OAuth2 scopes used by this API.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InappPurchase ¶
type InappPurchase struct {
// ConsumptionState: The consumption state of the inapp product.
// Possible values are:
// - Yet to be consumed
// - Consumed
ConsumptionState int64 `json:"consumptionState,omitempty"`
// DeveloperPayload: A developer-specified string that contains
// supplemental information about an order.
DeveloperPayload string `json:"developerPayload,omitempty"`
// Kind: This kind represents an inappPurchase object in the
// androidpublisher service.
Kind string `json:"kind,omitempty"`
// PurchaseState: The purchase state of the order. Possible values are:
//
// - Purchased
// - Cancelled
PurchaseState int64 `json:"purchaseState,omitempty"`
// PurchaseTime: The time the product was purchased, in milliseconds
// since the epoch (Jan 1, 1970).
PurchaseTime int64 `json:"purchaseTime,omitempty,string"`
}
InappPurchase: An InappPurchase resource indicates the status of a user's inapp product purchase.
type InapppurchasesGetCall ¶
type InapppurchasesGetCall struct {
// contains filtered or unexported fields
}
func (*InapppurchasesGetCall) Do ¶
func (c *InapppurchasesGetCall) Do() (*InappPurchase, error)
func (*InapppurchasesGetCall) Fields ¶
func (c *InapppurchasesGetCall) Fields(s ...googleapi.Field) *InapppurchasesGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type InapppurchasesService ¶
type InapppurchasesService struct {
// contains filtered or unexported fields
}
func NewInapppurchasesService ¶
func NewInapppurchasesService(s *Service) *InapppurchasesService
func (*InapppurchasesService) Get ¶
func (r *InapppurchasesService) Get(packageName string, productId string, token string) *InapppurchasesGetCall
Get: Checks the purchase and consumption status of an inapp item.
type PurchasesCancelCall ¶
type PurchasesCancelCall struct {
// contains filtered or unexported fields
}
func (*PurchasesCancelCall) Do ¶
func (c *PurchasesCancelCall) Do() error
func (*PurchasesCancelCall) Fields ¶
func (c *PurchasesCancelCall) Fields(s ...googleapi.Field) *PurchasesCancelCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type PurchasesGetCall ¶
type PurchasesGetCall struct {
// contains filtered or unexported fields
}
func (*PurchasesGetCall) Do ¶
func (c *PurchasesGetCall) Do() (*SubscriptionPurchase, error)
func (*PurchasesGetCall) Fields ¶
func (c *PurchasesGetCall) Fields(s ...googleapi.Field) *PurchasesGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type PurchasesService ¶
type PurchasesService struct {
// contains filtered or unexported fields
}
func NewPurchasesService ¶
func NewPurchasesService(s *Service) *PurchasesService
func (*PurchasesService) Cancel ¶
func (r *PurchasesService) Cancel(packageName string, subscriptionId string, token string) *PurchasesCancelCall
Cancel: Cancels a user's subscription purchase. The subscription remains valid until its expiration time.
func (*PurchasesService) Get ¶
func (r *PurchasesService) Get(packageName string, subscriptionId string, token string) *PurchasesGetCall
Get: Checks whether a user's subscription purchase is valid and returns its expiry time.
type Service ¶
type Service struct {
BasePath string // API endpoint base URL
UserAgent string // optional additional User-Agent fragment
Inapppurchases *InapppurchasesService
Purchases *PurchasesService
// contains filtered or unexported fields
}
type SubscriptionPurchase ¶
type SubscriptionPurchase struct {
// AutoRenewing: Whether the subscription will automatically be renewed
// when it reaches its current expiry time.
AutoRenewing bool `json:"autoRenewing,omitempty"`
// InitiationTimestampMsec: Time at which the subscription was granted,
// in milliseconds since Epoch.
InitiationTimestampMsec int64 `json:"initiationTimestampMsec,omitempty,string"`
// Kind: This kind represents a subscriptionPurchase object in the
// androidpublisher service.
Kind string `json:"kind,omitempty"`
// ValidUntilTimestampMsec: Time at which the subscription will expire,
// in milliseconds since Epoch.
ValidUntilTimestampMsec int64 `json:"validUntilTimestampMsec,omitempty,string"`
}
SubscriptionPurchase: A SubscriptionPurchase resource indicates the status of a user's subscription purchase.