Documentation
¶
Overview ¶
Package appsactivity provides access to the Google Apps Activity API.
See https://developers.google.com/google-apps/activity/
Usage example:
import "google.golang.org/api/appsactivity/v1" ... appsactivityService, err := appsactivity.New(oauthHttpClient)
Index ¶
- Constants
- type ActivitiesListCall
- func (c *ActivitiesListCall) Do() (*ListActivitiesResponse, error)
- func (c *ActivitiesListCall) DriveAncestorId(driveAncestorId string) *ActivitiesListCall
- func (c *ActivitiesListCall) DriveFileId(driveFileId string) *ActivitiesListCall
- func (c *ActivitiesListCall) Fields(s ...googleapi.Field) *ActivitiesListCall
- func (c *ActivitiesListCall) GroupingStrategy(groupingStrategy string) *ActivitiesListCall
- func (c *ActivitiesListCall) PageSize(pageSize int64) *ActivitiesListCall
- func (c *ActivitiesListCall) PageToken(pageToken string) *ActivitiesListCall
- func (c *ActivitiesListCall) Source(source string) *ActivitiesListCall
- func (c *ActivitiesListCall) UserId(userId string) *ActivitiesListCall
- type ActivitiesService
- type Activity
- type Event
- type ListActivitiesResponse
- type Move
- type Parent
- type Permission
- type PermissionChange
- type Photo
- type Rename
- type Service
- type Target
- type User
Constants ¶
const ( // View the activity history of your Google Apps ActivityScope = "https://www.googleapis.com/auth/activity" // View and manage the files in your Google Drive DriveScope = "https://www.googleapis.com/auth/drive" // View and manage metadata of files in your Google Drive DriveMetadataScope = "https://www.googleapis.com/auth/drive.metadata" // View metadata for files in your Google Drive DriveMetadataReadonlyScope = "https://www.googleapis.com/auth/drive.metadata.readonly" // View the files in your Google Drive DriveReadonlyScope = "https://www.googleapis.com/auth/drive.readonly" )
OAuth2 scopes used by this API.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ActivitiesListCall ¶
type ActivitiesListCall struct {
// contains filtered or unexported fields
}
func (*ActivitiesListCall) Do ¶
func (c *ActivitiesListCall) Do() (*ListActivitiesResponse, error)
func (*ActivitiesListCall) DriveAncestorId ¶
func (c *ActivitiesListCall) DriveAncestorId(driveAncestorId string) *ActivitiesListCall
DriveAncestorId sets the optional parameter "drive.ancestorId": Identifies the Drive folder containing the items for which to return activities.
func (*ActivitiesListCall) DriveFileId ¶
func (c *ActivitiesListCall) DriveFileId(driveFileId string) *ActivitiesListCall
DriveFileId sets the optional parameter "drive.fileId": Identifies the Drive item to return activities for.
func (*ActivitiesListCall) Fields ¶
func (c *ActivitiesListCall) Fields(s ...googleapi.Field) *ActivitiesListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*ActivitiesListCall) GroupingStrategy ¶
func (c *ActivitiesListCall) GroupingStrategy(groupingStrategy string) *ActivitiesListCall
GroupingStrategy sets the optional parameter "groupingStrategy": Indicates the strategy to use when grouping singleEvents items in the associated combinedEvent object.
Possible values:
"driveUi" (default) "none"
func (*ActivitiesListCall) PageSize ¶
func (c *ActivitiesListCall) PageSize(pageSize int64) *ActivitiesListCall
PageSize sets the optional parameter "pageSize": The maximum number of events to return on a page. The response includes a continuation token if there are more events.
func (*ActivitiesListCall) PageToken ¶
func (c *ActivitiesListCall) PageToken(pageToken string) *ActivitiesListCall
PageToken sets the optional parameter "pageToken": A token to retrieve a specific page of results.
func (*ActivitiesListCall) Source ¶
func (c *ActivitiesListCall) Source(source string) *ActivitiesListCall
Source sets the optional parameter "source": The Google service from which to return activities. Possible values of source are: - drive.google.com
func (*ActivitiesListCall) UserId ¶
func (c *ActivitiesListCall) UserId(userId string) *ActivitiesListCall
UserId sets the optional parameter "userId": Indicates the user to return activity for. Use the special value me to indicate the currently authenticated user.
type ActivitiesService ¶
type ActivitiesService struct {
// contains filtered or unexported fields
}
func NewActivitiesService ¶
func NewActivitiesService(s *Service) *ActivitiesService
func (*ActivitiesService) List ¶
func (r *ActivitiesService) List() *ActivitiesListCall
List: Returns a list of activities visible to the current logged in user. Visible activities are determined by the visiblity settings of the object that was acted on, e.g. Drive files a user can see. An activity is a record of past events. Multiple events may be merged if they are similar. A request is scoped to activities from a given Google service using the source parameter.
type Activity ¶
type Activity struct {
// CombinedEvent: The fields common to all of the singleEvents that make
// up the Activity.
CombinedEvent *Event `json:"combinedEvent,omitempty"`
// SingleEvents: A list of all the Events that make up the Activity.
SingleEvents []*Event `json:"singleEvents,omitempty"`
}
Activity: An Activity resource is a combined view of multiple events. An activity has a list of individual events and a combined view of the common fields among all events.
type Event ¶
type Event struct {
// AdditionalEventTypes: Additional event types. Some events may have
// multiple types when multiple actions are part of a single event. For
// example, creating a document, renaming it, and sharing it may be part
// of a single file-creation event.
//
// Possible values:
// "comment"
// "create"
// "edit"
// "emptyTrash"
// "move"
// "permissionChange"
// "rename"
// "trash"
// "unknown"
// "untrash"
// "upload"
AdditionalEventTypes []string `json:"additionalEventTypes,omitempty"`
// EventTimeMillis: The time at which the event occurred formatted as
// Unix time in milliseconds.
EventTimeMillis uint64 `json:"eventTimeMillis,omitempty,string"`
// FromUserDeletion: Whether this event is caused by a user being
// deleted.
FromUserDeletion bool `json:"fromUserDeletion,omitempty"`
// Move: Extra information for move type events, such as changes in an
// object's parents.
Move *Move `json:"move,omitempty"`
// PermissionChanges: Extra information for permissionChange type
// events, such as the user or group the new permission applies to.
PermissionChanges []*PermissionChange `json:"permissionChanges,omitempty"`
// PrimaryEventType: The main type of event that occurred.
//
// Possible values:
// "comment"
// "create"
// "edit"
// "emptyTrash"
// "move"
// "permissionChange"
// "rename"
// "trash"
// "unknown"
// "untrash"
// "upload"
PrimaryEventType string `json:"primaryEventType,omitempty"`
// Rename: Extra information for rename type events, such as the old and
// new names.
Rename *Rename `json:"rename,omitempty"`
// Target: Information specific to the Target object modified by the
// event.
Target *Target `json:"target,omitempty"`
// User: Represents the user responsible for the event.
User *User `json:"user,omitempty"`
}
Event: Represents the changes associated with an action taken by a user.
type ListActivitiesResponse ¶
type ListActivitiesResponse struct {
// Activities: List of activities.
Activities []*Activity `json:"activities,omitempty"`
// NextPageToken: Token for the next page of results.
NextPageToken string `json:"nextPageToken,omitempty"`
}
ListActivitiesResponse: The response from the list request. Contains a list of activities and a token to retrieve the next page of results.
type Move ¶
type Move struct {
// AddedParents: The added parent(s).
AddedParents []*Parent `json:"addedParents,omitempty"`
// RemovedParents: The removed parent(s).
RemovedParents []*Parent `json:"removedParents,omitempty"`
}
Move: Contains information about changes in an object's parents as a result of a move type event.
type Parent ¶
type Parent struct {
// Id: The parent's ID.
Id string `json:"id,omitempty"`
// IsRoot: Whether this is the root folder.
IsRoot bool `json:"isRoot,omitempty"`
// Title: The parent's title.
Title string `json:"title,omitempty"`
}
Parent: Contains information about a parent object. For example, a folder in Drive is a parent for all files within it.
type Permission ¶
type Permission struct {
// Name: The name of the user or group the permission applies to.
Name string `json:"name,omitempty"`
// PermissionId: The ID for this permission. Corresponds to the Drive
// API's permission ID returned as part of the Drive Permissions
// resource.
PermissionId string `json:"permissionId,omitempty"`
// Role: Indicates the Google Drive permissions role. The role
// determines a user's ability to read, write, or comment on the file.
//
// Possible values:
// "commenter"
// "owner"
// "reader"
// "writer"
Role string `json:"role,omitempty"`
// Type: Indicates how widely permissions are granted.
//
// Possible values:
// "anyone"
// "domain"
// "group"
// "user"
Type string `json:"type,omitempty"`
// User: The user's information if the type is USER.
User *User `json:"user,omitempty"`
// WithLink: Whether the permission requires a link to the file.
WithLink bool `json:"withLink,omitempty"`
}
Permission: Contains information about the permissions and type of access allowed with regards to a Google Drive object. This is a subset of the fields contained in a corresponding Drive Permissions object.
type PermissionChange ¶
type PermissionChange struct {
// AddedPermissions: Lists all Permission objects added.
AddedPermissions []*Permission `json:"addedPermissions,omitempty"`
// RemovedPermissions: Lists all Permission objects removed.
RemovedPermissions []*Permission `json:"removedPermissions,omitempty"`
}
PermissionChange: Contains information about a Drive object's permissions that changed as a result of a permissionChange type event.
type Photo ¶
type Photo struct {
// Url: The URL of the photo.
Url string `json:"url,omitempty"`
}
Photo: Photo information for a user.
type Rename ¶
type Rename struct {
// NewTitle: The new title.
NewTitle string `json:"newTitle,omitempty"`
// OldTitle: The old title.
OldTitle string `json:"oldTitle,omitempty"`
}
Rename: Contains information about a renametype event.
type Service ¶
type Service struct {
BasePath string // API endpoint base URL
UserAgent string // optional additional User-Agent fragment
Activities *ActivitiesService
// contains filtered or unexported fields
}
type Target ¶
type Target struct {
// Id: The ID of the target. For example, in Google Drive, this is the
// file or folder ID.
Id string `json:"id,omitempty"`
// MimeType: The MIME type of the target.
MimeType string `json:"mimeType,omitempty"`
// Name: The name of the target. For example, in Google Drive, this is
// the title of the file.
Name string `json:"name,omitempty"`
}
Target: Information about the object modified by the event.