Documentation
¶
Overview ¶
Package customsearch provides access to the CustomSearch API.
See https://developers.google.com/custom-search/v1/using_rest
Usage example:
import "google.golang.org/api/customsearch/v1" ... customsearchService, err := customsearch.New(oauthHttpClient)
Index ¶
- type Context
- type ContextFacetsItem
- type CseListCall
- func (c *CseListCall) C2coff(c2coff string) *CseListCall
- func (c *CseListCall) Cr(cr string) *CseListCall
- func (c *CseListCall) Cref(cref string) *CseListCall
- func (c *CseListCall) Cx(cx string) *CseListCall
- func (c *CseListCall) DateRestrict(dateRestrict string) *CseListCall
- func (c *CseListCall) Do() (*Search, error)
- func (c *CseListCall) ExactTerms(exactTerms string) *CseListCall
- func (c *CseListCall) ExcludeTerms(excludeTerms string) *CseListCall
- func (c *CseListCall) Fields(s ...googleapi.Field) *CseListCall
- func (c *CseListCall) FileType(fileType string) *CseListCall
- func (c *CseListCall) Filter(filter string) *CseListCall
- func (c *CseListCall) Gl(gl string) *CseListCall
- func (c *CseListCall) Googlehost(googlehost string) *CseListCall
- func (c *CseListCall) HighRange(highRange string) *CseListCall
- func (c *CseListCall) Hl(hl string) *CseListCall
- func (c *CseListCall) Hq(hq string) *CseListCall
- func (c *CseListCall) ImgColorType(imgColorType string) *CseListCall
- func (c *CseListCall) ImgDominantColor(imgDominantColor string) *CseListCall
- func (c *CseListCall) ImgSize(imgSize string) *CseListCall
- func (c *CseListCall) ImgType(imgType string) *CseListCall
- func (c *CseListCall) LinkSite(linkSite string) *CseListCall
- func (c *CseListCall) LowRange(lowRange string) *CseListCall
- func (c *CseListCall) Lr(lr string) *CseListCall
- func (c *CseListCall) Num(num int64) *CseListCall
- func (c *CseListCall) OrTerms(orTerms string) *CseListCall
- func (c *CseListCall) RelatedSite(relatedSite string) *CseListCall
- func (c *CseListCall) Rights(rights string) *CseListCall
- func (c *CseListCall) Safe(safe string) *CseListCall
- func (c *CseListCall) SearchType(searchType string) *CseListCall
- func (c *CseListCall) SiteSearch(siteSearch string) *CseListCall
- func (c *CseListCall) SiteSearchFilter(siteSearchFilter string) *CseListCall
- func (c *CseListCall) Sort(sort string) *CseListCall
- func (c *CseListCall) Start(start int64) *CseListCall
- type CseService
- type Promotion
- type PromotionBodyLines
- type PromotionImage
- type Query
- type Result
- type ResultImage
- type ResultLabels
- type ResultPagemap
- type Search
- type SearchSearchInformation
- type SearchSpelling
- type SearchUrl
- type Service
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Context ¶
type Context struct {
Facets [][]*ContextFacetsItem `json:"facets,omitempty"`
Title string `json:"title,omitempty"`
}
type ContextFacetsItem ¶
type CseListCall ¶
type CseListCall struct {
// contains filtered or unexported fields
}
func (*CseListCall) C2coff ¶
func (c *CseListCall) C2coff(c2coff string) *CseListCall
C2coff sets the optional parameter "c2coff": Turns off the translation between zh-CN and zh-TW.
func (*CseListCall) Cr ¶
func (c *CseListCall) Cr(cr string) *CseListCall
Cr sets the optional parameter "cr": Country restrict(s).
func (*CseListCall) Cref ¶
func (c *CseListCall) Cref(cref string) *CseListCall
Cref sets the optional parameter "cref": The URL of a linked custom search engine
func (*CseListCall) Cx ¶
func (c *CseListCall) Cx(cx string) *CseListCall
Cx sets the optional parameter "cx": The custom search engine ID to scope this search query
func (*CseListCall) DateRestrict ¶
func (c *CseListCall) DateRestrict(dateRestrict string) *CseListCall
DateRestrict sets the optional parameter "dateRestrict": Specifies all search results are from a time period
func (*CseListCall) Do ¶
func (c *CseListCall) Do() (*Search, error)
func (*CseListCall) ExactTerms ¶
func (c *CseListCall) ExactTerms(exactTerms string) *CseListCall
ExactTerms sets the optional parameter "exactTerms": Identifies a phrase that all documents in the search results must contain
func (*CseListCall) ExcludeTerms ¶
func (c *CseListCall) ExcludeTerms(excludeTerms string) *CseListCall
ExcludeTerms sets the optional parameter "excludeTerms": Identifies a word or phrase that should not appear in any documents in the search results
func (*CseListCall) Fields ¶
func (c *CseListCall) Fields(s ...googleapi.Field) *CseListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*CseListCall) FileType ¶
func (c *CseListCall) FileType(fileType string) *CseListCall
FileType sets the optional parameter "fileType": Returns images of a specified type. Some of the allowed values are: bmp, gif, png, jpg, svg, pdf, ...
func (*CseListCall) Filter ¶
func (c *CseListCall) Filter(filter string) *CseListCall
Filter sets the optional parameter "filter": Controls turning on or off the duplicate content filter.
Possible values:
"0" - Turns off duplicate content filter. "1" - Turns on duplicate content filter.
func (*CseListCall) Gl ¶
func (c *CseListCall) Gl(gl string) *CseListCall
Gl sets the optional parameter "gl": Geolocation of end user.
func (*CseListCall) Googlehost ¶
func (c *CseListCall) Googlehost(googlehost string) *CseListCall
Googlehost sets the optional parameter "googlehost": The local Google domain to use to perform the search.
func (*CseListCall) HighRange ¶
func (c *CseListCall) HighRange(highRange string) *CseListCall
HighRange sets the optional parameter "highRange": Creates a range in form as_nlo value..as_nhi value and attempts to append it to query
func (*CseListCall) Hl ¶
func (c *CseListCall) Hl(hl string) *CseListCall
Hl sets the optional parameter "hl": Sets the user interface language.
func (*CseListCall) Hq ¶
func (c *CseListCall) Hq(hq string) *CseListCall
Hq sets the optional parameter "hq": Appends the extra query terms to the query.
func (*CseListCall) ImgColorType ¶
func (c *CseListCall) ImgColorType(imgColorType string) *CseListCall
ImgColorType sets the optional parameter "imgColorType": Returns black and white, grayscale, or color images: mono, gray, and color.
Possible values:
"color" - color "gray" - gray "mono" - mono
func (*CseListCall) ImgDominantColor ¶
func (c *CseListCall) ImgDominantColor(imgDominantColor string) *CseListCall
ImgDominantColor sets the optional parameter "imgDominantColor": Returns images of a specific dominant color: yellow, green, teal, blue, purple, pink, white, gray, black and brown.
Possible values:
"black" - black "blue" - blue "brown" - brown "gray" - gray "green" - green "pink" - pink "purple" - purple "teal" - teal "white" - white "yellow" - yellow
func (*CseListCall) ImgSize ¶
func (c *CseListCall) ImgSize(imgSize string) *CseListCall
ImgSize sets the optional parameter "imgSize": Returns images of a specified size, where size can be one of: icon, small, medium, large, xlarge, xxlarge, and huge.
Possible values:
"huge" - huge "icon" - icon "large" - large "medium" - medium "small" - small "xlarge" - xlarge "xxlarge" - xxlarge
func (*CseListCall) ImgType ¶
func (c *CseListCall) ImgType(imgType string) *CseListCall
ImgType sets the optional parameter "imgType": Returns images of a type, which can be one of: clipart, face, lineart, news, and photo.
Possible values:
"clipart" - clipart "face" - face "lineart" - lineart "news" - news "photo" - photo
func (*CseListCall) LinkSite ¶
func (c *CseListCall) LinkSite(linkSite string) *CseListCall
LinkSite sets the optional parameter "linkSite": Specifies that all search results should contain a link to a particular URL
func (*CseListCall) LowRange ¶
func (c *CseListCall) LowRange(lowRange string) *CseListCall
LowRange sets the optional parameter "lowRange": Creates a range in form as_nlo value..as_nhi value and attempts to append it to query
func (*CseListCall) Lr ¶
func (c *CseListCall) Lr(lr string) *CseListCall
Lr sets the optional parameter "lr": The language restriction for the search results
Possible values:
"lang_ar" - Arabic "lang_bg" - Bulgarian "lang_ca" - Catalan "lang_cs" - Czech "lang_da" - Danish "lang_de" - German "lang_el" - Greek "lang_en" - English "lang_es" - Spanish "lang_et" - Estonian "lang_fi" - Finnish "lang_fr" - French "lang_hr" - Croatian "lang_hu" - Hungarian "lang_id" - Indonesian "lang_is" - Icelandic "lang_it" - Italian "lang_iw" - Hebrew "lang_ja" - Japanese "lang_ko" - Korean "lang_lt" - Lithuanian "lang_lv" - Latvian "lang_nl" - Dutch "lang_no" - Norwegian "lang_pl" - Polish "lang_pt" - Portuguese "lang_ro" - Romanian "lang_ru" - Russian "lang_sk" - Slovak "lang_sl" - Slovenian "lang_sr" - Serbian "lang_sv" - Swedish "lang_tr" - Turkish "lang_zh-CN" - Chinese (Simplified) "lang_zh-TW" - Chinese (Traditional)
func (*CseListCall) Num ¶
func (c *CseListCall) Num(num int64) *CseListCall
Num sets the optional parameter "num": Number of search results to return
func (*CseListCall) OrTerms ¶
func (c *CseListCall) OrTerms(orTerms string) *CseListCall
OrTerms sets the optional parameter "orTerms": Provides additional search terms to check for in a document, where each document in the search results must contain at least one of the additional search terms
func (*CseListCall) RelatedSite ¶
func (c *CseListCall) RelatedSite(relatedSite string) *CseListCall
RelatedSite sets the optional parameter "relatedSite": Specifies that all search results should be pages that are related to the specified URL
func (*CseListCall) Rights ¶
func (c *CseListCall) Rights(rights string) *CseListCall
Rights sets the optional parameter "rights": Filters based on licensing. Supported values include: cc_publicdomain, cc_attribute, cc_sharealike, cc_noncommercial, cc_nonderived and combinations of these.
func (*CseListCall) Safe ¶
func (c *CseListCall) Safe(safe string) *CseListCall
Safe sets the optional parameter "safe": Search safety level
Possible values:
"high" - Enables highest level of safe search filtering. "medium" - Enables moderate safe search filtering. "off" (default) - Disables safe search filtering.
func (*CseListCall) SearchType ¶
func (c *CseListCall) SearchType(searchType string) *CseListCall
SearchType sets the optional parameter "searchType": Specifies the search type: image.
Possible values:
"image" - custom image search
func (*CseListCall) SiteSearch ¶
func (c *CseListCall) SiteSearch(siteSearch string) *CseListCall
SiteSearch sets the optional parameter "siteSearch": Specifies all search results should be pages from a given site
func (*CseListCall) SiteSearchFilter ¶
func (c *CseListCall) SiteSearchFilter(siteSearchFilter string) *CseListCall
SiteSearchFilter sets the optional parameter "siteSearchFilter": Controls whether to include or exclude results from the site named in the as_sitesearch parameter
Possible values:
"e" - exclude "i" - include
func (*CseListCall) Sort ¶
func (c *CseListCall) Sort(sort string) *CseListCall
Sort sets the optional parameter "sort": The sort expression to apply to the results
func (*CseListCall) Start ¶
func (c *CseListCall) Start(start int64) *CseListCall
Start sets the optional parameter "start": The index of the first result to return
type CseService ¶
type CseService struct {
// contains filtered or unexported fields
}
func NewCseService ¶
func NewCseService(s *Service) *CseService
func (*CseService) List ¶
func (r *CseService) List(q string) *CseListCall
List: Returns metadata about the search performed, metadata about the custom search engine used for the search, and the search results.
type Promotion ¶
type Promotion struct {
BodyLines []*PromotionBodyLines `json:"bodyLines,omitempty"`
DisplayLink string `json:"displayLink,omitempty"`
HtmlTitle string `json:"htmlTitle,omitempty"`
Image *PromotionImage `json:"image,omitempty"`
Link string `json:"link,omitempty"`
Title string `json:"title,omitempty"`
}
type PromotionBodyLines ¶
type PromotionImage ¶
type Query ¶
type Query struct {
Count int64 `json:"count,omitempty"`
Cr string `json:"cr,omitempty"`
Cref string `json:"cref,omitempty"`
Cx string `json:"cx,omitempty"`
DateRestrict string `json:"dateRestrict,omitempty"`
DisableCnTwTranslation string `json:"disableCnTwTranslation,omitempty"`
ExactTerms string `json:"exactTerms,omitempty"`
ExcludeTerms string `json:"excludeTerms,omitempty"`
FileType string `json:"fileType,omitempty"`
Filter string `json:"filter,omitempty"`
Gl string `json:"gl,omitempty"`
GoogleHost string `json:"googleHost,omitempty"`
HighRange string `json:"highRange,omitempty"`
Hl string `json:"hl,omitempty"`
Hq string `json:"hq,omitempty"`
ImgColorType string `json:"imgColorType,omitempty"`
ImgDominantColor string `json:"imgDominantColor,omitempty"`
ImgSize string `json:"imgSize,omitempty"`
ImgType string `json:"imgType,omitempty"`
InputEncoding string `json:"inputEncoding,omitempty"`
Language string `json:"language,omitempty"`
LinkSite string `json:"linkSite,omitempty"`
LowRange string `json:"lowRange,omitempty"`
OrTerms string `json:"orTerms,omitempty"`
OutputEncoding string `json:"outputEncoding,omitempty"`
RelatedSite string `json:"relatedSite,omitempty"`
Rights string `json:"rights,omitempty"`
Safe string `json:"safe,omitempty"`
SearchTerms string `json:"searchTerms,omitempty"`
SearchType string `json:"searchType,omitempty"`
SiteSearch string `json:"siteSearch,omitempty"`
SiteSearchFilter string `json:"siteSearchFilter,omitempty"`
Sort string `json:"sort,omitempty"`
StartIndex int64 `json:"startIndex,omitempty"`
StartPage int64 `json:"startPage,omitempty"`
Title string `json:"title,omitempty"`
TotalResults int64 `json:"totalResults,omitempty,string"`
}
type Result ¶
type Result struct {
CacheId string `json:"cacheId,omitempty"`
DisplayLink string `json:"displayLink,omitempty"`
FileFormat string `json:"fileFormat,omitempty"`
FormattedUrl string `json:"formattedUrl,omitempty"`
HtmlFormattedUrl string `json:"htmlFormattedUrl,omitempty"`
HtmlSnippet string `json:"htmlSnippet,omitempty"`
HtmlTitle string `json:"htmlTitle,omitempty"`
Image *ResultImage `json:"image,omitempty"`
Kind string `json:"kind,omitempty"`
Labels []*ResultLabels `json:"labels,omitempty"`
Link string `json:"link,omitempty"`
Mime string `json:"mime,omitempty"`
Pagemap *ResultPagemap `json:"pagemap,omitempty"`
Snippet string `json:"snippet,omitempty"`
Title string `json:"title,omitempty"`
}
type ResultImage ¶
type ResultImage struct {
ByteSize int64 `json:"byteSize,omitempty"`
ContextLink string `json:"contextLink,omitempty"`
Height int64 `json:"height,omitempty"`
ThumbnailHeight int64 `json:"thumbnailHeight,omitempty"`
ThumbnailLink string `json:"thumbnailLink,omitempty"`
ThumbnailWidth int64 `json:"thumbnailWidth,omitempty"`
Width int64 `json:"width,omitempty"`
}
type ResultLabels ¶
type ResultPagemap ¶
type ResultPagemap struct {
}
type Search ¶
type Search struct {
Context *Context `json:"context,omitempty"`
Items []*Result `json:"items,omitempty"`
Kind string `json:"kind,omitempty"`
Promotions []*Promotion `json:"promotions,omitempty"`
Queries map[string][]Query `json:"queries,omitempty"`
SearchInformation *SearchSearchInformation `json:"searchInformation,omitempty"`
Spelling *SearchSpelling `json:"spelling,omitempty"`
Url *SearchUrl `json:"url,omitempty"`
}