Documentation
¶
Overview ¶
Package dfareporting provides access to the DFA Reporting API.
See https://developers.google.com/doubleclick-advertisers/reporting/
Usage example:
import "google.golang.org/api/dfareporting/v1.3" ... dfareportingService, err := dfareporting.New(oauthHttpClient)
Index ¶
- Constants
- type Activities
- type CompatibleFields
- type CrossDimensionReachReportCompatibleFields
- type CustomRichMediaEvents
- type DateRange
- type Dimension
- type DimensionFilter
- type DimensionValue
- type DimensionValueList
- type DimensionValueRequest
- type DimensionValuesQueryCall
- func (c *DimensionValuesQueryCall) Do() (*DimensionValueList, error)
- func (c *DimensionValuesQueryCall) Fields(s ...googleapi.Field) *DimensionValuesQueryCall
- func (c *DimensionValuesQueryCall) MaxResults(maxResults int64) *DimensionValuesQueryCall
- func (c *DimensionValuesQueryCall) PageToken(pageToken string) *DimensionValuesQueryCall
- type DimensionValuesService
- type File
- type FileList
- type FileUrls
- type FilesGetCall
- type FilesListCall
- func (c *FilesListCall) Do() (*FileList, error)
- func (c *FilesListCall) Fields(s ...googleapi.Field) *FilesListCall
- func (c *FilesListCall) MaxResults(maxResults int64) *FilesListCall
- func (c *FilesListCall) PageToken(pageToken string) *FilesListCall
- func (c *FilesListCall) Scope(scope string) *FilesListCall
- func (c *FilesListCall) SortField(sortField string) *FilesListCall
- func (c *FilesListCall) SortOrder(sortOrder string) *FilesListCall
- type FilesService
- type FloodlightReportCompatibleFields
- type Metric
- type PathToConversionReportCompatibleFields
- type ReachReportCompatibleFields
- type Recipient
- type Report
- type ReportActiveGrpCriteria
- type ReportCompatibleFields
- type ReportCriteria
- type ReportCrossDimensionReachCriteria
- type ReportDelivery
- type ReportFloodlightCriteria
- type ReportFloodlightCriteriaReportProperties
- type ReportList
- type ReportPathToConversionCriteria
- type ReportPathToConversionCriteriaReportProperties
- type ReportReachCriteria
- type ReportSchedule
- type ReportsCompatibleFieldsQueryCall
- type ReportsCompatibleFieldsService
- type ReportsDeleteCall
- type ReportsFilesGetCall
- type ReportsFilesListCall
- func (c *ReportsFilesListCall) Do() (*FileList, error)
- func (c *ReportsFilesListCall) Fields(s ...googleapi.Field) *ReportsFilesListCall
- func (c *ReportsFilesListCall) MaxResults(maxResults int64) *ReportsFilesListCall
- func (c *ReportsFilesListCall) PageToken(pageToken string) *ReportsFilesListCall
- func (c *ReportsFilesListCall) SortField(sortField string) *ReportsFilesListCall
- func (c *ReportsFilesListCall) SortOrder(sortOrder string) *ReportsFilesListCall
- type ReportsFilesService
- type ReportsGetCall
- type ReportsInsertCall
- type ReportsListCall
- func (c *ReportsListCall) Do() (*ReportList, error)
- func (c *ReportsListCall) Fields(s ...googleapi.Field) *ReportsListCall
- func (c *ReportsListCall) MaxResults(maxResults int64) *ReportsListCall
- func (c *ReportsListCall) PageToken(pageToken string) *ReportsListCall
- func (c *ReportsListCall) Scope(scope string) *ReportsListCall
- func (c *ReportsListCall) SortField(sortField string) *ReportsListCall
- func (c *ReportsListCall) SortOrder(sortOrder string) *ReportsListCall
- type ReportsPatchCall
- type ReportsRunCall
- type ReportsService
- func (r *ReportsService) Delete(profileId int64, reportId int64) *ReportsDeleteCall
- func (r *ReportsService) Get(profileId int64, reportId int64) *ReportsGetCall
- func (r *ReportsService) Insert(profileId int64, report *Report) *ReportsInsertCall
- func (r *ReportsService) List(profileId int64) *ReportsListCall
- func (r *ReportsService) Patch(profileId int64, reportId int64, report *Report) *ReportsPatchCall
- func (r *ReportsService) Run(profileId int64, reportId int64) *ReportsRunCall
- func (r *ReportsService) Update(profileId int64, reportId int64, report *Report) *ReportsUpdateCall
- type ReportsUpdateCall
- type Service
- type SortedDimension
- type UserProfile
- type UserProfileList
- type UserProfilesGetCall
- type UserProfilesListCall
- type UserProfilesService
Constants ¶
const (
// View and manage DoubleClick for Advertisers reports
DfareportingScope = "https://www.googleapis.com/auth/dfareporting"
)
OAuth2 scopes used by this API.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Activities ¶
type Activities struct {
// Filters: List of activity filters. The dimension values need to be
// all either of type "dfa:activity" or "dfa:activityGroup".
Filters []*DimensionValue `json:"filters,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#activities.
Kind string `json:"kind,omitempty"`
// MetricNames: List of names of floodlight activity metrics.
MetricNames []string `json:"metricNames,omitempty"`
}
Activities: Represents an activity group.
type CompatibleFields ¶
type CompatibleFields struct {
// CrossDimensionReachReportCompatibleFields: Contains items that are
// compatible to be selected for a report of type
// "CROSS_DIMENSION_REACH".
CrossDimensionReachReportCompatibleFields *CrossDimensionReachReportCompatibleFields `json:"crossDimensionReachReportCompatibleFields,omitempty"`
// FloodlightReportCompatibleFields: Contains items that are compatible
// to be selected for a report of type "FLOODLIGHT".
FloodlightReportCompatibleFields *FloodlightReportCompatibleFields `json:"floodlightReportCompatibleFields,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#compatibleFields.
Kind string `json:"kind,omitempty"`
// PathToConversionReportCompatibleFields: Contains items that are
// compatible to be selected for a report of type "PATH_TO_CONVERSION".
PathToConversionReportCompatibleFields *PathToConversionReportCompatibleFields `json:"pathToConversionReportCompatibleFields,omitempty"`
// ReachReportCompatibleFields: Contains items that are compatible to be
// selected for a report of type "REACH".
ReachReportCompatibleFields *ReachReportCompatibleFields `json:"reachReportCompatibleFields,omitempty"`
// ReportCompatibleFields: Contains items that are compatible to be
// selected for a report of type "STANDARD".
ReportCompatibleFields *ReportCompatibleFields `json:"reportCompatibleFields,omitempty"`
}
CompatibleFields: Represents a response to the queryCompatibleFields method.
type CrossDimensionReachReportCompatibleFields ¶
type CrossDimensionReachReportCompatibleFields struct {
// Breakdown: Dimensions which are compatible to be selected in the
// "breakdown" section of the report.
Breakdown []*Dimension `json:"breakdown,omitempty"`
// DimensionFilters: Dimensions which are compatible to be selected in
// the "dimensionFilters" section of the report.
DimensionFilters []*Dimension `json:"dimensionFilters,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#crossDimensionReachReportCompatibleFields.
Kind string `json:"kind,omitempty"`
// Metrics: Metrics which are compatible to be selected in the
// "metricNames" section of the report.
Metrics []*Metric `json:"metrics,omitempty"`
// OverlapMetrics: Metrics which are compatible to be selected in the
// "overlapMetricNames" section of the report.
OverlapMetrics []*Metric `json:"overlapMetrics,omitempty"`
}
CrossDimensionReachReportCompatibleFields: Represents fields that are compatible to be selected for a report of type "CROSS_DIMENSION_REACH".
type CustomRichMediaEvents ¶
type CustomRichMediaEvents struct {
// FilteredEventIds: List of custom rich media event IDs. Dimension
// values must be all of type dfa:richMediaEventTypeIdAndName.
FilteredEventIds []*DimensionValue `json:"filteredEventIds,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#customRichMediaEvents.
Kind string `json:"kind,omitempty"`
}
CustomRichMediaEvents: Represents a Custom Rich Media Events group.
type DateRange ¶
type DateRange struct {
// EndDate: The end date of the date range, inclusive. A string of the
// format: "yyyy-MM-dd".
EndDate string `json:"endDate,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#dateRange.
Kind string `json:"kind,omitempty"`
// RelativeDateRange: The date range relative to the date of when the
// report is run, one of:
// - "TODAY"
// - "YESTERDAY"
// - "WEEK_TO_DATE"
// - "MONTH_TO_DATE"
// - "QUARTER_TO_DATE"
// - "YEAR_TO_DATE"
// - "PREVIOUS_WEEK"
// - "PREVIOUS_MONTH"
// - "PREVIOUS_QUARTER"
// - "PREVIOUS_YEAR"
// - "LAST_7_DAYS"
// - "LAST_30_DAYS"
// - "LAST_90_DAYS"
// - "LAST_365_DAYS"
// - "LAST_24_MONTHS"
RelativeDateRange string `json:"relativeDateRange,omitempty"`
// StartDate: The start date of the date range, inclusive. A string of
// the format: "yyyy-MM-dd".
StartDate string `json:"startDate,omitempty"`
}
DateRange: Represents a date range.
type Dimension ¶
type Dimension struct {
// Kind: The kind of resource this is, in this case
// dfareporting#dimension.
Kind string `json:"kind,omitempty"`
// Name: The dimension name, e.g. dfa:advertiser
Name string `json:"name,omitempty"`
}
Dimension: Represents a dimension.
type DimensionFilter ¶
type DimensionFilter struct {
// DimensionName: The name of the dimension to filter.
DimensionName string `json:"dimensionName,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#dimensionFilter.
Kind string `json:"kind,omitempty"`
// Value: The value of the dimension to filter.
Value string `json:"value,omitempty"`
}
DimensionFilter: Represents a dimension filter.
type DimensionValue ¶
type DimensionValue struct {
// DimensionName: The name of the dimension.
DimensionName string `json:"dimensionName,omitempty"`
// Etag: The eTag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Id: The ID associated with the value if available.
Id string `json:"id,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#dimensionValue.
Kind string `json:"kind,omitempty"`
// MatchType: Determines how the 'value' field is matched when
// filtering. One of:
// - EXACT (default if not specified)
// - CONTAINS
// - BEGINS_WITH
// - WILDCARD_EXPRESSION (allowing '*' as a placeholder for variable
// length character sequences, it can be escaped with a backslash.)
// Note, only paid search dimensions ('dfa:paidSearch*') allow a
// matchType other than EXACT.
MatchType string `json:"matchType,omitempty"`
// Value: The value of the dimension.
Value string `json:"value,omitempty"`
}
DimensionValue: Represents a DimensionValue resource.
type DimensionValueList ¶
type DimensionValueList struct {
// Etag: The eTag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The dimension values returned in this response.
Items []*DimensionValue `json:"items,omitempty"`
// Kind: The kind of list this is, in this case
// dfareporting#dimensionValueList.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through dimension
// values. To retrieve the next page of results, set the next request's
// "pageToken" to the value of this field. The page token is only valid
// for a limited amount of time and should not be persisted.
NextPageToken string `json:"nextPageToken,omitempty"`
}
DimensionValueList: Represents the list of DimensionValue resources.
type DimensionValueRequest ¶
type DimensionValueRequest struct {
// DimensionName: The name of the dimension for which values should be
// requested.
DimensionName string `json:"dimensionName,omitempty"`
// EndDate: The end date of the date range for which to retrieve
// dimension values. A string of the format: "yyyy-MM-dd".
EndDate string `json:"endDate,omitempty"`
// Filters: The list of filters by which to filter values. The filters
// are ANDed.
Filters []*DimensionFilter `json:"filters,omitempty"`
// Kind: The kind of request this is, in this case
// dfareporting#dimensionValueRequest.
Kind string `json:"kind,omitempty"`
// StartDate: The start date of the date range for which to retrieve
// dimension values. A string of the format: "yyyy-MM-dd".
StartDate string `json:"startDate,omitempty"`
}
DimensionValueRequest: Represents a DimensionValuesRequest.
type DimensionValuesQueryCall ¶
type DimensionValuesQueryCall struct {
// contains filtered or unexported fields
}
func (*DimensionValuesQueryCall) Do ¶
func (c *DimensionValuesQueryCall) Do() (*DimensionValueList, error)
func (*DimensionValuesQueryCall) Fields ¶
func (c *DimensionValuesQueryCall) Fields(s ...googleapi.Field) *DimensionValuesQueryCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*DimensionValuesQueryCall) MaxResults ¶
func (c *DimensionValuesQueryCall) MaxResults(maxResults int64) *DimensionValuesQueryCall
MaxResults sets the optional parameter "maxResults": Maximum number of results to return.
func (*DimensionValuesQueryCall) PageToken ¶
func (c *DimensionValuesQueryCall) PageToken(pageToken string) *DimensionValuesQueryCall
PageToken sets the optional parameter "pageToken": The value of the nextToken from the previous result page.
type DimensionValuesService ¶
type DimensionValuesService struct {
// contains filtered or unexported fields
}
func NewDimensionValuesService ¶
func NewDimensionValuesService(s *Service) *DimensionValuesService
func (*DimensionValuesService) Query ¶
func (r *DimensionValuesService) Query(profileId int64, dimensionvaluerequest *DimensionValueRequest) *DimensionValuesQueryCall
Query: Retrieves list of report dimension values for a list of filters.
type File ¶
type File struct {
// DateRange: The date range for which the file has report data. The
// date range will always be the absolute date range for which the
// report is run.
DateRange *DateRange `json:"dateRange,omitempty"`
// Etag: The eTag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// FileName: The file name of the file.
FileName string `json:"fileName,omitempty"`
// Format: The output format of the report. Only available once the file
// is available.
Format string `json:"format,omitempty"`
// Id: The unique ID of this report file.
Id int64 `json:"id,omitempty,string"`
// Kind: The kind of resource this is, in this case dfareporting#file.
Kind string `json:"kind,omitempty"`
// LastModifiedTime: The timestamp in milliseconds since epoch when this
// file was last modified.
LastModifiedTime int64 `json:"lastModifiedTime,omitempty,string"`
// ReportId: The ID of the report this file was generated from.
ReportId int64 `json:"reportId,omitempty,string"`
// Status: The status of the report file, one of:
// - "PROCESSING"
// - "REPORT_AVAILABLE"
// - "FAILED"
// - "CANCELLED"
Status string `json:"status,omitempty"`
// Urls: The urls where the completed report file can be downloaded.
Urls *FileUrls `json:"urls,omitempty"`
}
File: Represents a File resource. A File contains the meta-data for a report run. It shows the status of the run and holds the urls to the generated report data if the run is finished and the status is "REPORT_AVAILABLE".
type FileList ¶
type FileList struct {
// Etag: The eTag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The files returned in this response.
Items []*File `json:"items,omitempty"`
// Kind: The kind of list this is, in this case dfareporting#fileList.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through files. To
// retrieve the next page of results, set the next request's "pageToken"
// to the value of this field. The page token is only valid for a
// limited amount of time and should not be persisted.
NextPageToken string `json:"nextPageToken,omitempty"`
}
FileList: Represents the list of File resources.
type FileUrls ¶
type FileUrls struct {
// ApiUrl: The url for downloading the report data through the API.
ApiUrl string `json:"apiUrl,omitempty"`
// BrowserUrl: The url for downloading the report data through a
// browser.
BrowserUrl string `json:"browserUrl,omitempty"`
}
FileUrls: The urls where the completed report file can be downloaded.
type FilesGetCall ¶
type FilesGetCall struct {
// contains filtered or unexported fields
}
func (*FilesGetCall) Do ¶
func (c *FilesGetCall) Do() (*File, error)
func (*FilesGetCall) Download ¶
func (c *FilesGetCall) Download() (*http.Response, error)
Download fetches the API endpoint's "media" value, instead of the normal API response value. If the returned error is nil, the Response is guaranteed to have a 2xx status code. Callers must close the Response.Body as usual.
func (*FilesGetCall) Fields ¶
func (c *FilesGetCall) Fields(s ...googleapi.Field) *FilesGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type FilesListCall ¶
type FilesListCall struct {
// contains filtered or unexported fields
}
func (*FilesListCall) Do ¶
func (c *FilesListCall) Do() (*FileList, error)
func (*FilesListCall) Fields ¶
func (c *FilesListCall) Fields(s ...googleapi.Field) *FilesListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*FilesListCall) MaxResults ¶
func (c *FilesListCall) MaxResults(maxResults int64) *FilesListCall
MaxResults sets the optional parameter "maxResults": Maximum number of results to return.
func (*FilesListCall) PageToken ¶
func (c *FilesListCall) PageToken(pageToken string) *FilesListCall
PageToken sets the optional parameter "pageToken": The value of the nextToken from the previous result page.
func (*FilesListCall) Scope ¶
func (c *FilesListCall) Scope(scope string) *FilesListCall
Scope sets the optional parameter "scope": The scope that defines which results are returned, default is 'MINE'.
Possible values:
"ALL" - All files in account. "MINE" (default) - My files. "SHARED_WITH_ME" - Files shared with me.
func (*FilesListCall) SortField ¶
func (c *FilesListCall) SortField(sortField string) *FilesListCall
SortField sets the optional parameter "sortField": The field by which to sort the list.
Possible values:
"ID" - Sort by file ID. "LAST_MODIFIED_TIME" (default) - Sort by 'lastmodifiedAt' field.
func (*FilesListCall) SortOrder ¶
func (c *FilesListCall) SortOrder(sortOrder string) *FilesListCall
SortOrder sets the optional parameter "sortOrder": Order of sorted results, default is 'DESCENDING'.
Possible values:
"ASCENDING" - Ascending order. "DESCENDING" (default) - Descending order.
type FilesService ¶
type FilesService struct {
// contains filtered or unexported fields
}
func NewFilesService ¶
func NewFilesService(s *Service) *FilesService
func (*FilesService) Get ¶
func (r *FilesService) Get(reportId int64, fileId int64) *FilesGetCall
Get: Retrieves a report file by its report ID and file ID.
func (*FilesService) List ¶
func (r *FilesService) List(profileId int64) *FilesListCall
List: Lists files for a user profile.
type FloodlightReportCompatibleFields ¶
type FloodlightReportCompatibleFields struct {
// DimensionFilters: Dimensions which are compatible to be selected in
// the "dimensionFilters" section of the report.
DimensionFilters []*Dimension `json:"dimensionFilters,omitempty"`
// Dimensions: Dimensions which are compatible to be selected in the
// "dimensions" section of the report.
Dimensions []*Dimension `json:"dimensions,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#floodlightReportCompatibleFields.
Kind string `json:"kind,omitempty"`
// Metrics: Metrics which are compatible to be selected in the
// "metricNames" section of the report.
Metrics []*Metric `json:"metrics,omitempty"`
}
FloodlightReportCompatibleFields: Represents fields that are compatible to be selected for a report of type "FlOODLIGHT".
type Metric ¶
type Metric struct {
// Kind: The kind of resource this is, in this case dfareporting#metric.
Kind string `json:"kind,omitempty"`
// Name: The metric name, e.g. dfa:impressions
Name string `json:"name,omitempty"`
}
Metric: Represents a metric.
type PathToConversionReportCompatibleFields ¶
type PathToConversionReportCompatibleFields struct {
// ConversionDimensions: Conversion dimensions which are compatible to
// be selected in the "conversionDimensions" section of the report.
ConversionDimensions []*Dimension `json:"conversionDimensions,omitempty"`
// CustomFloodlightVariables: Custom floodlight variables which are
// compatible to be selected in the "customFloodlightVariables" section
// of the report.
CustomFloodlightVariables []*Dimension `json:"customFloodlightVariables,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#pathToConversionReportCompatibleFields.
Kind string `json:"kind,omitempty"`
// Metrics: Metrics which are compatible to be selected in the
// "metricNames" section of the report.
Metrics []*Metric `json:"metrics,omitempty"`
// PerInteractionDimensions: Per-interaction dimensions which are
// compatible to be selected in the "perInteractionDimensions" section
// of the report.
PerInteractionDimensions []*Dimension `json:"perInteractionDimensions,omitempty"`
}
PathToConversionReportCompatibleFields: Represents fields that are compatible to be selected for a report of type "PATH_TO_CONVERSION".
type ReachReportCompatibleFields ¶
type ReachReportCompatibleFields struct {
// DimensionFilters: Dimensions which are compatible to be selected in
// the "dimensionFilters" section of the report.
DimensionFilters []*Dimension `json:"dimensionFilters,omitempty"`
// Dimensions: Dimensions which are compatible to be selected in the
// "dimensions" section of the report.
Dimensions []*Dimension `json:"dimensions,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#reachReportCompatibleFields.
Kind string `json:"kind,omitempty"`
// Metrics: Metrics which are compatible to be selected in the
// "metricNames" section of the report.
Metrics []*Metric `json:"metrics,omitempty"`
// PivotedActivityMetrics: Metrics which are compatible to be selected
// as activity metrics to pivot on in the "activities" section of the
// report.
PivotedActivityMetrics []*Metric `json:"pivotedActivityMetrics,omitempty"`
// ReachByFrequencyMetrics: Metrics which are compatible to be selected
// in the "reachByFrequencyMetricNames" section of the report.
ReachByFrequencyMetrics []*Metric `json:"reachByFrequencyMetrics,omitempty"`
}
ReachReportCompatibleFields: Represents fields that are compatible to be selected for a report of type "REACH".
type Recipient ¶
type Recipient struct {
// DeliveryType: The delivery type for the recipient, one of:
// - "ATTACHMENT"
// - "LINK"
DeliveryType string `json:"deliveryType,omitempty"`
// Email: The email address of the recipient.
Email string `json:"email,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#recipient.
Kind string `json:"kind,omitempty"`
}
Recipient: Represents a recipient.
type Report ¶
type Report struct {
// AccountId: The account ID to which this report belongs.
AccountId int64 `json:"accountId,omitempty,string"`
// ActiveGrpCriteria: The report criteria for a report of type
// "ACTIVE_GRP".
ActiveGrpCriteria *ReportActiveGrpCriteria `json:"activeGrpCriteria,omitempty"`
// Criteria: The report criteria for a report of type "STANDARD".
Criteria *ReportCriteria `json:"criteria,omitempty"`
// CrossDimensionReachCriteria: The report criteria for a report of type
// "CROSS_DIMENSION_REACH".
CrossDimensionReachCriteria *ReportCrossDimensionReachCriteria `json:"crossDimensionReachCriteria,omitempty"`
// Delivery: The report's email delivery settings.
Delivery *ReportDelivery `json:"delivery,omitempty"`
// Etag: The eTag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// FileName: The file name used when generating report files for this
// report.
FileName string `json:"fileName,omitempty"`
// FloodlightCriteria: The report criteria for a report of type
// "FLOODLIGHT".
FloodlightCriteria *ReportFloodlightCriteria `json:"floodlightCriteria,omitempty"`
// Format: The output format of the report, one of:
// - "CSV"
// - "EXCEL" If not specified, default format is "CSV". Note that the
// actual format in the completed report file might differ if for
// instance the report's size exceeds the format's capabilities. "CSV"
// will then be the fallback format.
Format string `json:"format,omitempty"`
// Id: The unique ID identifying this report resource.
Id int64 `json:"id,omitempty,string"`
// Kind: The kind of resource this is, in this case dfareporting#report.
Kind string `json:"kind,omitempty"`
// LastModifiedTime: The timestamp (in milliseconds since epoch) of when
// this report was last modified.
LastModifiedTime uint64 `json:"lastModifiedTime,omitempty,string"`
// Name: The name of the report.
Name string `json:"name,omitempty"`
// OwnerProfileId: The user profile id of the owner of this report.
OwnerProfileId int64 `json:"ownerProfileId,omitempty,string"`
// PathToConversionCriteria: The report criteria for a report of type
// "PATH_TO_CONVERSION".
PathToConversionCriteria *ReportPathToConversionCriteria `json:"pathToConversionCriteria,omitempty"`
// ReachCriteria: The report criteria for a report of type "REACH".
ReachCriteria *ReportReachCriteria `json:"reachCriteria,omitempty"`
// Schedule: The report's schedule. Can only be set if the report's
// 'dateRange' is a relative date range and the relative date range is
// not "TODAY".
Schedule *ReportSchedule `json:"schedule,omitempty"`
// SubAccountId: The subbaccount ID to which this report belongs if
// applicable.
SubAccountId int64 `json:"subAccountId,omitempty,string"`
// Type: The type of the report, one of:
// - STANDARD
// - REACH
// - ACTIVE_GRP
// - PATH_TO_CONVERSION
// - FLOODLIGHT
// - CROSS_DIMENSION_REACH
Type string `json:"type,omitempty"`
}
Report: Represents a Report resource.
type ReportActiveGrpCriteria ¶
type ReportActiveGrpCriteria struct {
// DateRange: The date range this report should be run for.
DateRange *DateRange `json:"dateRange,omitempty"`
// DimensionFilters: The list of filters on which dimensions are
// filtered.
// Filters for different dimensions are ANDed, filters for the same
// dimension are grouped together and ORed.
// A valid active GRP report needs to have exactly one DimensionValue
// for the United States in addition to any advertiser or campaign
// dimension values.
DimensionFilters []*DimensionValue `json:"dimensionFilters,omitempty"`
// Dimensions: The list of dimensions the report should include.
Dimensions []*SortedDimension `json:"dimensions,omitempty"`
// MetricNames: The list of names of metrics the report should include.
MetricNames []string `json:"metricNames,omitempty"`
}
ReportActiveGrpCriteria: The report criteria for a report of type "ACTIVE_GRP".
type ReportCompatibleFields ¶
type ReportCompatibleFields struct {
// DimensionFilters: Dimensions which are compatible to be selected in
// the "dimensionFilters" section of the report.
DimensionFilters []*Dimension `json:"dimensionFilters,omitempty"`
// Dimensions: Dimensions which are compatible to be selected in the
// "dimensions" section of the report.
Dimensions []*Dimension `json:"dimensions,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#reportCompatibleFields.
Kind string `json:"kind,omitempty"`
// Metrics: Metrics which are compatible to be selected in the
// "metricNames" section of the report.
Metrics []*Metric `json:"metrics,omitempty"`
// PivotedActivityMetrics: Metrics which are compatible to be selected
// as activity metrics to pivot on in the "activities" section of the
// report.
PivotedActivityMetrics []*Metric `json:"pivotedActivityMetrics,omitempty"`
}
ReportCompatibleFields: Represents fields that are compatible to be selected for a report of type "STANDARD".
type ReportCriteria ¶
type ReportCriteria struct {
// Activities: Activity group.
Activities *Activities `json:"activities,omitempty"`
// CustomRichMediaEvents: Custom Rich Media Events group.
CustomRichMediaEvents *CustomRichMediaEvents `json:"customRichMediaEvents,omitempty"`
// DateRange: The date range for which this report should be run.
DateRange *DateRange `json:"dateRange,omitempty"`
// DimensionFilters: The list of filters on which dimensions are
// filtered.
// Filters for different dimensions are ANDed, filters for the same
// dimension are grouped together and ORed.
DimensionFilters []*DimensionValue `json:"dimensionFilters,omitempty"`
// Dimensions: The list of standard dimensions the report should
// include.
Dimensions []*SortedDimension `json:"dimensions,omitempty"`
// MetricNames: The list of names of metrics the report should include.
MetricNames []string `json:"metricNames,omitempty"`
}
ReportCriteria: The report criteria for a report of type "STANDARD".
type ReportCrossDimensionReachCriteria ¶
type ReportCrossDimensionReachCriteria struct {
// Breakdown: The list of dimensions the report should include.
Breakdown []*SortedDimension `json:"breakdown,omitempty"`
// DateRange: The date range this report should be run for.
DateRange *DateRange `json:"dateRange,omitempty"`
// Dimension: The dimension option, one of:
// - "ADVERTISER"
// - "CAMPAIGN"
// - "SITE_BY_ADVERTISER"
// - "SITE_BY_CAMPAIGN"
Dimension string `json:"dimension,omitempty"`
// DimensionFilters: The list of filters on which dimensions are
// filtered.
DimensionFilters []*DimensionValue `json:"dimensionFilters,omitempty"`
// MetricNames: The list of names of metrics the report should include.
MetricNames []string `json:"metricNames,omitempty"`
// OverlapMetricNames: The list of names of overlap metrics the report
// should include.
OverlapMetricNames []string `json:"overlapMetricNames,omitempty"`
// Pivoted: Whether the report is pivoted or not. Defaults to true.
Pivoted bool `json:"pivoted,omitempty"`
}
ReportCrossDimensionReachCriteria: The report criteria for a report of type "CROSS_DIMENSION_REACH".
type ReportDelivery ¶
type ReportDelivery struct {
// EmailOwner: Whether the report should be emailed to the report owner.
EmailOwner bool `json:"emailOwner,omitempty"`
// EmailOwnerDeliveryType: The type of delivery for the owner to
// receive, if enabled. One of:
// - "ATTACHMENT"
// - "LINK"
EmailOwnerDeliveryType string `json:"emailOwnerDeliveryType,omitempty"`
// Message: The message to be sent with each email.
Message string `json:"message,omitempty"`
// Recipients: The list of recipients to which to email the report.
Recipients []*Recipient `json:"recipients,omitempty"`
}
ReportDelivery: The report's email delivery settings.
type ReportFloodlightCriteria ¶
type ReportFloodlightCriteria struct {
// CustomRichMediaEvents: The list of custom rich media events to
// include.
CustomRichMediaEvents []*DimensionValue `json:"customRichMediaEvents,omitempty"`
// DateRange: The date range this report should be run for.
DateRange *DateRange `json:"dateRange,omitempty"`
// DimensionFilters: The list of filters on which dimensions are
// filtered.
// Filters for different dimensions are ANDed, filters for the same
// dimension are grouped together and ORed.
DimensionFilters []*DimensionValue `json:"dimensionFilters,omitempty"`
// Dimensions: The list of dimensions the report should include.
Dimensions []*SortedDimension `json:"dimensions,omitempty"`
// FloodlightConfigId: The floodlight ID for which to show data in this
// report. All advertisers associated with that ID will automatically be
// added. The dimension of the value needs to be
// 'dfa:floodlightConfigId'.
FloodlightConfigId *DimensionValue `json:"floodlightConfigId,omitempty"`
// MetricNames: The list of names of metrics the report should include.
MetricNames []string `json:"metricNames,omitempty"`
// ReportProperties: The properties of the report.
ReportProperties *ReportFloodlightCriteriaReportProperties `json:"reportProperties,omitempty"`
}
ReportFloodlightCriteria: The report criteria for a report of type "FLOODLIGHT".
type ReportFloodlightCriteriaReportProperties ¶
type ReportFloodlightCriteriaReportProperties struct {
// IncludeAttributedIPConversions: Include conversions that have no
// cookie, but do have an exposure path.
IncludeAttributedIPConversions bool `json:"includeAttributedIPConversions,omitempty"`
// IncludeUnattributedCookieConversions: Include conversions of users
// with a DoubleClick cookie but without an exposure. That means the
// user did not click or see an ad from the advertiser within the
// Floodlight group, or that the interaction happened outside the
// lookback window.
IncludeUnattributedCookieConversions bool `json:"includeUnattributedCookieConversions,omitempty"`
// IncludeUnattributedIPConversions: Include conversions that have no
// associated cookies and no exposures. It’s therefore impossible to
// know how the user was exposed to your ads during the lookback window
// prior to a conversion.
IncludeUnattributedIPConversions bool `json:"includeUnattributedIPConversions,omitempty"`
}
ReportFloodlightCriteriaReportProperties: The properties of the report.
type ReportList ¶
type ReportList struct {
// Etag: The eTag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The reports returned in this response.
Items []*Report `json:"items,omitempty"`
// Kind: The kind of list this is, in this case dfareporting#reportList.
Kind string `json:"kind,omitempty"`
// NextPageToken: Continuation token used to page through reports. To
// retrieve the next page of results, set the next request's "pageToken"
// to the value of this field. The page token is only valid for a
// limited amount of time and should not be persisted.
NextPageToken string `json:"nextPageToken,omitempty"`
}
ReportList: Represents the list of reports.
type ReportPathToConversionCriteria ¶
type ReportPathToConversionCriteria struct {
// ActivityFilters: The list of 'dfa:activity' values to filter on.
ActivityFilters []*DimensionValue `json:"activityFilters,omitempty"`
// ConversionDimensions: The list of conversion dimensions the report
// should include.
ConversionDimensions []*SortedDimension `json:"conversionDimensions,omitempty"`
// CustomFloodlightVariables: The list of custom floodlight variables
// the report should include.
CustomFloodlightVariables []*SortedDimension `json:"customFloodlightVariables,omitempty"`
// CustomRichMediaEvents: The list of custom rich media events to
// include.
CustomRichMediaEvents []*DimensionValue `json:"customRichMediaEvents,omitempty"`
// DateRange: The date range this report should be run for.
DateRange *DateRange `json:"dateRange,omitempty"`
// FloodlightConfigId: The floodlight ID for which to show data in this
// report. All advertisers associated with that ID will automatically be
// added. The dimension of the value needs to be
// 'dfa:floodlightConfigId'.
FloodlightConfigId *DimensionValue `json:"floodlightConfigId,omitempty"`
// MetricNames: The list of names of metrics the report should include.
MetricNames []string `json:"metricNames,omitempty"`
// PerInteractionDimensions: The list of per interaction dimensions the
// report should include.
PerInteractionDimensions []*SortedDimension `json:"perInteractionDimensions,omitempty"`
// ReportProperties: The properties of the report.
ReportProperties *ReportPathToConversionCriteriaReportProperties `json:"reportProperties,omitempty"`
}
ReportPathToConversionCriteria: The report criteria for a report of type "PATH_TO_CONVERSION".
type ReportPathToConversionCriteriaReportProperties ¶
type ReportPathToConversionCriteriaReportProperties struct {
// ClicksLookbackWindow: DFA checks to see if a click interaction
// occurred within the specified period of time before a conversion. By
// default the value is pulled from Floodlight or you can manually enter
// a custom value. Valid values: 1-90.
ClicksLookbackWindow int64 `json:"clicksLookbackWindow,omitempty"`
// ImpressionsLookbackWindow: DFA checks to see if an impression
// interaction occurred within the specified period of time before a
// conversion. By default the value is pulled from Floodlight or you can
// manually enter a custom value. Valid values: 1-90.
ImpressionsLookbackWindow int64 `json:"impressionsLookbackWindow,omitempty"`
// IncludeAttributedIPConversions: Deprecated: has no effect.
IncludeAttributedIPConversions bool `json:"includeAttributedIPConversions,omitempty"`
// IncludeUnattributedCookieConversions: Include conversions of users
// with a DoubleClick cookie but without an exposure. That means the
// user did not click or see an ad from the advertiser within the
// Floodlight group, or that the interaction happened outside the
// lookback window.
IncludeUnattributedCookieConversions bool `json:"includeUnattributedCookieConversions,omitempty"`
// IncludeUnattributedIPConversions: Include conversions that have no
// associated cookies and no exposures. It’s therefore impossible to
// know how the user was exposed to your ads during the lookback window
// prior to a conversion.
IncludeUnattributedIPConversions bool `json:"includeUnattributedIPConversions,omitempty"`
// MaximumClickInteractions: The maximum number of click interactions to
// include in the report. Advertisers currently paying for E2C reports
// get up to 200 (100 clicks, 100 impressions). If another advertiser in
// your network is paying for E2C, you can have up to 5 total exposures
// per report.
MaximumClickInteractions int64 `json:"maximumClickInteractions,omitempty"`
// MaximumImpressionInteractions: The maximum number of click
// interactions to include in the report. Advertisers currently paying
// for E2C reports get up to 200 (100 clicks, 100 impressions). If
// another advertiser in your network is paying for E2C, you can have up
// to 5 total exposures per report.
MaximumImpressionInteractions int64 `json:"maximumImpressionInteractions,omitempty"`
// MaximumInteractionGap: The maximum amount of time that can take place
// between interactions (clicks or impressions) by the same user. Valid
// values: 1-90.
MaximumInteractionGap int64 `json:"maximumInteractionGap,omitempty"`
// PivotOnInteractionPath: Enable pivoting on interaction path.
PivotOnInteractionPath bool `json:"pivotOnInteractionPath,omitempty"`
}
ReportPathToConversionCriteriaReportProperties: The properties of the report.
type ReportReachCriteria ¶
type ReportReachCriteria struct {
// Activities: Activity group.
Activities *Activities `json:"activities,omitempty"`
// CustomRichMediaEvents: Custom Rich Media Events group.
CustomRichMediaEvents *CustomRichMediaEvents `json:"customRichMediaEvents,omitempty"`
// DateRange: The date range this report should be run for.
DateRange *DateRange `json:"dateRange,omitempty"`
// DimensionFilters: The list of filters on which dimensions are
// filtered.
// Filters for different dimensions are ANDed, filters for the same
// dimension are grouped together and ORed.
DimensionFilters []*DimensionValue `json:"dimensionFilters,omitempty"`
// Dimensions: The list of dimensions the report should include.
Dimensions []*SortedDimension `json:"dimensions,omitempty"`
// MetricNames: The list of names of metrics the report should include.
MetricNames []string `json:"metricNames,omitempty"`
// ReachByFrequencyMetricNames: The list of names of Reach By Frequency
// metrics the report should include.
ReachByFrequencyMetricNames []string `json:"reachByFrequencyMetricNames,omitempty"`
}
ReportReachCriteria: The report criteria for a report of type "REACH".
type ReportSchedule ¶
type ReportSchedule struct {
// Active: Whether the schedule is active or not. Must be set to either
// true or false.
Active bool `json:"active,omitempty"`
// Every: Defines every how many days, weeks or months the report should
// be run. Needs to be set when "repeats" is either "DAILY", "WEEKLY" or
// "MONTHLY".
Every int64 `json:"every,omitempty"`
// ExpirationDate: The expiration date when the scheduled report stops
// running.
ExpirationDate string `json:"expirationDate,omitempty"`
// Repeats: The interval for which the report is repeated, one of:
// - "DAILY", also requires field "every" to be set.
// - "WEEKLY", also requires fields "every" and "repeatsOnWeekDays" to
// be set.
// - "TWICE_A_MONTH"
// - "MONTHLY", also requires fields "every" and "runsOnDayOfMonth" to
// be set.
// - "QUARTERLY"
// - "YEARLY"
Repeats string `json:"repeats,omitempty"`
// RepeatsOnWeekDays: List of week days "WEEKLY" on which scheduled
// reports should run.
RepeatsOnWeekDays []string `json:"repeatsOnWeekDays,omitempty"`
// RunsOnDayOfMonth: Enum to define for "MONTHLY" scheduled reports
// whether reports should be repeated on the same day of the month as
// "startDate" or the same day of the week of the month. Possible values
// are:
// - DAY_OF_MONTH
// - WEEK_OF_MONTH
// Example: If 'startDate' is Monday, April 2nd 2012 (2012-04-02),
// "DAY_OF_MONTH" would run subsequent reports on the 2nd of every
// Month, and "WEEK_OF_MONTH" would run subsequent reports on the first
// Monday of the month.
RunsOnDayOfMonth string `json:"runsOnDayOfMonth,omitempty"`
// StartDate: Start date of date range for which scheduled reports
// should be run.
StartDate string `json:"startDate,omitempty"`
}
ReportSchedule: The report's schedule. Can only be set if the report's 'dateRange' is a relative date range and the relative date range is not "TODAY".
type ReportsCompatibleFieldsQueryCall ¶
type ReportsCompatibleFieldsQueryCall struct {
// contains filtered or unexported fields
}
func (*ReportsCompatibleFieldsQueryCall) Do ¶
func (c *ReportsCompatibleFieldsQueryCall) Do() (*CompatibleFields, error)
func (*ReportsCompatibleFieldsQueryCall) Fields ¶
func (c *ReportsCompatibleFieldsQueryCall) Fields(s ...googleapi.Field) *ReportsCompatibleFieldsQueryCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ReportsCompatibleFieldsService ¶
type ReportsCompatibleFieldsService struct {
// contains filtered or unexported fields
}
func NewReportsCompatibleFieldsService ¶
func NewReportsCompatibleFieldsService(s *Service) *ReportsCompatibleFieldsService
func (*ReportsCompatibleFieldsService) Query ¶
func (r *ReportsCompatibleFieldsService) Query(profileId int64, report *Report) *ReportsCompatibleFieldsQueryCall
Query: Returns the fields that are compatible to be selected in the respective sections of a report criteria, given the fields already selected in the input report and user permissions.
type ReportsDeleteCall ¶
type ReportsDeleteCall struct {
// contains filtered or unexported fields
}
func (*ReportsDeleteCall) Do ¶
func (c *ReportsDeleteCall) Do() error
func (*ReportsDeleteCall) Fields ¶
func (c *ReportsDeleteCall) Fields(s ...googleapi.Field) *ReportsDeleteCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ReportsFilesGetCall ¶
type ReportsFilesGetCall struct {
// contains filtered or unexported fields
}
func (*ReportsFilesGetCall) Do ¶
func (c *ReportsFilesGetCall) Do() (*File, error)
func (*ReportsFilesGetCall) Download ¶
func (c *ReportsFilesGetCall) Download() (*http.Response, error)
Download fetches the API endpoint's "media" value, instead of the normal API response value. If the returned error is nil, the Response is guaranteed to have a 2xx status code. Callers must close the Response.Body as usual.
func (*ReportsFilesGetCall) Fields ¶
func (c *ReportsFilesGetCall) Fields(s ...googleapi.Field) *ReportsFilesGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ReportsFilesListCall ¶
type ReportsFilesListCall struct {
// contains filtered or unexported fields
}
func (*ReportsFilesListCall) Do ¶
func (c *ReportsFilesListCall) Do() (*FileList, error)
func (*ReportsFilesListCall) Fields ¶
func (c *ReportsFilesListCall) Fields(s ...googleapi.Field) *ReportsFilesListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*ReportsFilesListCall) MaxResults ¶
func (c *ReportsFilesListCall) MaxResults(maxResults int64) *ReportsFilesListCall
MaxResults sets the optional parameter "maxResults": Maximum number of results to return.
func (*ReportsFilesListCall) PageToken ¶
func (c *ReportsFilesListCall) PageToken(pageToken string) *ReportsFilesListCall
PageToken sets the optional parameter "pageToken": The value of the nextToken from the previous result page.
func (*ReportsFilesListCall) SortField ¶
func (c *ReportsFilesListCall) SortField(sortField string) *ReportsFilesListCall
SortField sets the optional parameter "sortField": The field by which to sort the list.
Possible values:
"ID" - Sort by file ID. "LAST_MODIFIED_TIME" (default) - Sort by 'lastmodifiedAt' field.
func (*ReportsFilesListCall) SortOrder ¶
func (c *ReportsFilesListCall) SortOrder(sortOrder string) *ReportsFilesListCall
SortOrder sets the optional parameter "sortOrder": Order of sorted results, default is 'DESCENDING'.
Possible values:
"ASCENDING" - Ascending order. "DESCENDING" (default) - Descending order.
type ReportsFilesService ¶
type ReportsFilesService struct {
// contains filtered or unexported fields
}
func NewReportsFilesService ¶
func NewReportsFilesService(s *Service) *ReportsFilesService
func (*ReportsFilesService) Get ¶
func (r *ReportsFilesService) Get(profileId int64, reportId int64, fileId int64) *ReportsFilesGetCall
Get: Retrieves a report file.
func (*ReportsFilesService) List ¶
func (r *ReportsFilesService) List(profileId int64, reportId int64) *ReportsFilesListCall
List: Lists files for a report.
type ReportsGetCall ¶
type ReportsGetCall struct {
// contains filtered or unexported fields
}
func (*ReportsGetCall) Do ¶
func (c *ReportsGetCall) Do() (*Report, error)
func (*ReportsGetCall) Fields ¶
func (c *ReportsGetCall) Fields(s ...googleapi.Field) *ReportsGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ReportsInsertCall ¶
type ReportsInsertCall struct {
// contains filtered or unexported fields
}
func (*ReportsInsertCall) Do ¶
func (c *ReportsInsertCall) Do() (*Report, error)
func (*ReportsInsertCall) Fields ¶
func (c *ReportsInsertCall) Fields(s ...googleapi.Field) *ReportsInsertCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ReportsListCall ¶
type ReportsListCall struct {
// contains filtered or unexported fields
}
func (*ReportsListCall) Do ¶
func (c *ReportsListCall) Do() (*ReportList, error)
func (*ReportsListCall) Fields ¶
func (c *ReportsListCall) Fields(s ...googleapi.Field) *ReportsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*ReportsListCall) MaxResults ¶
func (c *ReportsListCall) MaxResults(maxResults int64) *ReportsListCall
MaxResults sets the optional parameter "maxResults": Maximum number of results to return.
func (*ReportsListCall) PageToken ¶
func (c *ReportsListCall) PageToken(pageToken string) *ReportsListCall
PageToken sets the optional parameter "pageToken": The value of the nextToken from the previous result page.
func (*ReportsListCall) Scope ¶
func (c *ReportsListCall) Scope(scope string) *ReportsListCall
Scope sets the optional parameter "scope": The scope that defines which results are returned, default is 'MINE'.
Possible values:
"ALL" - All reports in account. "MINE" (default) - My reports.
func (*ReportsListCall) SortField ¶
func (c *ReportsListCall) SortField(sortField string) *ReportsListCall
SortField sets the optional parameter "sortField": The field by which to sort the list.
Possible values:
"ID" - Sort by report ID. "LAST_MODIFIED_TIME" (default) - Sort by 'lastModifiedTime' field. "NAME" - Sort by name of reports.
func (*ReportsListCall) SortOrder ¶
func (c *ReportsListCall) SortOrder(sortOrder string) *ReportsListCall
SortOrder sets the optional parameter "sortOrder": Order of sorted results, default is 'DESCENDING'.
Possible values:
"ASCENDING" - Ascending order. "DESCENDING" (default) - Descending order.
type ReportsPatchCall ¶
type ReportsPatchCall struct {
// contains filtered or unexported fields
}
func (*ReportsPatchCall) Do ¶
func (c *ReportsPatchCall) Do() (*Report, error)
func (*ReportsPatchCall) Fields ¶
func (c *ReportsPatchCall) Fields(s ...googleapi.Field) *ReportsPatchCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ReportsRunCall ¶
type ReportsRunCall struct {
// contains filtered or unexported fields
}
func (*ReportsRunCall) Do ¶
func (c *ReportsRunCall) Do() (*File, error)
func (*ReportsRunCall) Fields ¶
func (c *ReportsRunCall) Fields(s ...googleapi.Field) *ReportsRunCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*ReportsRunCall) Synchronous ¶
func (c *ReportsRunCall) Synchronous(synchronous bool) *ReportsRunCall
Synchronous sets the optional parameter "synchronous": If set and true, tries to run the report synchronously.
type ReportsService ¶
type ReportsService struct {
CompatibleFields *ReportsCompatibleFieldsService
Files *ReportsFilesService
// contains filtered or unexported fields
}
func NewReportsService ¶
func NewReportsService(s *Service) *ReportsService
func (*ReportsService) Delete ¶
func (r *ReportsService) Delete(profileId int64, reportId int64) *ReportsDeleteCall
Delete: Deletes a report by its ID.
func (*ReportsService) Get ¶
func (r *ReportsService) Get(profileId int64, reportId int64) *ReportsGetCall
Get: Retrieves a report by its ID.
func (*ReportsService) Insert ¶
func (r *ReportsService) Insert(profileId int64, report *Report) *ReportsInsertCall
Insert: Creates a report.
func (*ReportsService) List ¶
func (r *ReportsService) List(profileId int64) *ReportsListCall
List: Retrieves list of reports.
func (*ReportsService) Patch ¶
func (r *ReportsService) Patch(profileId int64, reportId int64, report *Report) *ReportsPatchCall
Patch: Updates a report. This method supports patch semantics.
func (*ReportsService) Run ¶
func (r *ReportsService) Run(profileId int64, reportId int64) *ReportsRunCall
Run: Runs a report.
func (*ReportsService) Update ¶
func (r *ReportsService) Update(profileId int64, reportId int64, report *Report) *ReportsUpdateCall
Update: Updates a report.
type ReportsUpdateCall ¶
type ReportsUpdateCall struct {
// contains filtered or unexported fields
}
func (*ReportsUpdateCall) Do ¶
func (c *ReportsUpdateCall) Do() (*Report, error)
func (*ReportsUpdateCall) Fields ¶
func (c *ReportsUpdateCall) Fields(s ...googleapi.Field) *ReportsUpdateCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type Service ¶
type Service struct {
BasePath string // API endpoint base URL
UserAgent string // optional additional User-Agent fragment
DimensionValues *DimensionValuesService
Files *FilesService
Reports *ReportsService
UserProfiles *UserProfilesService
// contains filtered or unexported fields
}
type SortedDimension ¶
type SortedDimension struct {
// Kind: The kind of resource this is, in this case
// dfareporting#sortedDimension.
Kind string `json:"kind,omitempty"`
// Name: The name of the dimension.
Name string `json:"name,omitempty"`
// SortOrder: An optional sort order for the dimension column, one of:
//
// - "ASCENDING"
// - "DESCENDING"
SortOrder string `json:"sortOrder,omitempty"`
}
SortedDimension: Represents a sorted dimension.
type UserProfile ¶
type UserProfile struct {
// AccountId: The account ID to which this profile belongs.
AccountId int64 `json:"accountId,omitempty,string"`
// AccountName: The account name this profile belongs to.
AccountName string `json:"accountName,omitempty"`
// Etag: The eTag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Kind: The kind of resource this is, in this case
// dfareporting#userProfile.
Kind string `json:"kind,omitempty"`
// ProfileId: The unique ID of the user profile.
ProfileId int64 `json:"profileId,omitempty,string"`
// SubAccountId: The sub account ID this profile belongs to if
// applicable.
SubAccountId int64 `json:"subAccountId,omitempty,string"`
// SubAccountName: The sub account name this profile belongs to if
// applicable.
SubAccountName string `json:"subAccountName,omitempty"`
// UserName: The user name.
UserName string `json:"userName,omitempty"`
}
UserProfile: Represents a UserProfile resource.
type UserProfileList ¶
type UserProfileList struct {
// Etag: The eTag of this response for caching purposes.
Etag string `json:"etag,omitempty"`
// Items: The user profiles returned in this response.
Items []*UserProfile `json:"items,omitempty"`
// Kind: The kind of list this is, in this case
// dfareporting#userProfileList.
Kind string `json:"kind,omitempty"`
}
UserProfileList: Represents the list of user profiles.
type UserProfilesGetCall ¶
type UserProfilesGetCall struct {
// contains filtered or unexported fields
}
func (*UserProfilesGetCall) Do ¶
func (c *UserProfilesGetCall) Do() (*UserProfile, error)
func (*UserProfilesGetCall) Fields ¶
func (c *UserProfilesGetCall) Fields(s ...googleapi.Field) *UserProfilesGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type UserProfilesListCall ¶
type UserProfilesListCall struct {
// contains filtered or unexported fields
}
func (*UserProfilesListCall) Do ¶
func (c *UserProfilesListCall) Do() (*UserProfileList, error)
func (*UserProfilesListCall) Fields ¶
func (c *UserProfilesListCall) Fields(s ...googleapi.Field) *UserProfilesListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type UserProfilesService ¶
type UserProfilesService struct {
// contains filtered or unexported fields
}
func NewUserProfilesService ¶
func NewUserProfilesService(s *Service) *UserProfilesService
func (*UserProfilesService) Get ¶
func (r *UserProfilesService) Get(profileId int64) *UserProfilesGetCall
Get: Gets one user profile by ID.
func (*UserProfilesService) List ¶
func (r *UserProfilesService) List() *UserProfilesListCall
List: Retrieves list of user profiles for a user.