Documentation
¶
Overview ¶
Package doubleclickbidmanager provides access to the DoubleClick Bid Manager API.
See https://developers.google.com/bid-manager/
Usage example:
import "google.golang.org/api/doubleclickbidmanager/v1" ... doubleclickbidmanagerService, err := doubleclickbidmanager.New(oauthHttpClient)
Index ¶
- type DownloadLineItemsRequest
- type DownloadLineItemsResponse
- type FilterPair
- type LineitemsDownloadlineitemsCall
- type LineitemsService
- type LineitemsUploadlineitemsCall
- type ListQueriesResponse
- type ListReportsResponse
- type Parameters
- type QueriesCreatequeryCall
- type QueriesDeletequeryCall
- type QueriesGetqueryCall
- type QueriesListqueriesCall
- type QueriesRunqueryCall
- type QueriesService
- func (r *QueriesService) Createquery(query *Query) *QueriesCreatequeryCall
- func (r *QueriesService) Deletequery(queryId int64) *QueriesDeletequeryCall
- func (r *QueriesService) Getquery(queryId int64) *QueriesGetqueryCall
- func (r *QueriesService) Listqueries() *QueriesListqueriesCall
- func (r *QueriesService) Runquery(queryId int64, runqueryrequest *RunQueryRequest) *QueriesRunqueryCall
- type Query
- type QueryMetadata
- type QuerySchedule
- type Report
- type ReportFailure
- type ReportKey
- type ReportMetadata
- type ReportStatus
- type ReportsListreportsCall
- type ReportsService
- type RowStatus
- type RunQueryRequest
- type Service
- type UploadLineItemsRequest
- type UploadLineItemsResponse
- type UploadStatus
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DownloadLineItemsRequest ¶
type DownloadLineItemsRequest struct {
// FilterIds: Ids of the specified filter type used to filter line items
// to fetch. If omitted, all the line items will be returned.
FilterIds googleapi.Int64s `json:"filterIds,omitempty"`
// FilterType: Filter type used to filter line items to fetch.
//
// Possible values:
// "ADVERTISER_ID"
// "INSERTION_ORDER_ID"
// "LINE_ITEM_ID"
FilterType string `json:"filterType,omitempty"`
// Format: Format in which the line items will be returned. Default to
// CSV.
//
// Possible values:
// "CSV"
Format string `json:"format,omitempty"`
}
DownloadLineItemsRequest: Request to fetch stored line items.
type DownloadLineItemsResponse ¶
type DownloadLineItemsResponse struct {
// LineItems: Retrieved line items in CSV format. Refer to Entity Write
// File Format for more information on file format.
LineItems string `json:"lineItems,omitempty"`
}
DownloadLineItemsResponse: Download line items response.
type FilterPair ¶
type FilterPair struct {
// Type: Filter type.
//
// Possible values:
// "FILTER_ACTIVE_VIEW_EXPECTED_VIEWABILITY"
// "FILTER_ACTIVITY_ID"
// "FILTER_ADVERTISER"
// "FILTER_ADVERTISER_CURRENCY"
// "FILTER_ADVERTISER_TIMEZONE"
// "FILTER_AD_POSITION"
// "FILTER_AGE"
// "FILTER_BRANDSAFE_CHANNEL_ID"
// "FILTER_BROWSER"
// "FILTER_CAMPAIGN_DAILY_FREQUENCY"
// "FILTER_CARRIER"
// "FILTER_CHANNEL_ID"
// "FILTER_CITY"
// "FILTER_CONVERSION_DELAY"
// "FILTER_COUNTRY"
// "FILTER_CREATIVE_ID"
// "FILTER_CREATIVE_SIZE"
// "FILTER_CREATIVE_TYPE"
// "FILTER_DATA_PROVIDER"
// "FILTER_DATE"
// "FILTER_DAY_OF_WEEK"
// "FILTER_DMA"
// "FILTER_EXCHANGE_ID"
// "FILTER_FLOODLIGHT_PIXEL_ID"
// "FILTER_GENDER"
// "FILTER_INSERTION_ORDER"
// "FILTER_INVENTORY_FORMAT"
// "FILTER_INVENTORY_SOURCE"
// "FILTER_INVENTORY_SOURCE_TYPE"
// "FILTER_KEYWORD"
// "FILTER_LINE_ITEM"
// "FILTER_LINE_ITEM_DAILY_FREQUENCY"
// "FILTER_LINE_ITEM_LIFETIME_FREQUENCY"
// "FILTER_LINE_ITEM_TYPE"
// "FILTER_MOBILE_DEVICE_MAKE"
// "FILTER_MOBILE_DEVICE_MAKE_MODEL"
// "FILTER_MOBILE_DEVICE_TYPE"
// "FILTER_MOBILE_GEO"
// "FILTER_MONTH"
// "FILTER_MRAID_SUPPORT"
// "FILTER_NIELSEN_AGE"
// "FILTER_NIELSEN_COUNTRY_CODE"
// "FILTER_NIELSEN_DEVICE_ID"
// "FILTER_NIELSEN_GENDER"
// "FILTER_ORDER_ID"
// "FILTER_OS"
// "FILTER_PAGE_CATEGORY"
// "FILTER_PAGE_LAYOUT"
// "FILTER_PARTNER"
// "FILTER_PARTNER_CURRENCY"
// "FILTER_PUBLIC_INVENTORY"
// "FILTER_QUARTER"
// "FILTER_REGION"
// "FILTER_REGULAR_CHANNEL_ID"
// "FILTER_SITE_ID"
// "FILTER_SITE_LANGUAGE"
// "FILTER_TARGETED_USER_LIST"
// "FILTER_TIME_OF_DAY"
// "FILTER_TRUEVIEW_CONVERSION_TYPE"
// "FILTER_UNKNOWN"
// "FILTER_USER_LIST"
// "FILTER_USER_LIST_FIRST_PARTY"
// "FILTER_USER_LIST_THIRD_PARTY"
// "FILTER_VIDEO_AD_POSITION_IN_STREAM"
// "FILTER_VIDEO_COMPANION_SIZE"
// "FILTER_VIDEO_COMPANION_TYPE"
// "FILTER_VIDEO_CREATIVE_DURATION"
// "FILTER_VIDEO_CREATIVE_DURATION_SKIPPABLE"
// "FILTER_VIDEO_DURATION_SECONDS"
// "FILTER_VIDEO_FORMAT_SUPPORT"
// "FILTER_VIDEO_INVENTORY_TYPE"
// "FILTER_VIDEO_PLAYER_SIZE"
// "FILTER_VIDEO_RATING_TIER"
// "FILTER_VIDEO_SKIPPABLE_SUPPORT"
// "FILTER_VIDEO_VPAID_SUPPORT"
// "FILTER_WEEK"
// "FILTER_YEAR"
// "FILTER_YOUTUBE_VERTICAL"
// "FILTER_ZIP_CODE"
Type string `json:"type,omitempty"`
// Value: Filter value.
Value string `json:"value,omitempty"`
}
FilterPair: Filter used to match traffic data in your report.
type LineitemsDownloadlineitemsCall ¶
type LineitemsDownloadlineitemsCall struct {
// contains filtered or unexported fields
}
func (*LineitemsDownloadlineitemsCall) Do ¶
func (c *LineitemsDownloadlineitemsCall) Do() (*DownloadLineItemsResponse, error)
func (*LineitemsDownloadlineitemsCall) Fields ¶
func (c *LineitemsDownloadlineitemsCall) Fields(s ...googleapi.Field) *LineitemsDownloadlineitemsCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type LineitemsService ¶
type LineitemsService struct {
// contains filtered or unexported fields
}
func NewLineitemsService ¶
func NewLineitemsService(s *Service) *LineitemsService
func (*LineitemsService) Downloadlineitems ¶
func (r *LineitemsService) Downloadlineitems(downloadlineitemsrequest *DownloadLineItemsRequest) *LineitemsDownloadlineitemsCall
Downloadlineitems: Retrieves line items in CSV format.
func (*LineitemsService) Uploadlineitems ¶
func (r *LineitemsService) Uploadlineitems(uploadlineitemsrequest *UploadLineItemsRequest) *LineitemsUploadlineitemsCall
Uploadlineitems: Uploads line items in CSV format.
type LineitemsUploadlineitemsCall ¶
type LineitemsUploadlineitemsCall struct {
// contains filtered or unexported fields
}
func (*LineitemsUploadlineitemsCall) Do ¶
func (c *LineitemsUploadlineitemsCall) Do() (*UploadLineItemsResponse, error)
func (*LineitemsUploadlineitemsCall) Fields ¶
func (c *LineitemsUploadlineitemsCall) Fields(s ...googleapi.Field) *LineitemsUploadlineitemsCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ListQueriesResponse ¶
type ListQueriesResponse struct {
// Kind: Identifies what kind of resource this is. Value: the fixed
// string "doubleclickbidmanager#listQueriesResponse".
Kind string `json:"kind,omitempty"`
// Queries: Retrieved queries.
Queries []*Query `json:"queries,omitempty"`
}
ListQueriesResponse: List queries response.
type ListReportsResponse ¶
type ListReportsResponse struct {
// Kind: Identifies what kind of resource this is. Value: the fixed
// string "doubleclickbidmanager#listReportsResponse".
Kind string `json:"kind,omitempty"`
// Reports: Retrieved reports.
Reports []*Report `json:"reports,omitempty"`
}
ListReportsResponse: List reports response.
type Parameters ¶
type Parameters struct {
// Filters: Filters used to match traffic data in your report.
Filters []*FilterPair `json:"filters,omitempty"`
// GroupBys: Data is grouped by the filters listed in this field.
//
// Possible values:
// "FILTER_ACTIVE_VIEW_EXPECTED_VIEWABILITY"
// "FILTER_ACTIVITY_ID"
// "FILTER_ADVERTISER"
// "FILTER_ADVERTISER_CURRENCY"
// "FILTER_ADVERTISER_TIMEZONE"
// "FILTER_AD_POSITION"
// "FILTER_AGE"
// "FILTER_BRANDSAFE_CHANNEL_ID"
// "FILTER_BROWSER"
// "FILTER_CAMPAIGN_DAILY_FREQUENCY"
// "FILTER_CARRIER"
// "FILTER_CHANNEL_ID"
// "FILTER_CITY"
// "FILTER_CONVERSION_DELAY"
// "FILTER_COUNTRY"
// "FILTER_CREATIVE_ID"
// "FILTER_CREATIVE_SIZE"
// "FILTER_CREATIVE_TYPE"
// "FILTER_DATA_PROVIDER"
// "FILTER_DATE"
// "FILTER_DAY_OF_WEEK"
// "FILTER_DMA"
// "FILTER_EXCHANGE_ID"
// "FILTER_FLOODLIGHT_PIXEL_ID"
// "FILTER_GENDER"
// "FILTER_INSERTION_ORDER"
// "FILTER_INVENTORY_FORMAT"
// "FILTER_INVENTORY_SOURCE"
// "FILTER_INVENTORY_SOURCE_TYPE"
// "FILTER_KEYWORD"
// "FILTER_LINE_ITEM"
// "FILTER_LINE_ITEM_DAILY_FREQUENCY"
// "FILTER_LINE_ITEM_LIFETIME_FREQUENCY"
// "FILTER_LINE_ITEM_TYPE"
// "FILTER_MOBILE_DEVICE_MAKE"
// "FILTER_MOBILE_DEVICE_MAKE_MODEL"
// "FILTER_MOBILE_DEVICE_TYPE"
// "FILTER_MOBILE_GEO"
// "FILTER_MONTH"
// "FILTER_MRAID_SUPPORT"
// "FILTER_NIELSEN_AGE"
// "FILTER_NIELSEN_COUNTRY_CODE"
// "FILTER_NIELSEN_DEVICE_ID"
// "FILTER_NIELSEN_GENDER"
// "FILTER_ORDER_ID"
// "FILTER_OS"
// "FILTER_PAGE_CATEGORY"
// "FILTER_PAGE_LAYOUT"
// "FILTER_PARTNER"
// "FILTER_PARTNER_CURRENCY"
// "FILTER_PUBLIC_INVENTORY"
// "FILTER_QUARTER"
// "FILTER_REGION"
// "FILTER_REGULAR_CHANNEL_ID"
// "FILTER_SITE_ID"
// "FILTER_SITE_LANGUAGE"
// "FILTER_TARGETED_USER_LIST"
// "FILTER_TIME_OF_DAY"
// "FILTER_TRUEVIEW_CONVERSION_TYPE"
// "FILTER_UNKNOWN"
// "FILTER_USER_LIST"
// "FILTER_USER_LIST_FIRST_PARTY"
// "FILTER_USER_LIST_THIRD_PARTY"
// "FILTER_VIDEO_AD_POSITION_IN_STREAM"
// "FILTER_VIDEO_COMPANION_SIZE"
// "FILTER_VIDEO_COMPANION_TYPE"
// "FILTER_VIDEO_CREATIVE_DURATION"
// "FILTER_VIDEO_CREATIVE_DURATION_SKIPPABLE"
// "FILTER_VIDEO_DURATION_SECONDS"
// "FILTER_VIDEO_FORMAT_SUPPORT"
// "FILTER_VIDEO_INVENTORY_TYPE"
// "FILTER_VIDEO_PLAYER_SIZE"
// "FILTER_VIDEO_RATING_TIER"
// "FILTER_VIDEO_SKIPPABLE_SUPPORT"
// "FILTER_VIDEO_VPAID_SUPPORT"
// "FILTER_WEEK"
// "FILTER_YEAR"
// "FILTER_YOUTUBE_VERTICAL"
// "FILTER_ZIP_CODE"
GroupBys []string `json:"groupBys,omitempty"`
// IncludeInviteData: Whether to include data from Invite Media.
IncludeInviteData bool `json:"includeInviteData,omitempty"`
// Metrics: Metrics to include as columns in your report.
//
// Possible values:
// "METRIC_BID_REQUESTS"
// "METRIC_BILLABLE_COST_ADVERTISER"
// "METRIC_BILLABLE_COST_PARTNER"
// "METRIC_BILLABLE_COST_USD"
// "METRIC_CLICKS"
// "METRIC_CLICK_TO_POST_CLICK_CONVERSION_RATE"
// "METRIC_COMSCORE_VCE_AUDIENCE_AVG_FREQUENCY"
// "METRIC_COMSCORE_VCE_AUDIENCE_IMPRESSIONS"
// "METRIC_COMSCORE_VCE_AUDIENCE_IMPRESSIONS_SHARE"
// "METRIC_COMSCORE_VCE_AUDIENCE_REACH_PCT"
// "METRIC_COMSCORE_VCE_AUDIENCE_SHARE_PCT"
// "METRIC_COMSCORE_VCE_GROSS_RATING_POINTS"
// "METRIC_COMSCORE_VCE_POPULATION"
// "METRIC_COMSCORE_VCE_UNIQUE_AUDIENCE"
// "METRIC_CONVERSIONS_PER_MILLE"
// "METRIC_CPM_FEE1_ADVERTISER"
// "METRIC_CPM_FEE1_PARTNER"
// "METRIC_CPM_FEE1_USD"
// "METRIC_CPM_FEE2_ADVERTISER"
// "METRIC_CPM_FEE2_PARTNER"
// "METRIC_CPM_FEE2_USD"
// "METRIC_CPM_FEE3_ADVERTISER"
// "METRIC_CPM_FEE3_PARTNER"
// "METRIC_CPM_FEE3_USD"
// "METRIC_CPM_FEE4_ADVERTISER"
// "METRIC_CPM_FEE4_PARTNER"
// "METRIC_CPM_FEE4_USD"
// "METRIC_CPM_FEE5_ADVERTISER"
// "METRIC_CPM_FEE5_PARTNER"
// "METRIC_CPM_FEE5_USD"
// "METRIC_CTR"
// "METRIC_DATA_COST_ADVERTISER"
// "METRIC_DATA_COST_PARTNER"
// "METRIC_DATA_COST_USD"
// "METRIC_FEE10_ADVERTISER"
// "METRIC_FEE10_PARTNER"
// "METRIC_FEE10_USD"
// "METRIC_FEE11_ADVERTISER"
// "METRIC_FEE11_PARTNER"
// "METRIC_FEE11_USD"
// "METRIC_FEE12_ADVERTISER"
// "METRIC_FEE12_PARTNER"
// "METRIC_FEE12_USD"
// "METRIC_FEE13_ADVERTISER"
// "METRIC_FEE13_PARTNER"
// "METRIC_FEE13_USD"
// "METRIC_FEE14_ADVERTISER"
// "METRIC_FEE14_PARTNER"
// "METRIC_FEE14_USD"
// "METRIC_FEE15_ADVERTISER"
// "METRIC_FEE15_PARTNER"
// "METRIC_FEE15_USD"
// "METRIC_FEE16_ADVERTISER"
// "METRIC_FEE16_PARTNER"
// "METRIC_FEE16_USD"
// "METRIC_FEE17_ADVERTISER"
// "METRIC_FEE17_PARTNER"
// "METRIC_FEE17_USD"
// "METRIC_FEE18_ADVERTISER"
// "METRIC_FEE18_PARTNER"
// "METRIC_FEE18_USD"
// "METRIC_FEE19_ADVERTISER"
// "METRIC_FEE19_PARTNER"
// "METRIC_FEE19_USD"
// "METRIC_FEE20_ADVERTISER"
// "METRIC_FEE20_PARTNER"
// "METRIC_FEE20_USD"
// "METRIC_FEE2_ADVERTISER"
// "METRIC_FEE2_PARTNER"
// "METRIC_FEE2_USD"
// "METRIC_FEE3_ADVERTISER"
// "METRIC_FEE3_PARTNER"
// "METRIC_FEE3_USD"
// "METRIC_FEE4_ADVERTISER"
// "METRIC_FEE4_PARTNER"
// "METRIC_FEE4_USD"
// "METRIC_FEE5_ADVERTISER"
// "METRIC_FEE5_PARTNER"
// "METRIC_FEE5_USD"
// "METRIC_FEE6_ADVERTISER"
// "METRIC_FEE6_PARTNER"
// "METRIC_FEE6_USD"
// "METRIC_FEE7_ADVERTISER"
// "METRIC_FEE7_PARTNER"
// "METRIC_FEE7_USD"
// "METRIC_FEE8_ADVERTISER"
// "METRIC_FEE8_PARTNER"
// "METRIC_FEE8_USD"
// "METRIC_FEE9_ADVERTISER"
// "METRIC_FEE9_PARTNER"
// "METRIC_FEE9_USD"
// "METRIC_IMPRESSIONS"
// "METRIC_IMPRESSIONS_TO_CONVERSION_RATE"
// "METRIC_LAST_CLICKS"
// "METRIC_LAST_IMPRESSIONS"
// "METRIC_MEDIA_COST_ADVERTISER"
// "METRIC_MEDIA_COST_ECPAPC_ADVERTISER"
// "METRIC_MEDIA_COST_ECPAPC_PARTNER"
// "METRIC_MEDIA_COST_ECPAPC_USD"
// "METRIC_MEDIA_COST_ECPAPV_ADVERTISER"
// "METRIC_MEDIA_COST_ECPAPV_PARTNER"
// "METRIC_MEDIA_COST_ECPAPV_USD"
// "METRIC_MEDIA_COST_ECPA_ADVERTISER"
// "METRIC_MEDIA_COST_ECPA_PARTNER"
// "METRIC_MEDIA_COST_ECPA_USD"
// "METRIC_MEDIA_COST_ECPCV_ADVERTISER"
// "METRIC_MEDIA_COST_ECPCV_PARTNER"
// "METRIC_MEDIA_COST_ECPCV_USD"
// "METRIC_MEDIA_COST_ECPC_ADVERTISER"
// "METRIC_MEDIA_COST_ECPC_PARTNER"
// "METRIC_MEDIA_COST_ECPC_USD"
// "METRIC_MEDIA_COST_ECPM_ADVERTISER"
// "METRIC_MEDIA_COST_ECPM_PARTNER"
// "METRIC_MEDIA_COST_ECPM_USD"
// "METRIC_MEDIA_COST_PARTNER"
// "METRIC_MEDIA_COST_USD"
// "METRIC_MEDIA_FEE1_ADVERTISER"
// "METRIC_MEDIA_FEE1_PARTNER"
// "METRIC_MEDIA_FEE1_USD"
// "METRIC_MEDIA_FEE2_ADVERTISER"
// "METRIC_MEDIA_FEE2_PARTNER"
// "METRIC_MEDIA_FEE2_USD"
// "METRIC_MEDIA_FEE3_ADVERTISER"
// "METRIC_MEDIA_FEE3_PARTNER"
// "METRIC_MEDIA_FEE3_USD"
// "METRIC_MEDIA_FEE4_ADVERTISER"
// "METRIC_MEDIA_FEE4_PARTNER"
// "METRIC_MEDIA_FEE4_USD"
// "METRIC_MEDIA_FEE5_ADVERTISER"
// "METRIC_MEDIA_FEE5_PARTNER"
// "METRIC_MEDIA_FEE5_USD"
// "METRIC_PIXEL_LOADS"
// "METRIC_PLATFORM_FEE_ADVERTISER"
// "METRIC_PLATFORM_FEE_PARTNER"
// "METRIC_PLATFORM_FEE_USD"
// "METRIC_POST_CLICK_DFA_REVENUE"
// "METRIC_POST_VIEW_DFA_REVENUE"
// "METRIC_PROFIT_ADVERTISER"
// "METRIC_PROFIT_ECPAPC_ADVERTISER"
// "METRIC_PROFIT_ECPAPC_PARTNER"
// "METRIC_PROFIT_ECPAPC_USD"
// "METRIC_PROFIT_ECPAPV_ADVERTISER"
// "METRIC_PROFIT_ECPAPV_PARTNER"
// "METRIC_PROFIT_ECPAPV_USD"
// "METRIC_PROFIT_ECPA_ADVERTISER"
// "METRIC_PROFIT_ECPA_PARTNER"
// "METRIC_PROFIT_ECPA_USD"
// "METRIC_PROFIT_ECPC_ADVERTISER"
// "METRIC_PROFIT_ECPC_PARTNER"
// "METRIC_PROFIT_ECPC_USD"
// "METRIC_PROFIT_ECPM_ADVERTISER"
// "METRIC_PROFIT_ECPM_PARTNER"
// "METRIC_PROFIT_ECPM_USD"
// "METRIC_PROFIT_MARGIN"
// "METRIC_PROFIT_PARTNER"
// "METRIC_PROFIT_USD"
// "METRIC_REVENUE_ADVERTISER"
// "METRIC_REVENUE_ECPAPC_ADVERTISER"
// "METRIC_REVENUE_ECPAPC_PARTNER"
// "METRIC_REVENUE_ECPAPC_USD"
// "METRIC_REVENUE_ECPAPV_ADVERTISER"
// "METRIC_REVENUE_ECPAPV_PARTNER"
// "METRIC_REVENUE_ECPAPV_USD"
// "METRIC_REVENUE_ECPA_ADVERTISER"
// "METRIC_REVENUE_ECPA_PARTNER"
// "METRIC_REVENUE_ECPA_USD"
// "METRIC_REVENUE_ECPCV_ADVERTISER"
// "METRIC_REVENUE_ECPCV_PARTNER"
// "METRIC_REVENUE_ECPCV_USD"
// "METRIC_REVENUE_ECPC_ADVERTISER"
// "METRIC_REVENUE_ECPC_PARTNER"
// "METRIC_REVENUE_ECPC_USD"
// "METRIC_REVENUE_ECPM_ADVERTISER"
// "METRIC_REVENUE_ECPM_PARTNER"
// "METRIC_REVENUE_ECPM_USD"
// "METRIC_REVENUE_PARTNER"
// "METRIC_REVENUE_USD"
// "METRIC_RICH_MEDIA_VIDEO_COMPLETIONS"
// "METRIC_RICH_MEDIA_VIDEO_FIRST_QUARTILE_COMPLETES"
// "METRIC_RICH_MEDIA_VIDEO_FULL_SCREENS"
// "METRIC_RICH_MEDIA_VIDEO_MIDPOINTS"
// "METRIC_RICH_MEDIA_VIDEO_MUTES"
// "METRIC_RICH_MEDIA_VIDEO_PAUSES"
// "METRIC_RICH_MEDIA_VIDEO_PLAYS"
// "METRIC_RICH_MEDIA_VIDEO_SKIPS"
// "METRIC_RICH_MEDIA_VIDEO_THIRD_QUARTILE_COMPLETES"
// "METRIC_TEA_TRUEVIEW_IMPRESSIONS"
// "METRIC_TEA_TRUEVIEW_UNIQUE_COOKIES"
// "METRIC_TEA_TRUEVIEW_UNIQUE_PEOPLE"
// "METRIC_TOTAL_CONVERSIONS"
// "METRIC_TOTAL_MEDIA_COST_ADVERTISER"
// "METRIC_TOTAL_MEDIA_COST_ECPAPC_ADVERTISER"
// "METRIC_TOTAL_MEDIA_COST_ECPAPC_PARTNER"
// "METRIC_TOTAL_MEDIA_COST_ECPAPC_USD"
// "METRIC_TOTAL_MEDIA_COST_ECPAPV_ADVERTISER"
// "METRIC_TOTAL_MEDIA_COST_ECPAPV_PARTNER"
// "METRIC_TOTAL_MEDIA_COST_ECPAPV_USD"
// "METRIC_TOTAL_MEDIA_COST_ECPA_ADVERTISER"
// "METRIC_TOTAL_MEDIA_COST_ECPA_PARTNER"
// "METRIC_TOTAL_MEDIA_COST_ECPA_USD"
// "METRIC_TOTAL_MEDIA_COST_ECPCV_ADVERTISER"
// "METRIC_TOTAL_MEDIA_COST_ECPCV_PARTNER"
// "METRIC_TOTAL_MEDIA_COST_ECPCV_USD"
// "METRIC_TOTAL_MEDIA_COST_ECPC_ADVERTISER"
// "METRIC_TOTAL_MEDIA_COST_ECPC_PARTNER"
// "METRIC_TOTAL_MEDIA_COST_ECPC_USD"
// "METRIC_TOTAL_MEDIA_COST_ECPM_ADVERTISER"
// "METRIC_TOTAL_MEDIA_COST_ECPM_PARTNER"
// "METRIC_TOTAL_MEDIA_COST_ECPM_USD"
// "METRIC_TOTAL_MEDIA_COST_PARTNER"
// "METRIC_TOTAL_MEDIA_COST_USD"
// "METRIC_TRUEVIEW_CONVERSION_MANY_PER_VIEW"
// "METRIC_TRUEVIEW_CONVERSION_ONE_PER_VIEW"
// "METRIC_TRUEVIEW_CONVERSION_RATE_ONE_PER_VIEW"
// "METRIC_TRUEVIEW_COST_CONVERSION_MANY_PER_VIEW_RATIO"
// "METRIC_TRUEVIEW_COST_CONVERSION_ONE_PER_VIEW_RATIO"
// "METRIC_TRUEVIEW_CPV_ADVERTISER"
// "METRIC_TRUEVIEW_CPV_PARTNER"
// "METRIC_TRUEVIEW_CPV_USD"
// "METRIC_TRUEVIEW_EARNED_LIKES"
// "METRIC_TRUEVIEW_EARNED_PLAYLIST_ADDITIONS"
// "METRIC_TRUEVIEW_EARNED_SHARES"
// "METRIC_TRUEVIEW_EARNED_SUBSCRIBERS"
// "METRIC_TRUEVIEW_EARNED_VIEWS"
// "METRIC_TRUEVIEW_IMPRESSION_SHARE"
// "METRIC_TRUEVIEW_LOST_IS_BUDGET"
// "METRIC_TRUEVIEW_LOST_IS_RANK"
// "METRIC_TRUEVIEW_TOTAL_CONVERSION_VALUE"
// "METRIC_TRUEVIEW_UNIQUE_VIEWERS"
// "METRIC_TRUEVIEW_VALUE_CONVERSION_MANY_PER_VIEW_RATIO"
// "METRIC_TRUEVIEW_VALUE_CONVERSION_ONE_PER_VIEW_RATIO"
// "METRIC_TRUEVIEW_VIEWS"
// "METRIC_TRUEVIEW_VIEW_RATE"
// "METRIC_TRUEVIEW_VIEW_THROUGH_CONVERSION"
// "METRIC_UNIQUE_VISITORS_COOKIES"
// "METRIC_UNKNOWN"
// "METRIC_VIDEO_COMPANION_CLICKS"
// "METRIC_VIDEO_COMPANION_IMPRESSIONS"
// "METRIC_VIDEO_COMPLETION_RATE"
Metrics []string `json:"metrics,omitempty"`
// Type: Report type.
//
// Possible values:
// "TYPE_ACTIVE_GRP"
// "TYPE_AUDIENCE_COMPOSITION"
// "TYPE_AUDIENCE_PERFORMANCE"
// "TYPE_CLIENT_SAFE"
// "TYPE_COMSCORE_VCE"
// "TYPE_CROSS_FEE"
// "TYPE_CROSS_PARTNER"
// "TYPE_CROSS_PARTNER_THIRD_PARTY_DATA_PROVIDER"
// "TYPE_ESTIMATED_CONVERSION"
// "TYPE_FEE"
// "TYPE_GENERAL"
// "TYPE_INVENTORY_AVAILABILITY"
// "TYPE_KEYWORD"
// "TYPE_NIELSEN_AUDIENCE_PROFILE"
// "TYPE_NIELSEN_DAILY_REACH_BUILD"
// "TYPE_NIELSEN_SITE"
// "TYPE_ORDER_ID"
// "TYPE_PAGE_CATEGORY"
// "TYPE_PIXEL_LOAD"
// "TYPE_REACH_AND_FREQUENCY"
// "TYPE_THIRD_PARTY_DATA_PROVIDER"
// "TYPE_TRUEVIEW"
// "TYPE_TRUEVIEW_IAR"
// "TYPE_VERIFICATION"
// "TYPE_YOUTUBE_VERTICAL"
Type string `json:"type,omitempty"`
}
Parameters: Parameters of a query or report.
type QueriesCreatequeryCall ¶
type QueriesCreatequeryCall struct {
// contains filtered or unexported fields
}
func (*QueriesCreatequeryCall) Do ¶
func (c *QueriesCreatequeryCall) Do() (*Query, error)
func (*QueriesCreatequeryCall) Fields ¶
func (c *QueriesCreatequeryCall) Fields(s ...googleapi.Field) *QueriesCreatequeryCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type QueriesDeletequeryCall ¶
type QueriesDeletequeryCall struct {
// contains filtered or unexported fields
}
func (*QueriesDeletequeryCall) Do ¶
func (c *QueriesDeletequeryCall) Do() error
func (*QueriesDeletequeryCall) Fields ¶
func (c *QueriesDeletequeryCall) Fields(s ...googleapi.Field) *QueriesDeletequeryCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type QueriesGetqueryCall ¶
type QueriesGetqueryCall struct {
// contains filtered or unexported fields
}
func (*QueriesGetqueryCall) Do ¶
func (c *QueriesGetqueryCall) Do() (*Query, error)
func (*QueriesGetqueryCall) Fields ¶
func (c *QueriesGetqueryCall) Fields(s ...googleapi.Field) *QueriesGetqueryCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type QueriesListqueriesCall ¶
type QueriesListqueriesCall struct {
// contains filtered or unexported fields
}
func (*QueriesListqueriesCall) Do ¶
func (c *QueriesListqueriesCall) Do() (*ListQueriesResponse, error)
func (*QueriesListqueriesCall) Fields ¶
func (c *QueriesListqueriesCall) Fields(s ...googleapi.Field) *QueriesListqueriesCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type QueriesRunqueryCall ¶
type QueriesRunqueryCall struct {
// contains filtered or unexported fields
}
func (*QueriesRunqueryCall) Do ¶
func (c *QueriesRunqueryCall) Do() error
func (*QueriesRunqueryCall) Fields ¶
func (c *QueriesRunqueryCall) Fields(s ...googleapi.Field) *QueriesRunqueryCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type QueriesService ¶
type QueriesService struct {
// contains filtered or unexported fields
}
func NewQueriesService ¶
func NewQueriesService(s *Service) *QueriesService
func (*QueriesService) Createquery ¶
func (r *QueriesService) Createquery(query *Query) *QueriesCreatequeryCall
Createquery: Creates a query.
func (*QueriesService) Deletequery ¶
func (r *QueriesService) Deletequery(queryId int64) *QueriesDeletequeryCall
Deletequery: Deletes a stored query as well as the associated stored reports.
func (*QueriesService) Getquery ¶
func (r *QueriesService) Getquery(queryId int64) *QueriesGetqueryCall
Getquery: Retrieves a stored query.
func (*QueriesService) Listqueries ¶
func (r *QueriesService) Listqueries() *QueriesListqueriesCall
Listqueries: Retrieves stored queries.
func (*QueriesService) Runquery ¶
func (r *QueriesService) Runquery(queryId int64, runqueryrequest *RunQueryRequest) *QueriesRunqueryCall
Runquery: Runs a stored query to generate a report.
type Query ¶
type Query struct {
// Kind: Identifies what kind of resource this is. Value: the fixed
// string "doubleclickbidmanager#query".
Kind string `json:"kind,omitempty"`
// Metadata: Query metadata.
Metadata *QueryMetadata `json:"metadata,omitempty"`
// Params: Query parameters.
Params *Parameters `json:"params,omitempty"`
// QueryId: Query ID.
QueryId int64 `json:"queryId,omitempty,string"`
// ReportDataEndTimeMs: The ending time for the data that is shown in
// the report. Note, reportDataEndTimeMs is required if
// metadata.dataRange is CUSTOM_DATES and ignored otherwise.
ReportDataEndTimeMs int64 `json:"reportDataEndTimeMs,omitempty,string"`
// ReportDataStartTimeMs: The starting time for the data that is shown
// in the report. Note, reportDataStartTimeMs is required if
// metadata.dataRange is CUSTOM_DATES and ignored otherwise.
ReportDataStartTimeMs int64 `json:"reportDataStartTimeMs,omitempty,string"`
// Schedule: Information on how often and when to run a query.
Schedule *QuerySchedule `json:"schedule,omitempty"`
// TimezoneCode: Canonical timezone code for report data time. Defaults
// to America/New_York.
TimezoneCode string `json:"timezoneCode,omitempty"`
}
Query: Represents a query.
type QueryMetadata ¶
type QueryMetadata struct {
// DataRange: Range of report data.
//
// Possible values:
// "ALL_TIME"
// "CURRENT_DAY"
// "CUSTOM_DATES"
// "LAST_14_DAYS"
// "LAST_30_DAYS"
// "LAST_365_DAYS"
// "LAST_7_DAYS"
// "LAST_90_DAYS"
// "MONTH_TO_DATE"
// "PREVIOUS_DAY"
// "PREVIOUS_HALF_MONTH"
// "PREVIOUS_MONTH"
// "PREVIOUS_QUARTER"
// "PREVIOUS_WEEK"
// "PREVIOUS_YEAR"
// "QUARTER_TO_DATE"
// "WEEK_TO_DATE"
// "YEAR_TO_DATE"
DataRange string `json:"dataRange,omitempty"`
// Format: Format of the generated report.
//
// Possible values:
// "CSV"
// "EXCEL_CSV"
// "XLSX"
Format string `json:"format,omitempty"`
// GoogleCloudStoragePathForLatestReport: The path to the location in
// Google Cloud Storage where the latest report is stored.
GoogleCloudStoragePathForLatestReport string `json:"googleCloudStoragePathForLatestReport,omitempty"`
// GoogleDrivePathForLatestReport: The path in Google Drive for the
// latest report.
GoogleDrivePathForLatestReport string `json:"googleDrivePathForLatestReport,omitempty"`
// LatestReportRunTimeMs: The time when the latest report started to
// run.
LatestReportRunTimeMs int64 `json:"latestReportRunTimeMs,omitempty,string"`
// Locale: Locale of the generated reports. Valid values are cs CZECH de
// GERMAN en ENGLISH es SPANISH fr FRENCH it ITALIAN ja JAPANESE ko
// KOREAN pl POLISH pt-BR BRAZILIAN_PORTUGUESE ru RUSSIAN tr TURKISH uk
// UKRAINIAN zh-CN CHINA_CHINESE zh-TW TAIWAN_CHINESE
//
// An locale string not in the list above will generate reports in
// English.
Locale string `json:"locale,omitempty"`
// ReportCount: Number of reports that have been generated for the
// query.
ReportCount int64 `json:"reportCount,omitempty"`
// Running: Whether the latest report is currently running.
Running bool `json:"running,omitempty"`
// SendNotification: Whether to send an email notification when a report
// is ready. Default to false.
SendNotification bool `json:"sendNotification,omitempty"`
// notifications when the report is finished. Separate from
// sendNotification.
ShareEmailAddress []string `json:"shareEmailAddress,omitempty"`
// Title: Query title. It is used to name the reports generated from
// this query.
Title string `json:"title,omitempty"`
}
QueryMetadata: Query metadata.
type QuerySchedule ¶
type QuerySchedule struct {
// EndTimeMs: Datetime to periodically run the query until.
EndTimeMs int64 `json:"endTimeMs,omitempty,string"`
// Frequency: How often the query is run.
//
// Possible values:
// "DAILY"
// "MONTHLY"
// "ONE_TIME"
// "QUARTERLY"
// "SEMI_MONTHLY"
// "WEEKLY"
Frequency string `json:"frequency,omitempty"`
// NextRunMinuteOfDay: Time of day at which a new report will be
// generated, represented as minutes past midnight. Range is 0 to 1439.
// Only applies to scheduled reports.
NextRunMinuteOfDay int64 `json:"nextRunMinuteOfDay,omitempty"`
// NextRunTimezoneCode: Canonical timezone code for report generation
// time. Defaults to America/New_York.
NextRunTimezoneCode string `json:"nextRunTimezoneCode,omitempty"`
}
QuerySchedule: Information on how frequently and when to run a query.
type Report ¶
type Report struct {
// Key: Key used to identify a report.
Key *ReportKey `json:"key,omitempty"`
// Metadata: Report metadata.
Metadata *ReportMetadata `json:"metadata,omitempty"`
// Params: Report parameters.
Params *Parameters `json:"params,omitempty"`
}
Report: Represents a report.
type ReportFailure ¶
type ReportFailure struct {
// ErrorCode: Error code that shows why the report was not created.
//
// Possible values:
// "AUTHENTICATION_ERROR"
// "DEPRECATED_REPORTING_INVALID_QUERY"
// "REPORTING_BUCKET_NOT_FOUND"
// "REPORTING_CREATE_BUCKET_FAILED"
// "REPORTING_DELETE_BUCKET_FAILED"
// "REPORTING_FATAL_ERROR"
// "REPORTING_ILLEGAL_FILENAME"
// "REPORTING_IMCOMPATIBLE_METRICS"
// "REPORTING_INVALID_QUERY_MISSING_PARTNER_AND_ADVERTISER_FILTERS"
// "REPORTING_INVALID_QUERY_TITLE_MISSING"
// "REPORTING_INVALID_QUERY_TOO_MANY_UNFILTERED_LARGE_GROUP_BYS"
// "REPORTING_QUERY_NOT_FOUND"
// "REPORTING_TRANSIENT_ERROR"
// "REPORTING_UPDATE_BUCKET_PERMISSION_FAILED"
// "REPORTING_WRITE_BUCKET_OBJECT_FAILED"
// "SERVER_ERROR"
// "UNAUTHORIZED_API_ACCESS"
// "VALIDATION_ERROR"
ErrorCode string `json:"errorCode,omitempty"`
}
ReportFailure: An explanation of a report failure.
type ReportKey ¶
type ReportKey struct {
// QueryId: Query ID.
QueryId int64 `json:"queryId,omitempty,string"`
// ReportId: Report ID.
ReportId int64 `json:"reportId,omitempty,string"`
}
ReportKey: Key used to identify a report.
type ReportMetadata ¶
type ReportMetadata struct {
// GoogleCloudStoragePath: The path to the location in Google Cloud
// Storage where the report is stored.
GoogleCloudStoragePath string `json:"googleCloudStoragePath,omitempty"`
// ReportDataEndTimeMs: The ending time for the data that is shown in
// the report.
ReportDataEndTimeMs int64 `json:"reportDataEndTimeMs,omitempty,string"`
// ReportDataStartTimeMs: The starting time for the data that is shown
// in the report.
ReportDataStartTimeMs int64 `json:"reportDataStartTimeMs,omitempty,string"`
// Status: Report status.
Status *ReportStatus `json:"status,omitempty"`
}
ReportMetadata: Report metadata.
type ReportStatus ¶
type ReportStatus struct {
// Failure: If the report failed, this records the cause.
Failure *ReportFailure `json:"failure,omitempty"`
// FinishTimeMs: The time when this report either completed successfully
// or failed.
FinishTimeMs int64 `json:"finishTimeMs,omitempty,string"`
// Format: The file type of the report.
//
// Possible values:
// "CSV"
// "EXCEL_CSV"
// "XLSX"
Format string `json:"format,omitempty"`
// State: The state of the report.
//
// Possible values:
// "DONE"
// "FAILED"
// "RUNNING"
State string `json:"state,omitempty"`
}
ReportStatus: Report status.
type ReportsListreportsCall ¶
type ReportsListreportsCall struct {
// contains filtered or unexported fields
}
func (*ReportsListreportsCall) Do ¶
func (c *ReportsListreportsCall) Do() (*ListReportsResponse, error)
func (*ReportsListreportsCall) Fields ¶
func (c *ReportsListreportsCall) Fields(s ...googleapi.Field) *ReportsListreportsCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ReportsService ¶
type ReportsService struct {
// contains filtered or unexported fields
}
func NewReportsService ¶
func NewReportsService(s *Service) *ReportsService
func (*ReportsService) Listreports ¶
func (r *ReportsService) Listreports(queryId int64) *ReportsListreportsCall
Listreports: Retrieves stored reports.
type RowStatus ¶
type RowStatus struct {
// Changed: Whether the stored entity is changed as a result of upload.
Changed bool `json:"changed,omitempty"`
// EntityId: Entity Id.
EntityId int64 `json:"entityId,omitempty,string"`
// EntityName: Entity name.
EntityName string `json:"entityName,omitempty"`
// Errors: Reasons why the entity can't be uploaded.
Errors []string `json:"errors,omitempty"`
// Persisted: Whether the entity is persisted.
Persisted bool `json:"persisted,omitempty"`
// RowNumber: Row number.
RowNumber int64 `json:"rowNumber,omitempty"`
}
RowStatus: Represents the upload status of a row in the request.
type RunQueryRequest ¶
type RunQueryRequest struct {
// DataRange: Report data range used to generate the report.
//
// Possible values:
// "ALL_TIME"
// "CURRENT_DAY"
// "CUSTOM_DATES"
// "LAST_14_DAYS"
// "LAST_30_DAYS"
// "LAST_365_DAYS"
// "LAST_7_DAYS"
// "LAST_90_DAYS"
// "MONTH_TO_DATE"
// "PREVIOUS_DAY"
// "PREVIOUS_HALF_MONTH"
// "PREVIOUS_MONTH"
// "PREVIOUS_QUARTER"
// "PREVIOUS_WEEK"
// "PREVIOUS_YEAR"
// "QUARTER_TO_DATE"
// "WEEK_TO_DATE"
// "YEAR_TO_DATE"
DataRange string `json:"dataRange,omitempty"`
// ReportDataEndTimeMs: The ending time for the data that is shown in
// the report. Note, reportDataEndTimeMs is required if dataRange is
// CUSTOM_DATES and ignored otherwise.
ReportDataEndTimeMs int64 `json:"reportDataEndTimeMs,omitempty,string"`
// ReportDataStartTimeMs: The starting time for the data that is shown
// in the report. Note, reportDataStartTimeMs is required if dataRange
// is CUSTOM_DATES and ignored otherwise.
ReportDataStartTimeMs int64 `json:"reportDataStartTimeMs,omitempty,string"`
// TimezoneCode: Canonical timezone code for report data time. Defaults
// to America/New_York.
TimezoneCode string `json:"timezoneCode,omitempty"`
}
RunQueryRequest: Request to run a stored query to generate a report.
type Service ¶
type Service struct {
BasePath string // API endpoint base URL
UserAgent string // optional additional User-Agent fragment
Lineitems *LineitemsService
Queries *QueriesService
Reports *ReportsService
// contains filtered or unexported fields
}
type UploadLineItemsRequest ¶
type UploadLineItemsRequest struct {
// DryRun: Set to true to get upload status without actually persisting
// the line items.
DryRun bool `json:"dryRun,omitempty"`
// Format: Format the line items are in. Default to CSV.
//
// Possible values:
// "CSV"
Format string `json:"format,omitempty"`
// LineItems: Line items in CSV to upload. Refer to Entity Write File
// Format for more information on file format.
LineItems string `json:"lineItems,omitempty"`
}
UploadLineItemsRequest: Request to upload line items.
type UploadLineItemsResponse ¶
type UploadLineItemsResponse struct {
// UploadStatus: Status of upload.
UploadStatus *UploadStatus `json:"uploadStatus,omitempty"`
}
UploadLineItemsResponse: Upload line items response.
type UploadStatus ¶
type UploadStatus struct {
// Errors: Reasons why upload can't be completed.
Errors []string `json:"errors,omitempty"`
// RowStatus: Per-row upload status.
RowStatus []*RowStatus `json:"rowStatus,omitempty"`
}
UploadStatus: Represents the status of upload.