Documentation
¶
Overview ¶
Package identitytoolkit provides access to the Google Identity Toolkit API.
See https://developers.google.com/identity-toolkit/v3/
Usage example:
import "google.golang.org/api/identitytoolkit/v3" ... identitytoolkitService, err := identitytoolkit.New(oauthHttpClient)
Index ¶
- type CreateAuthUriResponse
- type DeleteAccountResponse
- type DownloadAccountResponse
- type GetAccountInfoResponse
- type GetOobConfirmationCodeResponse
- type GetRecaptchaParamResponse
- type IdentitytoolkitRelyingpartyCreateAuthUriRequest
- type IdentitytoolkitRelyingpartyDeleteAccountRequest
- type IdentitytoolkitRelyingpartyDownloadAccountRequest
- type IdentitytoolkitRelyingpartyGetAccountInfoRequest
- type IdentitytoolkitRelyingpartyResetPasswordRequest
- type IdentitytoolkitRelyingpartySetAccountInfoRequest
- type IdentitytoolkitRelyingpartyUploadAccountRequest
- type IdentitytoolkitRelyingpartyVerifyAssertionRequest
- type IdentitytoolkitRelyingpartyVerifyPasswordRequest
- type Relyingparty
- type RelyingpartyCreateAuthUriCall
- type RelyingpartyDeleteAccountCall
- type RelyingpartyDownloadAccountCall
- type RelyingpartyGetAccountInfoCall
- type RelyingpartyGetOobConfirmationCodeCall
- type RelyingpartyGetPublicKeysCall
- type RelyingpartyGetRecaptchaParamCall
- type RelyingpartyResetPasswordCall
- type RelyingpartyService
- func (r *RelyingpartyService) CreateAuthUri(...) *RelyingpartyCreateAuthUriCall
- func (r *RelyingpartyService) DeleteAccount(...) *RelyingpartyDeleteAccountCall
- func (r *RelyingpartyService) DownloadAccount(...) *RelyingpartyDownloadAccountCall
- func (r *RelyingpartyService) GetAccountInfo(...) *RelyingpartyGetAccountInfoCall
- func (r *RelyingpartyService) GetOobConfirmationCode(relyingparty *Relyingparty) *RelyingpartyGetOobConfirmationCodeCall
- func (r *RelyingpartyService) GetPublicKeys() *RelyingpartyGetPublicKeysCall
- func (r *RelyingpartyService) GetRecaptchaParam() *RelyingpartyGetRecaptchaParamCall
- func (r *RelyingpartyService) ResetPassword(...) *RelyingpartyResetPasswordCall
- func (r *RelyingpartyService) SetAccountInfo(...) *RelyingpartySetAccountInfoCall
- func (r *RelyingpartyService) UploadAccount(...) *RelyingpartyUploadAccountCall
- func (r *RelyingpartyService) VerifyAssertion(...) *RelyingpartyVerifyAssertionCall
- func (r *RelyingpartyService) VerifyPassword(...) *RelyingpartyVerifyPasswordCall
- type RelyingpartySetAccountInfoCall
- type RelyingpartyUploadAccountCall
- type RelyingpartyVerifyAssertionCall
- type RelyingpartyVerifyPasswordCall
- type ResetPasswordResponse
- type Service
- type SetAccountInfoResponse
- type SetAccountInfoResponseProviderUserInfo
- type UploadAccountResponse
- type UploadAccountResponseError
- type UserInfo
- type UserInfoProviderUserInfo
- type VerifyAssertionResponse
- type VerifyPasswordResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateAuthUriResponse ¶
type CreateAuthUriResponse struct {
// AuthUri: The URI used by the IDP to authenticate the user.
AuthUri string `json:"authUri,omitempty"`
// CaptchaRequired: True if captcha is required.
CaptchaRequired bool `json:"captchaRequired,omitempty"`
// ForExistingProvider: True if the authUri is for user's existing
// provider.
ForExistingProvider bool `json:"forExistingProvider,omitempty"`
// Kind: The fixed string identitytoolkit#CreateAuthUriResponse".
Kind string `json:"kind,omitempty"`
// ProviderId: The provider ID of the auth URI.
ProviderId string `json:"providerId,omitempty"`
// Registered: Whether the user is registered if the identifier is an
// email.
Registered bool `json:"registered,omitempty"`
}
CreateAuthUriResponse: Response of creating the IDP authentication URL.
type DeleteAccountResponse ¶
type DeleteAccountResponse struct {
// Kind: The fixed string "identitytoolkit#DeleteAccountResponse".
Kind string `json:"kind,omitempty"`
}
DeleteAccountResponse: Respone of deleting account.
type DownloadAccountResponse ¶
type DownloadAccountResponse struct {
// Kind: The fixed string "identitytoolkit#DownloadAccountResponse".
Kind string `json:"kind,omitempty"`
// NextPageToken: The next page token. To be used in a subsequent
// request to return the next page of results.
NextPageToken string `json:"nextPageToken,omitempty"`
// Users: The user accounts data.
Users []*UserInfo `json:"users,omitempty"`
}
DownloadAccountResponse: Respone of downloading accounts in batch.
type GetAccountInfoResponse ¶
type GetAccountInfoResponse struct {
// Kind: The fixed string "identitytoolkit#GetAccountInfoResponse".
Kind string `json:"kind,omitempty"`
// Users: The info of the users.
Users []*UserInfo `json:"users,omitempty"`
}
GetAccountInfoResponse: Response of getting account information.
type GetOobConfirmationCodeResponse ¶
type GetOobConfirmationCodeResponse struct {
// Kind: The fixed string
// "identitytoolkit#GetOobConfirmationCodeResponse".
Kind string `json:"kind,omitempty"`
// OobCode: The code to be send to the user.
OobCode string `json:"oobCode,omitempty"`
}
GetOobConfirmationCodeResponse: Response of getting a code for user confirmation (reset password, change email etc.).
type GetRecaptchaParamResponse ¶
type GetRecaptchaParamResponse struct {
// Kind: The fixed string "identitytoolkit#GetRecaptchaParamResponse".
Kind string `json:"kind,omitempty"`
// RecaptchaSiteKey: Site key registered at recaptcha.
RecaptchaSiteKey string `json:"recaptchaSiteKey,omitempty"`
// RecaptchaStoken: The stoken field for the recaptcha widget, used to
// request captcha challenge.
RecaptchaStoken string `json:"recaptchaStoken,omitempty"`
}
GetRecaptchaParamResponse: Response of getting recaptcha param.
type IdentitytoolkitRelyingpartyCreateAuthUriRequest ¶
type IdentitytoolkitRelyingpartyCreateAuthUriRequest struct {
// AppId: The app ID of the mobile app, base64(CERT_SHA1):PACKAGE_NAME
// for Android, BUNDLE_ID for iOS.
AppId string `json:"appId,omitempty"`
// ClientId: The relying party OAuth client ID.
ClientId string `json:"clientId,omitempty"`
// Context: The opaque value used by the client to maintain context info
// between the authentication request and the IDP callback.
Context string `json:"context,omitempty"`
// ContinueUri: The URI to which the IDP redirects the user after the
// federated login flow.
ContinueUri string `json:"continueUri,omitempty"`
// Identifier: The email or federated ID of the user.
Identifier string `json:"identifier,omitempty"`
// OauthConsumerKey: The developer's consumer key for OpenId OAuth
// Extension
OauthConsumerKey string `json:"oauthConsumerKey,omitempty"`
// OauthScope: Additional oauth scopes, beyond the basid user profile,
// that the user would be prompted to grant
OauthScope string `json:"oauthScope,omitempty"`
// OpenidRealm: Optional realm for OpenID protocol. The sub string
// "scheme://domain:port" of the param "continueUri" is used if this is
// not set.
OpenidRealm string `json:"openidRealm,omitempty"`
// OtaApp: The native app package for OTA installation.
OtaApp string `json:"otaApp,omitempty"`
// ProviderId: The IdP ID. For white listed IdPs it's a short domain
// name e.g. google.com, aol.com, live.net and yahoo.com. For other
// OpenID IdPs it's the OP identifier.
ProviderId string `json:"providerId,omitempty"`
}
IdentitytoolkitRelyingpartyCreateAuthUriRequest: Request to get the IDP authentication URL.
type IdentitytoolkitRelyingpartyDeleteAccountRequest ¶
type IdentitytoolkitRelyingpartyDeleteAccountRequest struct {
// LocalId: The local ID of the user.
LocalId string `json:"localId,omitempty"`
}
IdentitytoolkitRelyingpartyDeleteAccountRequest: Request to delete account.
type IdentitytoolkitRelyingpartyDownloadAccountRequest ¶
type IdentitytoolkitRelyingpartyDownloadAccountRequest struct {
// MaxResults: The max number of results to return in the response.
MaxResults int64 `json:"maxResults,omitempty"`
// NextPageToken: The token for the next page. This should be taken from
// the previous response.
NextPageToken string `json:"nextPageToken,omitempty"`
}
IdentitytoolkitRelyingpartyDownloadAccountRequest: Request to download user account in batch.
type IdentitytoolkitRelyingpartyGetAccountInfoRequest ¶
type IdentitytoolkitRelyingpartyGetAccountInfoRequest struct {
// Email: The list of emails of the users to inquiry.
Email []string `json:"email,omitempty"`
// IdToken: The GITKit token of the authenticated user.
IdToken string `json:"idToken,omitempty"`
// LocalId: The list of local ID's of the users to inquiry.
LocalId []string `json:"localId,omitempty"`
}
IdentitytoolkitRelyingpartyGetAccountInfoRequest: Request to get the account information.
type IdentitytoolkitRelyingpartyResetPasswordRequest ¶
type IdentitytoolkitRelyingpartyResetPasswordRequest struct {
// Email: The email address of the user.
Email string `json:"email,omitempty"`
// NewPassword: The new password inputted by the user.
NewPassword string `json:"newPassword,omitempty"`
// OldPassword: The old password inputted by the user.
OldPassword string `json:"oldPassword,omitempty"`
// OobCode: The confirmation code.
OobCode string `json:"oobCode,omitempty"`
}
IdentitytoolkitRelyingpartyResetPasswordRequest: Request to reset the password.
type IdentitytoolkitRelyingpartySetAccountInfoRequest ¶
type IdentitytoolkitRelyingpartySetAccountInfoRequest struct {
// CaptchaChallenge: The captcha challenge.
CaptchaChallenge string `json:"captchaChallenge,omitempty"`
// CaptchaResponse: Response to the captcha.
CaptchaResponse string `json:"captchaResponse,omitempty"`
// DisableUser: Whether to disable the user.
DisableUser bool `json:"disableUser,omitempty"`
// DisplayName: The name of the user.
DisplayName string `json:"displayName,omitempty"`
// Email: The email of the user.
Email string `json:"email,omitempty"`
// EmailVerified: Mark the email as verified or not.
EmailVerified bool `json:"emailVerified,omitempty"`
// IdToken: The GITKit token of the authenticated user.
IdToken string `json:"idToken,omitempty"`
// LocalId: The local ID of the user.
LocalId string `json:"localId,omitempty"`
// OobCode: The out-of-band code of the change email request.
OobCode string `json:"oobCode,omitempty"`
// Password: The new password of the user.
Password string `json:"password,omitempty"`
// Provider: The associated IDPs of the user.
Provider []string `json:"provider,omitempty"`
// UpgradeToFederatedLogin: Mark the user to upgrade to federated login.
UpgradeToFederatedLogin bool `json:"upgradeToFederatedLogin,omitempty"`
// ValidSince: Timestamp in seconds for valid login token.
ValidSince int64 `json:"validSince,omitempty,string"`
}
IdentitytoolkitRelyingpartySetAccountInfoRequest: Request to set the account information.
type IdentitytoolkitRelyingpartyUploadAccountRequest ¶
type IdentitytoolkitRelyingpartyUploadAccountRequest struct {
// HashAlgorithm: The password hash algorithm.
HashAlgorithm string `json:"hashAlgorithm,omitempty"`
// MemoryCost: Memory cost for hash calculation. Used by scrypt similar
// algorithms.
MemoryCost int64 `json:"memoryCost,omitempty"`
// Rounds: Rounds for hash calculation. Used by scrypt and similar
// algorithms.
Rounds int64 `json:"rounds,omitempty"`
// SaltSeparator: The salt separator.
SaltSeparator string `json:"saltSeparator,omitempty"`
// SignerKey: The key for to hash the password.
SignerKey string `json:"signerKey,omitempty"`
// Users: The account info to be stored.
Users []*UserInfo `json:"users,omitempty"`
}
IdentitytoolkitRelyingpartyUploadAccountRequest: Request to upload user account in batch.
type IdentitytoolkitRelyingpartyVerifyAssertionRequest ¶
type IdentitytoolkitRelyingpartyVerifyAssertionRequest struct {
// PendingIdToken: The GITKit token for the non-trusted IDP pending to
// be confirmed by the user.
PendingIdToken string `json:"pendingIdToken,omitempty"`
// PostBody: The post body if the request is a HTTP POST.
PostBody string `json:"postBody,omitempty"`
// RequestUri: The URI to which the IDP redirects the user back. It may
// contain federated login result params added by the IDP.
RequestUri string `json:"requestUri,omitempty"`
// ReturnRefreshToken: Whether to return refresh tokens.
ReturnRefreshToken bool `json:"returnRefreshToken,omitempty"`
}
IdentitytoolkitRelyingpartyVerifyAssertionRequest: Request to verify the IDP assertion.
type IdentitytoolkitRelyingpartyVerifyPasswordRequest ¶
type IdentitytoolkitRelyingpartyVerifyPasswordRequest struct {
// CaptchaChallenge: The captcha challenge.
CaptchaChallenge string `json:"captchaChallenge,omitempty"`
// CaptchaResponse: Response to the captcha.
CaptchaResponse string `json:"captchaResponse,omitempty"`
// Email: The email of the user.
Email string `json:"email,omitempty"`
// Password: The password inputed by the user.
Password string `json:"password,omitempty"`
// PendingIdToken: The GITKit token for the non-trusted IDP, which is to
// be confirmed by the user.
PendingIdToken string `json:"pendingIdToken,omitempty"`
}
IdentitytoolkitRelyingpartyVerifyPasswordRequest: Request to verify the password.
type Relyingparty ¶
type Relyingparty struct {
// CaptchaResp: The recaptcha response from the user.
CaptchaResp string `json:"captchaResp,omitempty"`
// Challenge: The recaptcha challenge presented to the user.
Challenge string `json:"challenge,omitempty"`
// Email: The email of the user.
Email string `json:"email,omitempty"`
// IdToken: The user's Gitkit login token for email change.
IdToken string `json:"idToken,omitempty"`
// Kind: The fixed string "identitytoolkit#relyingparty".
Kind string `json:"kind,omitempty"`
// NewEmail: The new email if the code is for email change.
NewEmail string `json:"newEmail,omitempty"`
// RequestType: The request type.
RequestType string `json:"requestType,omitempty"`
// UserIp: The IP address of the user.
UserIp string `json:"userIp,omitempty"`
}
Relyingparty: Request of getting a code for user confirmation (reset password, change email etc.)
type RelyingpartyCreateAuthUriCall ¶
type RelyingpartyCreateAuthUriCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyCreateAuthUriCall) Do ¶
func (c *RelyingpartyCreateAuthUriCall) Do() (*CreateAuthUriResponse, error)
func (*RelyingpartyCreateAuthUriCall) Fields ¶
func (c *RelyingpartyCreateAuthUriCall) Fields(s ...googleapi.Field) *RelyingpartyCreateAuthUriCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyDeleteAccountCall ¶
type RelyingpartyDeleteAccountCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyDeleteAccountCall) Do ¶
func (c *RelyingpartyDeleteAccountCall) Do() (*DeleteAccountResponse, error)
func (*RelyingpartyDeleteAccountCall) Fields ¶
func (c *RelyingpartyDeleteAccountCall) Fields(s ...googleapi.Field) *RelyingpartyDeleteAccountCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyDownloadAccountCall ¶
type RelyingpartyDownloadAccountCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyDownloadAccountCall) Do ¶
func (c *RelyingpartyDownloadAccountCall) Do() (*DownloadAccountResponse, error)
func (*RelyingpartyDownloadAccountCall) Fields ¶
func (c *RelyingpartyDownloadAccountCall) Fields(s ...googleapi.Field) *RelyingpartyDownloadAccountCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyGetAccountInfoCall ¶
type RelyingpartyGetAccountInfoCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyGetAccountInfoCall) Do ¶
func (c *RelyingpartyGetAccountInfoCall) Do() (*GetAccountInfoResponse, error)
func (*RelyingpartyGetAccountInfoCall) Fields ¶
func (c *RelyingpartyGetAccountInfoCall) Fields(s ...googleapi.Field) *RelyingpartyGetAccountInfoCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyGetOobConfirmationCodeCall ¶
type RelyingpartyGetOobConfirmationCodeCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyGetOobConfirmationCodeCall) Do ¶
func (c *RelyingpartyGetOobConfirmationCodeCall) Do() (*GetOobConfirmationCodeResponse, error)
func (*RelyingpartyGetOobConfirmationCodeCall) Fields ¶
func (c *RelyingpartyGetOobConfirmationCodeCall) Fields(s ...googleapi.Field) *RelyingpartyGetOobConfirmationCodeCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyGetPublicKeysCall ¶
type RelyingpartyGetPublicKeysCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyGetPublicKeysCall) Do ¶
func (c *RelyingpartyGetPublicKeysCall) Do() (map[string]string, error)
func (*RelyingpartyGetPublicKeysCall) Fields ¶
func (c *RelyingpartyGetPublicKeysCall) Fields(s ...googleapi.Field) *RelyingpartyGetPublicKeysCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyGetRecaptchaParamCall ¶
type RelyingpartyGetRecaptchaParamCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyGetRecaptchaParamCall) Do ¶
func (c *RelyingpartyGetRecaptchaParamCall) Do() (*GetRecaptchaParamResponse, error)
func (*RelyingpartyGetRecaptchaParamCall) Fields ¶
func (c *RelyingpartyGetRecaptchaParamCall) Fields(s ...googleapi.Field) *RelyingpartyGetRecaptchaParamCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyResetPasswordCall ¶
type RelyingpartyResetPasswordCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyResetPasswordCall) Do ¶
func (c *RelyingpartyResetPasswordCall) Do() (*ResetPasswordResponse, error)
func (*RelyingpartyResetPasswordCall) Fields ¶
func (c *RelyingpartyResetPasswordCall) Fields(s ...googleapi.Field) *RelyingpartyResetPasswordCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyService ¶
type RelyingpartyService struct {
// contains filtered or unexported fields
}
func NewRelyingpartyService ¶
func NewRelyingpartyService(s *Service) *RelyingpartyService
func (*RelyingpartyService) CreateAuthUri ¶
func (r *RelyingpartyService) CreateAuthUri(identitytoolkitrelyingpartycreateauthurirequest *IdentitytoolkitRelyingpartyCreateAuthUriRequest) *RelyingpartyCreateAuthUriCall
CreateAuthUri: Creates the URI used by the IdP to authenticate the user.
func (*RelyingpartyService) DeleteAccount ¶
func (r *RelyingpartyService) DeleteAccount(identitytoolkitrelyingpartydeleteaccountrequest *IdentitytoolkitRelyingpartyDeleteAccountRequest) *RelyingpartyDeleteAccountCall
DeleteAccount: Delete user account.
func (*RelyingpartyService) DownloadAccount ¶
func (r *RelyingpartyService) DownloadAccount(identitytoolkitrelyingpartydownloadaccountrequest *IdentitytoolkitRelyingpartyDownloadAccountRequest) *RelyingpartyDownloadAccountCall
DownloadAccount: Batch download user accounts.
func (*RelyingpartyService) GetAccountInfo ¶
func (r *RelyingpartyService) GetAccountInfo(identitytoolkitrelyingpartygetaccountinforequest *IdentitytoolkitRelyingpartyGetAccountInfoRequest) *RelyingpartyGetAccountInfoCall
GetAccountInfo: Returns the account info.
func (*RelyingpartyService) GetOobConfirmationCode ¶
func (r *RelyingpartyService) GetOobConfirmationCode(relyingparty *Relyingparty) *RelyingpartyGetOobConfirmationCodeCall
GetOobConfirmationCode: Get a code for user action confirmation.
func (*RelyingpartyService) GetPublicKeys ¶
func (r *RelyingpartyService) GetPublicKeys() *RelyingpartyGetPublicKeysCall
GetPublicKeys: Get token signing public key.
func (*RelyingpartyService) GetRecaptchaParam ¶
func (r *RelyingpartyService) GetRecaptchaParam() *RelyingpartyGetRecaptchaParamCall
GetRecaptchaParam: Get recaptcha secure param.
func (*RelyingpartyService) ResetPassword ¶
func (r *RelyingpartyService) ResetPassword(identitytoolkitrelyingpartyresetpasswordrequest *IdentitytoolkitRelyingpartyResetPasswordRequest) *RelyingpartyResetPasswordCall
ResetPassword: Reset password for a user.
func (*RelyingpartyService) SetAccountInfo ¶
func (r *RelyingpartyService) SetAccountInfo(identitytoolkitrelyingpartysetaccountinforequest *IdentitytoolkitRelyingpartySetAccountInfoRequest) *RelyingpartySetAccountInfoCall
SetAccountInfo: Set account info for a user.
func (*RelyingpartyService) UploadAccount ¶
func (r *RelyingpartyService) UploadAccount(identitytoolkitrelyingpartyuploadaccountrequest *IdentitytoolkitRelyingpartyUploadAccountRequest) *RelyingpartyUploadAccountCall
UploadAccount: Batch upload existing user accounts.
func (*RelyingpartyService) VerifyAssertion ¶
func (r *RelyingpartyService) VerifyAssertion(identitytoolkitrelyingpartyverifyassertionrequest *IdentitytoolkitRelyingpartyVerifyAssertionRequest) *RelyingpartyVerifyAssertionCall
VerifyAssertion: Verifies the assertion returned by the IdP.
func (*RelyingpartyService) VerifyPassword ¶
func (r *RelyingpartyService) VerifyPassword(identitytoolkitrelyingpartyverifypasswordrequest *IdentitytoolkitRelyingpartyVerifyPasswordRequest) *RelyingpartyVerifyPasswordCall
VerifyPassword: Verifies the user entered password.
type RelyingpartySetAccountInfoCall ¶
type RelyingpartySetAccountInfoCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartySetAccountInfoCall) Do ¶
func (c *RelyingpartySetAccountInfoCall) Do() (*SetAccountInfoResponse, error)
func (*RelyingpartySetAccountInfoCall) Fields ¶
func (c *RelyingpartySetAccountInfoCall) Fields(s ...googleapi.Field) *RelyingpartySetAccountInfoCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyUploadAccountCall ¶
type RelyingpartyUploadAccountCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyUploadAccountCall) Do ¶
func (c *RelyingpartyUploadAccountCall) Do() (*UploadAccountResponse, error)
func (*RelyingpartyUploadAccountCall) Fields ¶
func (c *RelyingpartyUploadAccountCall) Fields(s ...googleapi.Field) *RelyingpartyUploadAccountCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyVerifyAssertionCall ¶
type RelyingpartyVerifyAssertionCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyVerifyAssertionCall) Do ¶
func (c *RelyingpartyVerifyAssertionCall) Do() (*VerifyAssertionResponse, error)
func (*RelyingpartyVerifyAssertionCall) Fields ¶
func (c *RelyingpartyVerifyAssertionCall) Fields(s ...googleapi.Field) *RelyingpartyVerifyAssertionCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type RelyingpartyVerifyPasswordCall ¶
type RelyingpartyVerifyPasswordCall struct {
// contains filtered or unexported fields
}
func (*RelyingpartyVerifyPasswordCall) Do ¶
func (c *RelyingpartyVerifyPasswordCall) Do() (*VerifyPasswordResponse, error)
func (*RelyingpartyVerifyPasswordCall) Fields ¶
func (c *RelyingpartyVerifyPasswordCall) Fields(s ...googleapi.Field) *RelyingpartyVerifyPasswordCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type ResetPasswordResponse ¶
type ResetPasswordResponse struct {
// Email: The user's email.
Email string `json:"email,omitempty"`
// Kind: The fixed string "identitytoolkit#ResetPasswordResponse".
Kind string `json:"kind,omitempty"`
}
ResetPasswordResponse: Response of resetting the password.
type Service ¶
type Service struct {
BasePath string // API endpoint base URL
UserAgent string // optional additional User-Agent fragment
Relyingparty *RelyingpartyService
// contains filtered or unexported fields
}
type SetAccountInfoResponse ¶
type SetAccountInfoResponse struct {
// DisplayName: The name of the user.
DisplayName string `json:"displayName,omitempty"`
// Email: The email of the user.
Email string `json:"email,omitempty"`
// IdToken: The Gitkit id token to login the newly sign up user.
IdToken string `json:"idToken,omitempty"`
// Kind: The fixed string "identitytoolkit#SetAccountInfoResponse".
Kind string `json:"kind,omitempty"`
// NewEmail: The new email the user attempts to change to.
NewEmail string `json:"newEmail,omitempty"`
// ProviderUserInfo: The user's profiles at the associated IdPs.
ProviderUserInfo []*SetAccountInfoResponseProviderUserInfo `json:"providerUserInfo,omitempty"`
}
SetAccountInfoResponse: Respone of setting the account information.
type SetAccountInfoResponseProviderUserInfo ¶
type SetAccountInfoResponseProviderUserInfo struct {
// DisplayName: The user's display name at the IDP.
DisplayName string `json:"displayName,omitempty"`
// PhotoUrl: The user's photo url at the IDP.
PhotoUrl string `json:"photoUrl,omitempty"`
// ProviderId: The IdP ID. For whitelisted IdPs it's a short domain
// name, e.g., google.com, aol.com, live.net and yahoo.com. For other
// OpenID IdPs it's the OP identifier.
ProviderId string `json:"providerId,omitempty"`
}
type UploadAccountResponse ¶
type UploadAccountResponse struct {
// Error: The error encountered while processing the account info.
Error []*UploadAccountResponseError `json:"error,omitempty"`
// Kind: The fixed string "identitytoolkit#UploadAccountResponse".
Kind string `json:"kind,omitempty"`
}
UploadAccountResponse: Respone of uploading accounts in batch.
type UserInfo ¶
type UserInfo struct {
// Disabled: Whether the user is disabled.
Disabled bool `json:"disabled,omitempty"`
// DisplayName: The name of the user.
DisplayName string `json:"displayName,omitempty"`
// Email: The email of the user.
Email string `json:"email,omitempty"`
// EmailVerified: Whether the email has been verified.
EmailVerified bool `json:"emailVerified,omitempty"`
// LocalId: The local ID of the user.
LocalId string `json:"localId,omitempty"`
// PasswordHash: The user's hashed password.
PasswordHash string `json:"passwordHash,omitempty"`
// PasswordUpdatedAt: The timestamp when the password was last updated.
PasswordUpdatedAt float64 `json:"passwordUpdatedAt,omitempty"`
// PhotoUrl: The URL of the user profile photo.
PhotoUrl string `json:"photoUrl,omitempty"`
// ProviderUserInfo: The IDP of the user.
ProviderUserInfo []*UserInfoProviderUserInfo `json:"providerUserInfo,omitempty"`
// Salt: The user's password salt.
Salt string `json:"salt,omitempty"`
// ValidSince: Timestamp in seconds for valid login token.
ValidSince int64 `json:"validSince,omitempty,string"`
// Version: Version of the user's password.
Version int64 `json:"version,omitempty"`
}
UserInfo: Template for an individual account info.
type UserInfoProviderUserInfo ¶
type UserInfoProviderUserInfo struct {
// DisplayName: The user's display name at the IDP.
DisplayName string `json:"displayName,omitempty"`
// FederatedId: User's identifier at IDP.
FederatedId string `json:"federatedId,omitempty"`
// PhotoUrl: The user's photo url at the IDP.
PhotoUrl string `json:"photoUrl,omitempty"`
// ProviderId: The IdP ID. For white listed IdPs it's a short domain
// name, e.g., google.com, aol.com, live.net and yahoo.com. For other
// OpenID IdPs it's the OP identifier.
ProviderId string `json:"providerId,omitempty"`
}
type VerifyAssertionResponse ¶
type VerifyAssertionResponse struct {
// Action: The action code.
Action string `json:"action,omitempty"`
// AppInstallationUrl: URL for OTA app installation.
AppInstallationUrl string `json:"appInstallationUrl,omitempty"`
// AppScheme: The custom scheme used by mobile app.
AppScheme string `json:"appScheme,omitempty"`
// Context: The opaque value used by the client to maintain context info
// between the authentication request and the IDP callback.
Context string `json:"context,omitempty"`
// DateOfBirth: The birth date of the IdP account.
DateOfBirth string `json:"dateOfBirth,omitempty"`
// DisplayName: The display name of the user.
DisplayName string `json:"displayName,omitempty"`
// Email: The email returned by the IdP. NOTE: The federated login user
// may not own the email.
Email string `json:"email,omitempty"`
// EmailRecycled: It's true if the email is recycled.
EmailRecycled bool `json:"emailRecycled,omitempty"`
// EmailVerified: The value is true if the IDP is also the email
// provider. It means the user owns the email.
EmailVerified bool `json:"emailVerified,omitempty"`
// FederatedId: The unique ID identifies the IdP account.
FederatedId string `json:"federatedId,omitempty"`
// FirstName: The first name of the user.
FirstName string `json:"firstName,omitempty"`
// FullName: The full name of the user.
FullName string `json:"fullName,omitempty"`
// IdToken: The ID token.
IdToken string `json:"idToken,omitempty"`
// InputEmail: It's the identifier param in the createAuthUri request if
// the identifier is an email. It can be used to check whether the user
// input email is different from the asserted email.
InputEmail string `json:"inputEmail,omitempty"`
// Kind: The fixed string "identitytoolkit#VerifyAssertionResponse".
Kind string `json:"kind,omitempty"`
// Language: The language preference of the user.
Language string `json:"language,omitempty"`
// LastName: The last name of the user.
LastName string `json:"lastName,omitempty"`
// LocalId: The RP local ID if it's already been mapped to the IdP
// account identified by the federated ID.
LocalId string `json:"localId,omitempty"`
// NeedConfirmation: Whether the assertion is from a non-trusted IDP and
// need account linking confirmation.
NeedConfirmation bool `json:"needConfirmation,omitempty"`
// NickName: The nick name of the user.
NickName string `json:"nickName,omitempty"`
// OauthAccessToken: The OAuth2 access token.
OauthAccessToken string `json:"oauthAccessToken,omitempty"`
// OauthAuthorizationCode: The OAuth2 authorization code.
OauthAuthorizationCode string `json:"oauthAuthorizationCode,omitempty"`
// OauthExpireIn: The lifetime in seconds of the OAuth2 access token.
OauthExpireIn int64 `json:"oauthExpireIn,omitempty"`
// OauthRequestToken: The user approved request token for the OpenID
// OAuth extension.
OauthRequestToken string `json:"oauthRequestToken,omitempty"`
// OauthScope: The scope for the OpenID OAuth extension.
OauthScope string `json:"oauthScope,omitempty"`
// OriginalEmail: The original email stored in the mapping storage. It's
// returned when the federated ID is associated to a different email.
OriginalEmail string `json:"originalEmail,omitempty"`
// PhotoUrl: The URI of the public accessible profiel picture.
PhotoUrl string `json:"photoUrl,omitempty"`
// ProviderId: The IdP ID. For white listed IdPs it's a short domain
// name e.g. google.com, aol.com, live.net and yahoo.com. If the
// "providerId" param is set to OpenID OP identifer other than the
// whilte listed IdPs the OP identifier is returned. If the "identifier"
// param is federated ID in the createAuthUri request. The domain part
// of the federated ID is returned.
ProviderId string `json:"providerId,omitempty"`
// TimeZone: The timezone of the user.
TimeZone string `json:"timeZone,omitempty"`
// VerifiedProvider: When action is 'map', contains the idps which can
// be used for confirmation.
VerifiedProvider []string `json:"verifiedProvider,omitempty"`
}
VerifyAssertionResponse: Response of verifying the IDP assertion.
type VerifyPasswordResponse ¶
type VerifyPasswordResponse struct {
// DisplayName: The name of the user.
DisplayName string `json:"displayName,omitempty"`
// Email: The email returned by the IdP. NOTE: The federated login user
// may not own the email.
Email string `json:"email,omitempty"`
// IdToken: The GITKit token for authenticated user.
IdToken string `json:"idToken,omitempty"`
// Kind: The fixed string "identitytoolkit#VerifyPasswordResponse".
Kind string `json:"kind,omitempty"`
// LocalId: The RP local ID if it's already been mapped to the IdP
// account identified by the federated ID.
LocalId string `json:"localId,omitempty"`
// OauthAccessToken: The OAuth2 access token.
OauthAccessToken string `json:"oauthAccessToken,omitempty"`
// OauthAuthorizationCode: The OAuth2 authorization code.
OauthAuthorizationCode string `json:"oauthAuthorizationCode,omitempty"`
// OauthExpireIn: The lifetime in seconds of the OAuth2 access token.
OauthExpireIn int64 `json:"oauthExpireIn,omitempty"`
// PhotoUrl: The URI of the user's photo at IdP
PhotoUrl string `json:"photoUrl,omitempty"`
// Registered: Whether the email is registered.
Registered bool `json:"registered,omitempty"`
}
VerifyPasswordResponse: Request of verifying the password.