Documentation
¶
Overview ¶
Package pagespeedonline provides access to the PageSpeed Insights API.
See https://developers.google.com/speed/docs/insights/v2/getting-started
Usage example:
import "google.golang.org/api/pagespeedonline/v2" ... pagespeedonlineService, err := pagespeedonline.New(oauthHttpClient)
Index ¶
- type PagespeedApiFormatStringV2
- type PagespeedApiFormatStringV2Args
- type PagespeedApiFormatStringV2ArgsRects
- type PagespeedApiFormatStringV2ArgsSecondaryRects
- type PagespeedApiImageV2
- type PagespeedApiImageV2PageRect
- type PagespeedapiRunpagespeedCall
- func (c *PagespeedapiRunpagespeedCall) Do() (*Result, error)
- func (c *PagespeedapiRunpagespeedCall) Fields(s ...googleapi.Field) *PagespeedapiRunpagespeedCall
- func (c *PagespeedapiRunpagespeedCall) FilterThirdPartyResources(filterThirdPartyResources bool) *PagespeedapiRunpagespeedCall
- func (c *PagespeedapiRunpagespeedCall) Locale(locale string) *PagespeedapiRunpagespeedCall
- func (c *PagespeedapiRunpagespeedCall) Rule(rule string) *PagespeedapiRunpagespeedCall
- func (c *PagespeedapiRunpagespeedCall) Screenshot(screenshot bool) *PagespeedapiRunpagespeedCall
- func (c *PagespeedapiRunpagespeedCall) Strategy(strategy string) *PagespeedapiRunpagespeedCall
- type PagespeedapiService
- type Result
- type ResultFormattedResults
- type ResultFormattedResultsRuleResults
- type ResultPageStats
- type ResultRuleGroups
- type ResultVersion
- type Service
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PagespeedApiFormatStringV2 ¶
type PagespeedApiFormatStringV2 struct {
// Args: List of arguments for the format string.
Args []*PagespeedApiFormatStringV2Args `json:"args,omitempty"`
// Format: A localized format string with {{FOO}} placeholders, where
// 'FOO' is the key of the argument whose value should be substituted.
// For HYPERLINK arguments, the format string will instead contain
// {{BEGIN_FOO}} and {{END_FOO}} for the argument with key 'FOO'.
Format string `json:"format,omitempty"`
}
type PagespeedApiFormatStringV2Args ¶
type PagespeedApiFormatStringV2Args struct {
// Key: The placeholder key for this arg, as a string.
Key string `json:"key,omitempty"`
// Rects: The screen rectangles being referred to, with dimensions
// measured in CSS pixels. This is only ever used for SNAPSHOT_RECT
// arguments. If this is absent for a SNAPSHOT_RECT argument, it means
// that that argument refers to the entire snapshot.
Rects []*PagespeedApiFormatStringV2ArgsRects `json:"rects,omitempty"`
// SecondaryRects: Secondary screen rectangles being referred to, with
// dimensions measured in CSS pixels. This is only ever used for
// SNAPSHOT_RECT arguments.
SecondaryRects []*PagespeedApiFormatStringV2ArgsSecondaryRects `json:"secondary_rects,omitempty"`
// Type: Type of argument. One of URL, STRING_LITERAL, INT_LITERAL,
// BYTES, DURATION, VERBATIM_STRING, PERCENTAGE, HYPERLINK, or
// SNAPSHOT_RECT.
Type string `json:"type,omitempty"`
// Value: Argument value, as a localized string.
Value string `json:"value,omitempty"`
}
type PagespeedApiFormatStringV2ArgsRects ¶
type PagespeedApiFormatStringV2ArgsRects struct {
// Height: The height of the rect.
Height int64 `json:"height,omitempty"`
// Left: The left coordinate of the rect, in page coordinates.
Left int64 `json:"left,omitempty"`
// Top: The top coordinate of the rect, in page coordinates.
Top int64 `json:"top,omitempty"`
// Width: The width of the rect.
Width int64 `json:"width,omitempty"`
}
type PagespeedApiFormatStringV2ArgsSecondaryRects ¶
type PagespeedApiFormatStringV2ArgsSecondaryRects struct {
// Height: The height of the rect.
Height int64 `json:"height,omitempty"`
// Left: The left coordinate of the rect, in page coordinates.
Left int64 `json:"left,omitempty"`
// Top: The top coordinate of the rect, in page coordinates.
Top int64 `json:"top,omitempty"`
// Width: The width of the rect.
Width int64 `json:"width,omitempty"`
}
type PagespeedApiImageV2 ¶
type PagespeedApiImageV2 struct {
// Data: Image data base64 encoded.
Data string `json:"data,omitempty"`
// Height: Height of screenshot in pixels.
Height int64 `json:"height,omitempty"`
// Key: Unique string key, if any, identifying this image.
Key string `json:"key,omitempty"`
// MimeType: Mime type of image data (e.g. "image/jpeg").
MimeType string `json:"mime_type,omitempty"`
// PageRect: The region of the page that is captured by this image, with
// dimensions measured in CSS pixels.
PageRect *PagespeedApiImageV2PageRect `json:"page_rect,omitempty"`
// Width: Width of screenshot in pixels.
Width int64 `json:"width,omitempty"`
}
type PagespeedApiImageV2PageRect ¶
type PagespeedApiImageV2PageRect struct {
// Height: The height of the rect.
Height int64 `json:"height,omitempty"`
// Left: The left coordinate of the rect, in page coordinates.
Left int64 `json:"left,omitempty"`
// Top: The top coordinate of the rect, in page coordinates.
Top int64 `json:"top,omitempty"`
// Width: The width of the rect.
Width int64 `json:"width,omitempty"`
}
PagespeedApiImageV2PageRect: The region of the page that is captured by this image, with dimensions measured in CSS pixels.
type PagespeedapiRunpagespeedCall ¶
type PagespeedapiRunpagespeedCall struct {
// contains filtered or unexported fields
}
func (*PagespeedapiRunpagespeedCall) Do ¶
func (c *PagespeedapiRunpagespeedCall) Do() (*Result, error)
func (*PagespeedapiRunpagespeedCall) Fields ¶
func (c *PagespeedapiRunpagespeedCall) Fields(s ...googleapi.Field) *PagespeedapiRunpagespeedCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*PagespeedapiRunpagespeedCall) FilterThirdPartyResources ¶
func (c *PagespeedapiRunpagespeedCall) FilterThirdPartyResources(filterThirdPartyResources bool) *PagespeedapiRunpagespeedCall
FilterThirdPartyResources sets the optional parameter "filter_third_party_resources": Indicates if third party resources should be filtered out before PageSpeed analysis.
func (*PagespeedapiRunpagespeedCall) Locale ¶
func (c *PagespeedapiRunpagespeedCall) Locale(locale string) *PagespeedapiRunpagespeedCall
Locale sets the optional parameter "locale": The locale used to localize formatted results
func (*PagespeedapiRunpagespeedCall) Rule ¶
func (c *PagespeedapiRunpagespeedCall) Rule(rule string) *PagespeedapiRunpagespeedCall
Rule sets the optional parameter "rule": A PageSpeed rule to run; if none are given, all rules are run
func (*PagespeedapiRunpagespeedCall) Screenshot ¶
func (c *PagespeedapiRunpagespeedCall) Screenshot(screenshot bool) *PagespeedapiRunpagespeedCall
Screenshot sets the optional parameter "screenshot": Indicates if binary data containing a screenshot should be included
func (*PagespeedapiRunpagespeedCall) Strategy ¶
func (c *PagespeedapiRunpagespeedCall) Strategy(strategy string) *PagespeedapiRunpagespeedCall
Strategy sets the optional parameter "strategy": The analysis strategy to use
Possible values:
"desktop" - Fetch and analyze the URL for desktop browsers "mobile" - Fetch and analyze the URL for mobile devices
type PagespeedapiService ¶
type PagespeedapiService struct {
// contains filtered or unexported fields
}
func NewPagespeedapiService ¶
func NewPagespeedapiService(s *Service) *PagespeedapiService
func (*PagespeedapiService) Runpagespeed ¶
func (r *PagespeedapiService) Runpagespeed(url string) *PagespeedapiRunpagespeedCall
Runpagespeed: Runs PageSpeed analysis on the page at the specified URL, and returns PageSpeed scores, a list of suggestions to make that page faster, and other information.
type Result ¶
type Result struct {
// FormattedResults: Localized PageSpeed results. Contains a ruleResults
// entry for each PageSpeed rule instantiated and run by the server.
FormattedResults *ResultFormattedResults `json:"formattedResults,omitempty"`
// Id: Canonicalized and final URL for the document, after following
// page redirects (if any).
Id string `json:"id,omitempty"`
// InvalidRules: List of rules that were specified in the request, but
// which the server did not know how to instantiate.
InvalidRules []string `json:"invalidRules,omitempty"`
// Kind: Kind of result.
Kind string `json:"kind,omitempty"`
// PageStats: Summary statistics for the page, such as number of
// JavaScript bytes, number of HTML bytes, etc.
PageStats *ResultPageStats `json:"pageStats,omitempty"`
// ResponseCode: Response code for the document. 200 indicates a normal
// page load. 4xx/5xx indicates an error.
ResponseCode int64 `json:"responseCode,omitempty"`
// RuleGroups: A map with one entry for each rule group in these
// results.
RuleGroups *ResultRuleGroups `json:"ruleGroups,omitempty"`
// Screenshot: Base64-encoded screenshot of the page that was analyzed.
Screenshot *PagespeedApiImageV2 `json:"screenshot,omitempty"`
// Title: Title of the page, as displayed in the browser's title bar.
Title string `json:"title,omitempty"`
// Version: The version of PageSpeed used to generate these results.
Version *ResultVersion `json:"version,omitempty"`
}
type ResultFormattedResults ¶
type ResultFormattedResults struct {
// Locale: The locale of the formattedResults, e.g. "en_US".
Locale string `json:"locale,omitempty"`
// RuleResults: Dictionary of formatted rule results, with one entry for
// each PageSpeed rule instantiated and run by the server.
RuleResults *ResultFormattedResultsRuleResults `json:"ruleResults,omitempty"`
}
ResultFormattedResults: Localized PageSpeed results. Contains a ruleResults entry for each PageSpeed rule instantiated and run by the server.
type ResultFormattedResultsRuleResults ¶
type ResultFormattedResultsRuleResults struct {
}
ResultFormattedResultsRuleResults: Dictionary of formatted rule results, with one entry for each PageSpeed rule instantiated and run by the server.
type ResultPageStats ¶
type ResultPageStats struct {
// CssResponseBytes: Number of uncompressed response bytes for CSS
// resources on the page.
CssResponseBytes int64 `json:"cssResponseBytes,omitempty,string"`
// FlashResponseBytes: Number of response bytes for flash resources on
// the page.
FlashResponseBytes int64 `json:"flashResponseBytes,omitempty,string"`
// HtmlResponseBytes: Number of uncompressed response bytes for the main
// HTML document and all iframes on the page.
HtmlResponseBytes int64 `json:"htmlResponseBytes,omitempty,string"`
// ImageResponseBytes: Number of response bytes for image resources on
// the page.
ImageResponseBytes int64 `json:"imageResponseBytes,omitempty,string"`
// JavascriptResponseBytes: Number of uncompressed response bytes for JS
// resources on the page.
JavascriptResponseBytes int64 `json:"javascriptResponseBytes,omitempty,string"`
// NumberCssResources: Number of CSS resources referenced by the page.
NumberCssResources int64 `json:"numberCssResources,omitempty"`
// NumberHosts: Number of unique hosts referenced by the page.
NumberHosts int64 `json:"numberHosts,omitempty"`
// NumberJsResources: Number of JavaScript resources referenced by the
// page.
NumberJsResources int64 `json:"numberJsResources,omitempty"`
// NumberResources: Number of HTTP resources loaded by the page.
NumberResources int64 `json:"numberResources,omitempty"`
// NumberStaticResources: Number of static (i.e. cacheable) resources on
// the page.
NumberStaticResources int64 `json:"numberStaticResources,omitempty"`
// OtherResponseBytes: Number of response bytes for other resources on
// the page.
OtherResponseBytes int64 `json:"otherResponseBytes,omitempty,string"`
// TextResponseBytes: Number of uncompressed response bytes for text
// resources not covered by other statistics (i.e non-HTML, non-script,
// non-CSS resources) on the page.
TextResponseBytes int64 `json:"textResponseBytes,omitempty,string"`
// TotalRequestBytes: Total size of all request bytes sent by the page.
TotalRequestBytes int64 `json:"totalRequestBytes,omitempty,string"`
}
ResultPageStats: Summary statistics for the page, such as number of JavaScript bytes, number of HTML bytes, etc.
type ResultRuleGroups ¶
type ResultRuleGroups struct {
}
ResultRuleGroups: A map with one entry for each rule group in these results.
type ResultVersion ¶
type ResultVersion struct {
// Major: The major version number of PageSpeed used to generate these
// results.
Major int64 `json:"major,omitempty"`
// Minor: The minor version number of PageSpeed used to generate these
// results.
Minor int64 `json:"minor,omitempty"`
}
ResultVersion: The version of PageSpeed used to generate these results.