Documentation
¶
Overview ¶
Package playmoviespartner provides access to the Google Play Movies Partner API.
See https://developers.google.com/playmoviespartner/
Usage example:
import "google.golang.org/api/playmoviespartner/v1" ... playmoviespartnerService, err := playmoviespartner.New(oauthHttpClient)
Index ¶
- Constants
- type AccountsAvailsListCall
- func (c *AccountsAvailsListCall) AltId(altId string) *AccountsAvailsListCall
- func (c *AccountsAvailsListCall) Do() (*ListAvailsResponse, error)
- func (c *AccountsAvailsListCall) Fields(s ...googleapi.Field) *AccountsAvailsListCall
- func (c *AccountsAvailsListCall) PageSize(pageSize int64) *AccountsAvailsListCall
- func (c *AccountsAvailsListCall) PageToken(pageToken string) *AccountsAvailsListCall
- func (c *AccountsAvailsListCall) PphNames(pphNames string) *AccountsAvailsListCall
- func (c *AccountsAvailsListCall) StudioNames(studioNames string) *AccountsAvailsListCall
- func (c *AccountsAvailsListCall) Territories(territories string) *AccountsAvailsListCall
- func (c *AccountsAvailsListCall) Title(title string) *AccountsAvailsListCall
- func (c *AccountsAvailsListCall) VideoIds(videoIds string) *AccountsAvailsListCall
- type AccountsAvailsService
- type AccountsExperienceLocalesGetCall
- type AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) AltCutId(altCutId string) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) CustomId(customId string) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) Do() (*ListExperienceLocalesResponse, error)
- func (c *AccountsExperienceLocalesListCall) EditLevelEidr(editLevelEidr string) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) Fields(s ...googleapi.Field) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) PageSize(pageSize int64) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) PageToken(pageToken string) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) PphNames(pphNames string) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) Status(status string) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) StudioNames(studioNames string) *AccountsExperienceLocalesListCall
- func (c *AccountsExperienceLocalesListCall) TitleLevelEidr(titleLevelEidr string) *AccountsExperienceLocalesListCall
- type AccountsExperienceLocalesService
- type AccountsOrdersGetCall
- type AccountsOrdersListCall
- func (c *AccountsOrdersListCall) CustomId(customId string) *AccountsOrdersListCall
- func (c *AccountsOrdersListCall) Do() (*ListOrdersResponse, error)
- func (c *AccountsOrdersListCall) Fields(s ...googleapi.Field) *AccountsOrdersListCall
- func (c *AccountsOrdersListCall) Name(name string) *AccountsOrdersListCall
- func (c *AccountsOrdersListCall) PageSize(pageSize int64) *AccountsOrdersListCall
- func (c *AccountsOrdersListCall) PageToken(pageToken string) *AccountsOrdersListCall
- func (c *AccountsOrdersListCall) PphNames(pphNames string) *AccountsOrdersListCall
- func (c *AccountsOrdersListCall) Status(status string) *AccountsOrdersListCall
- func (c *AccountsOrdersListCall) StudioNames(studioNames string) *AccountsOrdersListCall
- type AccountsOrdersService
- type AccountsService
- type AccountsStoreInfosCountryGetCall
- type AccountsStoreInfosCountryService
- type AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) Countries(countries string) *AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) Do() (*ListStoreInfosResponse, error)
- func (c *AccountsStoreInfosListCall) Fields(s ...googleapi.Field) *AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) Name(name string) *AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) PageSize(pageSize int64) *AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) PageToken(pageToken string) *AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) PphNames(pphNames string) *AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) StudioNames(studioNames string) *AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) VideoId(videoId string) *AccountsStoreInfosListCall
- func (c *AccountsStoreInfosListCall) VideoIds(videoIds string) *AccountsStoreInfosListCall
- type AccountsStoreInfosService
- type Avail
- type ExperienceLocale
- type ListAvailsResponse
- type ListExperienceLocalesResponse
- type ListOrdersResponse
- type ListStoreInfosResponse
- type Order
- type Service
- type StoreInfo
Constants ¶
const (
// View the digital assets you publish on Google Play Movies and TV
PlaymoviesPartnerReadonlyScope = "https://www.googleapis.com/auth/playmovies_partner.readonly"
)
OAuth2 scopes used by this API.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccountsAvailsListCall ¶
type AccountsAvailsListCall struct {
// contains filtered or unexported fields
}
func (*AccountsAvailsListCall) AltId ¶
func (c *AccountsAvailsListCall) AltId(altId string) *AccountsAvailsListCall
AltId sets the optional parameter "altId": Filter Avails that match a case-insensitive, partner-specific custom id.
func (*AccountsAvailsListCall) Do ¶
func (c *AccountsAvailsListCall) Do() (*ListAvailsResponse, error)
func (*AccountsAvailsListCall) Fields ¶
func (c *AccountsAvailsListCall) Fields(s ...googleapi.Field) *AccountsAvailsListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*AccountsAvailsListCall) PageSize ¶
func (c *AccountsAvailsListCall) PageSize(pageSize int64) *AccountsAvailsListCall
PageSize sets the optional parameter "pageSize": See _List methods rules_ for info about this field.
func (*AccountsAvailsListCall) PageToken ¶
func (c *AccountsAvailsListCall) PageToken(pageToken string) *AccountsAvailsListCall
PageToken sets the optional parameter "pageToken": See _List methods rules_ for info about this field.
func (*AccountsAvailsListCall) PphNames ¶
func (c *AccountsAvailsListCall) PphNames(pphNames string) *AccountsAvailsListCall
PphNames sets the optional parameter "pphNames": See _List methods rules_ for info about this field.
func (*AccountsAvailsListCall) StudioNames ¶
func (c *AccountsAvailsListCall) StudioNames(studioNames string) *AccountsAvailsListCall
StudioNames sets the optional parameter "studioNames": See _List methods rules_ for info about this field.
func (*AccountsAvailsListCall) Territories ¶
func (c *AccountsAvailsListCall) Territories(territories string) *AccountsAvailsListCall
Territories sets the optional parameter "territories": Filter Avails that match (case-insensitive) any of the given country codes, using the "ISO 3166-1 alpha-2" format (examples: "US", "us", "Us").
func (*AccountsAvailsListCall) Title ¶
func (c *AccountsAvailsListCall) Title(title string) *AccountsAvailsListCall
Title sets the optional parameter "title": Filter Avails that match a case-insensitive substring of the default Title name.
func (*AccountsAvailsListCall) VideoIds ¶
func (c *AccountsAvailsListCall) VideoIds(videoIds string) *AccountsAvailsListCall
VideoIds sets the optional parameter "videoIds": Filter Avails that match any of the given `video_id`s.
type AccountsAvailsService ¶
type AccountsAvailsService struct {
// contains filtered or unexported fields
}
func NewAccountsAvailsService ¶
func NewAccountsAvailsService(s *Service) *AccountsAvailsService
func (*AccountsAvailsService) List ¶
func (r *AccountsAvailsService) List(accountId string) *AccountsAvailsListCall
List: List Avails owned or managed by the partner. See _Authentication and Authorization rules_ and _List methods rules_ for more information about this method.
type AccountsExperienceLocalesGetCall ¶
type AccountsExperienceLocalesGetCall struct {
// contains filtered or unexported fields
}
func (*AccountsExperienceLocalesGetCall) Do ¶
func (c *AccountsExperienceLocalesGetCall) Do() (*ExperienceLocale, error)
func (*AccountsExperienceLocalesGetCall) Fields ¶
func (c *AccountsExperienceLocalesGetCall) Fields(s ...googleapi.Field) *AccountsExperienceLocalesGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type AccountsExperienceLocalesListCall ¶
type AccountsExperienceLocalesListCall struct {
// contains filtered or unexported fields
}
func (*AccountsExperienceLocalesListCall) AltCutId ¶
func (c *AccountsExperienceLocalesListCall) AltCutId(altCutId string) *AccountsExperienceLocalesListCall
AltCutId sets the optional parameter "altCutId": Filter ExperienceLocales that match a case-insensitive, partner-specific Alternative Cut ID.
func (*AccountsExperienceLocalesListCall) CustomId ¶
func (c *AccountsExperienceLocalesListCall) CustomId(customId string) *AccountsExperienceLocalesListCall
CustomId sets the optional parameter "customId": Filter ExperienceLocales that match a case-insensitive, partner-specific custom id.
func (*AccountsExperienceLocalesListCall) Do ¶
func (c *AccountsExperienceLocalesListCall) Do() (*ListExperienceLocalesResponse, error)
func (*AccountsExperienceLocalesListCall) EditLevelEidr ¶
func (c *AccountsExperienceLocalesListCall) EditLevelEidr(editLevelEidr string) *AccountsExperienceLocalesListCall
EditLevelEidr sets the optional parameter "editLevelEidr": Filter ExperienceLocales that match a given edit-level EIDR.
func (*AccountsExperienceLocalesListCall) Fields ¶
func (c *AccountsExperienceLocalesListCall) Fields(s ...googleapi.Field) *AccountsExperienceLocalesListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*AccountsExperienceLocalesListCall) PageSize ¶
func (c *AccountsExperienceLocalesListCall) PageSize(pageSize int64) *AccountsExperienceLocalesListCall
PageSize sets the optional parameter "pageSize": See _List methods rules_ for info about this field.
func (*AccountsExperienceLocalesListCall) PageToken ¶
func (c *AccountsExperienceLocalesListCall) PageToken(pageToken string) *AccountsExperienceLocalesListCall
PageToken sets the optional parameter "pageToken": See _List methods rules_ for info about this field.
func (*AccountsExperienceLocalesListCall) PphNames ¶
func (c *AccountsExperienceLocalesListCall) PphNames(pphNames string) *AccountsExperienceLocalesListCall
PphNames sets the optional parameter "pphNames": See _List methods rules_ for info about this field.
func (*AccountsExperienceLocalesListCall) Status ¶
func (c *AccountsExperienceLocalesListCall) Status(status string) *AccountsExperienceLocalesListCall
Status sets the optional parameter "status": Filter ExperienceLocales that match one of the given status.
Possible values:
"STATUS_UNSPECIFIED" "STATUS_APPROVED" "STATUS_FAILED" "STATUS_PROCESSING" "STATUS_UNFULFILLED" "STATUS_NOT_AVAILABLE"
func (*AccountsExperienceLocalesListCall) StudioNames ¶
func (c *AccountsExperienceLocalesListCall) StudioNames(studioNames string) *AccountsExperienceLocalesListCall
StudioNames sets the optional parameter "studioNames": See _List methods rules_ for info about this field.
func (*AccountsExperienceLocalesListCall) TitleLevelEidr ¶
func (c *AccountsExperienceLocalesListCall) TitleLevelEidr(titleLevelEidr string) *AccountsExperienceLocalesListCall
TitleLevelEidr sets the optional parameter "titleLevelEidr": Filter ExperienceLocales that match a given title-level EIDR.
type AccountsExperienceLocalesService ¶
type AccountsExperienceLocalesService struct {
// contains filtered or unexported fields
}
func NewAccountsExperienceLocalesService ¶
func NewAccountsExperienceLocalesService(s *Service) *AccountsExperienceLocalesService
func (*AccountsExperienceLocalesService) Get ¶
func (r *AccountsExperienceLocalesService) Get(accountId string, elId string) *AccountsExperienceLocalesGetCall
Get: Get an ExperienceLocale given its id. See _Authentication and Authorization rules_ and _Get methods rules_ for more information about this method.
func (*AccountsExperienceLocalesService) List ¶
func (r *AccountsExperienceLocalesService) List(accountId string) *AccountsExperienceLocalesListCall
List: List ExperienceLocales owned or managed by the partner. See _Authentication and Authorization rules_ and _List methods rules_ for more information about this method.
type AccountsOrdersGetCall ¶
type AccountsOrdersGetCall struct {
// contains filtered or unexported fields
}
func (*AccountsOrdersGetCall) Do ¶
func (c *AccountsOrdersGetCall) Do() (*Order, error)
func (*AccountsOrdersGetCall) Fields ¶
func (c *AccountsOrdersGetCall) Fields(s ...googleapi.Field) *AccountsOrdersGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type AccountsOrdersListCall ¶
type AccountsOrdersListCall struct {
// contains filtered or unexported fields
}
func (*AccountsOrdersListCall) CustomId ¶
func (c *AccountsOrdersListCall) CustomId(customId string) *AccountsOrdersListCall
CustomId sets the optional parameter "customId": Filter Orders that match a case-insensitive, partner-specific custom id.
func (*AccountsOrdersListCall) Do ¶
func (c *AccountsOrdersListCall) Do() (*ListOrdersResponse, error)
func (*AccountsOrdersListCall) Fields ¶
func (c *AccountsOrdersListCall) Fields(s ...googleapi.Field) *AccountsOrdersListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*AccountsOrdersListCall) Name ¶
func (c *AccountsOrdersListCall) Name(name string) *AccountsOrdersListCall
Name sets the optional parameter "name": Filter Orders that match a title name (case-insensitive, sub-string match).
func (*AccountsOrdersListCall) PageSize ¶
func (c *AccountsOrdersListCall) PageSize(pageSize int64) *AccountsOrdersListCall
PageSize sets the optional parameter "pageSize": See _List methods rules_ for info about this field.
func (*AccountsOrdersListCall) PageToken ¶
func (c *AccountsOrdersListCall) PageToken(pageToken string) *AccountsOrdersListCall
PageToken sets the optional parameter "pageToken": See _List methods rules_ for info about this field.
func (*AccountsOrdersListCall) PphNames ¶
func (c *AccountsOrdersListCall) PphNames(pphNames string) *AccountsOrdersListCall
PphNames sets the optional parameter "pphNames": See _List methods rules_ for info about this field.
func (*AccountsOrdersListCall) Status ¶
func (c *AccountsOrdersListCall) Status(status string) *AccountsOrdersListCall
Status sets the optional parameter "status": Filter Orders that match one of the given status.
Possible values:
"STATUS_UNSPECIFIED" "STATUS_APPROVED" "STATUS_FAILED" "STATUS_PROCESSING" "STATUS_UNFULFILLED" "STATUS_NOT_AVAILABLE"
func (*AccountsOrdersListCall) StudioNames ¶
func (c *AccountsOrdersListCall) StudioNames(studioNames string) *AccountsOrdersListCall
StudioNames sets the optional parameter "studioNames": See _List methods rules_ for info about this field.
type AccountsOrdersService ¶
type AccountsOrdersService struct {
// contains filtered or unexported fields
}
func NewAccountsOrdersService ¶
func NewAccountsOrdersService(s *Service) *AccountsOrdersService
func (*AccountsOrdersService) Get ¶
func (r *AccountsOrdersService) Get(accountId string, orderId string) *AccountsOrdersGetCall
Get: Get an Order given its id. See _Authentication and Authorization rules_ and _Get methods rules_ for more information about this method.
func (*AccountsOrdersService) List ¶
func (r *AccountsOrdersService) List(accountId string) *AccountsOrdersListCall
List: List Orders owned or managed by the partner. See _Authentication and Authorization rules_ and _List methods rules_ for more information about this method.
type AccountsService ¶
type AccountsService struct {
Avails *AccountsAvailsService
ExperienceLocales *AccountsExperienceLocalesService
Orders *AccountsOrdersService
StoreInfos *AccountsStoreInfosService
// contains filtered or unexported fields
}
func NewAccountsService ¶
func NewAccountsService(s *Service) *AccountsService
type AccountsStoreInfosCountryGetCall ¶
type AccountsStoreInfosCountryGetCall struct {
// contains filtered or unexported fields
}
func (*AccountsStoreInfosCountryGetCall) Do ¶
func (c *AccountsStoreInfosCountryGetCall) Do() (*StoreInfo, error)
func (*AccountsStoreInfosCountryGetCall) Fields ¶
func (c *AccountsStoreInfosCountryGetCall) Fields(s ...googleapi.Field) *AccountsStoreInfosCountryGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
type AccountsStoreInfosCountryService ¶
type AccountsStoreInfosCountryService struct {
// contains filtered or unexported fields
}
func NewAccountsStoreInfosCountryService ¶
func NewAccountsStoreInfosCountryService(s *Service) *AccountsStoreInfosCountryService
func (*AccountsStoreInfosCountryService) Get ¶
func (r *AccountsStoreInfosCountryService) Get(accountId string, videoId string, country string) *AccountsStoreInfosCountryGetCall
Get: Get a StoreInfo given its video id and country. See _Authentication and Authorization rules_ and _Get methods rules_ for more information about this method.
type AccountsStoreInfosListCall ¶
type AccountsStoreInfosListCall struct {
// contains filtered or unexported fields
}
func (*AccountsStoreInfosListCall) Countries ¶
func (c *AccountsStoreInfosListCall) Countries(countries string) *AccountsStoreInfosListCall
Countries sets the optional parameter "countries": Filter StoreInfos that match (case-insensitive) any of the given country codes, using the "ISO 3166-1 alpha-2" format (examples: "US", "us", "Us").
func (*AccountsStoreInfosListCall) Do ¶
func (c *AccountsStoreInfosListCall) Do() (*ListStoreInfosResponse, error)
func (*AccountsStoreInfosListCall) Fields ¶
func (c *AccountsStoreInfosListCall) Fields(s ...googleapi.Field) *AccountsStoreInfosListCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*AccountsStoreInfosListCall) Name ¶
func (c *AccountsStoreInfosListCall) Name(name string) *AccountsStoreInfosListCall
Name sets the optional parameter "name": Filter StoreInfos that match a case-insensitive substring of the default name.
func (*AccountsStoreInfosListCall) PageSize ¶
func (c *AccountsStoreInfosListCall) PageSize(pageSize int64) *AccountsStoreInfosListCall
PageSize sets the optional parameter "pageSize": See _List methods rules_ for info about this field.
func (*AccountsStoreInfosListCall) PageToken ¶
func (c *AccountsStoreInfosListCall) PageToken(pageToken string) *AccountsStoreInfosListCall
PageToken sets the optional parameter "pageToken": See _List methods rules_ for info about this field.
func (*AccountsStoreInfosListCall) PphNames ¶
func (c *AccountsStoreInfosListCall) PphNames(pphNames string) *AccountsStoreInfosListCall
PphNames sets the optional parameter "pphNames": See _List methods rules_ for info about this field.
func (*AccountsStoreInfosListCall) StudioNames ¶
func (c *AccountsStoreInfosListCall) StudioNames(studioNames string) *AccountsStoreInfosListCall
StudioNames sets the optional parameter "studioNames": See _List methods rules_ for info about this field.
func (*AccountsStoreInfosListCall) VideoId ¶
func (c *AccountsStoreInfosListCall) VideoId(videoId string) *AccountsStoreInfosListCall
VideoId sets the optional parameter "videoId": Filter StoreInfos that match a given `video_id`. NOTE: this field is deprecated and will be removed on V2; `video_ids` should be used instead.
func (*AccountsStoreInfosListCall) VideoIds ¶
func (c *AccountsStoreInfosListCall) VideoIds(videoIds string) *AccountsStoreInfosListCall
VideoIds sets the optional parameter "videoIds": Filter StoreInfos that match any of the given `video_id`s.
type AccountsStoreInfosService ¶
type AccountsStoreInfosService struct {
Country *AccountsStoreInfosCountryService
// contains filtered or unexported fields
}
func NewAccountsStoreInfosService ¶
func NewAccountsStoreInfosService(s *Service) *AccountsStoreInfosService
func (*AccountsStoreInfosService) List ¶
func (r *AccountsStoreInfosService) List(accountId string) *AccountsStoreInfosListCall
List: List StoreInfos owned or managed by the partner. See _Authentication and Authorization rules_ and _List methods rules_ for more information about this method.
type Avail ¶
type Avail struct {
// AltId: Other identifier referring to the Edit, as defined by partner.
// Example: "GOOGLER_2006"
AltId string `json:"altId,omitempty"`
// CaptionExemption: Communicating an exempt category as defined by FCC
// regulations. It is not required for non-US Avails. Example: "1"
CaptionExemption string `json:"captionExemption,omitempty"`
// CaptionIncluded: Communicating if caption file will be delivered.
CaptionIncluded bool `json:"captionIncluded,omitempty"`
// ContentId: Title Identifier. This should be the Title Level EIDR.
// Example: "10.5240/1489-49A2-3956-4B2D-FE16-5".
ContentId string `json:"contentId,omitempty"`
// DisplayName: The name of the studio that owns the Edit referred in
// the Avail. This is the equivalent of `studio_name` in other
// resources, but it follows the EMA nomenclature. Example: "Google
// Films".
DisplayName string `json:"displayName,omitempty"`
// EncodeId: Manifestation Identifier. This should be the Manifestation
// Level EIDR. Example: "10.2340/1489-49A2-3956-4B2D-FE16-7"
EncodeId string `json:"encodeId,omitempty"`
// End: End of term in YYYY-MM-DD format in the timezone of the country
// of the Avail. "Open" if no end date is available. Example:
// "2019-02-17"
End string `json:"end,omitempty"`
// EpisodeAltId: Other identifier referring to the episode, as defined
// by partner. Only available on TV avails. Example: "rs_googlers_s1_3".
EpisodeAltId string `json:"episodeAltId,omitempty"`
// EpisodeNumber: The number assigned to the episode within a season.
// Only available on TV Avails. Example: "3".
EpisodeNumber string `json:"episodeNumber,omitempty"`
// EpisodeTitleInternalAlias: OPTIONAL.TV Only. Title used by involved
// parties to refer to this episode. Only available on TV Avails.
// Example: "Coding at Google".
EpisodeTitleInternalAlias string `json:"episodeTitleInternalAlias,omitempty"`
// FormatProfile: Indicates the format profile covered by the
// transaction.
//
// Possible values:
// "FORMAT_PROFILE_UNSPECIFIED"
// "SD"
// "HD"
FormatProfile string `json:"formatProfile,omitempty"`
// LicenseType: Type of transaction.
//
// Possible values:
// "LICENSE_TYPE_UNSPECIFIED"
// "EST"
// "VOD"
// "SVOD"
LicenseType string `json:"licenseType,omitempty"`
// PphNames: Name of the post-production houses that manage the Avail.
// Not part of EMA Specs.
PphNames []string `json:"pphNames,omitempty"`
// PriceType: Type of pricing that should be applied to this Avail based
// on how the partner classify them. Example: "Tier", "WSP", "SRP", or
// "Category".
PriceType string `json:"priceType,omitempty"`
// PriceValue: Value to be applied to the pricing type. Example: "4" or
// "2.99"
PriceValue string `json:"priceValue,omitempty"`
// ProductId: Edit Identifier. This should be the Edit Level EIDR.
// Example: "10.2340/1489-49A2-3956-4B2D-FE16-6"
ProductId string `json:"productId,omitempty"`
// RatingReason: Value representing the rating reason. Rating reasons
// should be formatted as per [EMA ratings
// spec](http://www.movielabs.com/md/ratings/) and comma-separated for
// inclusion of multiple reasons. Example: "L, S, V"
RatingReason string `json:"ratingReason,omitempty"`
// RatingSystem: Rating system applied to the version of title within
// territory of Avail. Rating systems should be formatted as per [EMA
// ratings spec](http://www.movielabs.com/md/ratings/) Example: "MPAA"
RatingSystem string `json:"ratingSystem,omitempty"`
// RatingValue: Value representing the rating. Ratings should be
// formatted as per http://www.movielabs.com/md/ratings/ Example: "PG"
RatingValue string `json:"ratingValue,omitempty"`
// ReleaseDate: Release date of the Title in earliest released
// territory. Typically it is just the year, but it is free-form as per
// EMA spec. Examples: "1979", "Oct 2014"
ReleaseDate string `json:"releaseDate,omitempty"`
// SeasonAltId: Other identifier referring to the season, as defined by
// partner. Only available on TV avails. Example: "rs_googlers_s1".
SeasonAltId string `json:"seasonAltId,omitempty"`
// SeasonNumber: The number assigned to the season within a series. Only
// available on TV Avails. Example: "1".
SeasonNumber string `json:"seasonNumber,omitempty"`
// SeasonTitleInternalAlias: Title used by involved parties to refer to
// this season. Only available on TV Avails. Example: "Googlers, The".
SeasonTitleInternalAlias string `json:"seasonTitleInternalAlias,omitempty"`
// SeriesAltId: Other identifier referring to the series, as defined by
// partner. Only available on TV avails. Example: "rs_googlers".
SeriesAltId string `json:"seriesAltId,omitempty"`
// SeriesTitleInternalAlias: Title used by involved parties to refer to
// this series. Only available on TV Avails. Example: "Googlers, The".
SeriesTitleInternalAlias string `json:"seriesTitleInternalAlias,omitempty"`
// Start: Start of term in YYYY-MM-DD format in the timezone of the
// country of the Avail. Example: "2013-05-14".
Start string `json:"start,omitempty"`
// StoreLanguage: Spoken language of the intended audience. Language
// shall be encoded in accordance with RFC 5646. Example: "fr".
StoreLanguage string `json:"storeLanguage,omitempty"`
// SuppressionLiftDate: First date an Edit could be publically announced
// as becoming available at a specific future date in territory of
// Avail. *Not* the Avail start date or pre-order start date. Format is
// YYYY-MM-DD. Only available for pre-orders. Example: "2012-12-10"
SuppressionLiftDate string `json:"suppressionLiftDate,omitempty"`
// Territory: ISO 3166-1 alpha-2 country code for the country or
// territory of this Avail. For Avails, we use Territory in lieu of
// Country to comply with EMA specifications. But please note that
// Territory and Country identify the same thing. Example: "US".
Territory string `json:"territory,omitempty"`
// TitleInternalAlias: Title used by involved parties to refer to this
// content. Example: "Googlers, The". Only available on Movie Avails.
TitleInternalAlias string `json:"titleInternalAlias,omitempty"`
// VideoId: Google-generated ID identifying the video linked to this
// Avail, once delivered. Not part of EMA Specs. Example: 'gtry456_xc'
VideoId string `json:"videoId,omitempty"`
// WorkType: Work type as enumerated in EMA.
//
// Possible values:
// "TITLE_TYPE_UNSPECIFIED"
// "MOVIE"
// "SEASON"
// "EPISODE"
WorkType string `json:"workType,omitempty"`
}
Avail: An Avail describes the Availability Window of a specific Edit in a given country, which means the period Google is allowed to sell or rent the Edit. Avails are exposed in EMA format Version 1.6b (available at http://www.movielabs.com/md/avails/) Studios can see the Avails for the Titles they own. Post-production houses cannot see any Avails.
type ExperienceLocale ¶
type ExperienceLocale struct {
// AltCutId: Alternative Cut ID, sometimes available in lieu of the main
// Edit-level EIDR ID. This is not an EIDR ID, but a Partner-provided
// ID. Example: "206346_79838".
AltCutId string `json:"altCutId,omitempty"`
// ApprovedTime: Timestamp when the ExperienceLocale was approved.
ApprovedTime string `json:"approvedTime,omitempty"`
// ChannelId: YouTube Channel ID linked to the ExperienceLocale.
// Example: "UCRG64darCZhb".
ChannelId string `json:"channelId,omitempty"`
// Country: Country where the ExperienceLocale is available, using the
// "ISO 3166-1 alpha-2" format. Example: "US".
Country string `json:"country,omitempty"`
// CreatedTime: Timestamp when the ExperienceLocale was created.
CreatedTime string `json:"createdTime,omitempty"`
// CustomIds: List of custom IDs (defined by the partner) linked to this
// ExperienceLocale. Example: "R86241"
CustomIds []string `json:"customIds,omitempty"`
// EarliestAvailStartTime: Timestamp of the earliest start date of the
// Avails linked to this ExperienceLocale.
EarliestAvailStartTime string `json:"earliestAvailStartTime,omitempty"`
// EditLevelEidr: Edit-level EIDR ID. Example:
// "10.5240/1489-49A2-3956-4B2D-FE16-6".
EditLevelEidr string `json:"editLevelEidr,omitempty"`
// ElId: ID internally generated by Google to uniquely identify a
// ExperienceLocale. Example: 'KRZiVjY9h7t'
ElId string `json:"elId,omitempty"`
// InventoryId: InventoryID as defined in the EMA specs.
InventoryId string `json:"inventoryId,omitempty"`
// Language: Language of the ExperienceLocale, using the "BCP 47"
// format. Examples: "en", "en-US", "es", "es-419".
Language string `json:"language,omitempty"`
// Name: Default Edit name, usually in the language of the country of
// origin. Example: "Googlers, The".
Name string `json:"name,omitempty"`
// NormalizedPriority: A simpler representation of the priority.
//
// Possible values:
// "NORMALIZED_PRIORITY_UNSPECIFIED"
// "LOW_PRIORITY"
// "HIGH_PRIORITY"
NormalizedPriority string `json:"normalizedPriority,omitempty"`
// PlayableSequenceId: PlayableSequenceID as defined in the EMA specs.
PlayableSequenceId string `json:"playableSequenceId,omitempty"`
// PphNames: Name of the post-production houses that manage the
// ExperienceLocale.
PphNames []string `json:"pphNames,omitempty"`
// PresentationId: PresentationID as defined in the EMA specs.
PresentationId string `json:"presentationId,omitempty"`
// Priority: ExperienceLocale priority, as defined by Google. The higher
// the value, the higher the priority. Example: 90
Priority float64 `json:"priority,omitempty"`
// Status: High-level status of the ExperienceLocale.
//
// Possible values:
// "STATUS_UNSPECIFIED"
// "STATUS_APPROVED"
// "STATUS_FAILED"
// "STATUS_PROCESSING"
// "STATUS_UNFULFILLED"
// "STATUS_NOT_AVAILABLE"
Status string `json:"status,omitempty"`
// StudioName: Name of the studio that owns the ExperienceLocale.
StudioName string `json:"studioName,omitempty"`
// TitleLevelEidr: Title-level EIDR ID. Example:
// "10.5240/1489-49A2-3956-4B2D-FE16-5".
TitleLevelEidr string `json:"titleLevelEidr,omitempty"`
// TrailerId: Trailer ID, as defined by Google, linked to the trailer
// video in the ExperienceLocale. Example: 'gtry457_tr'.
TrailerId string `json:"trailerId,omitempty"`
// Type: Type of the Edit linked to the ExperienceLocale.
//
// Possible values:
// "TITLE_TYPE_UNSPECIFIED"
// "MOVIE"
// "SEASON"
// "EPISODE"
Type string `json:"type,omitempty"`
// VideoId: Video ID, as defined by Google, linked to the feature video
// in the ExperienceLocale. Example: 'gtry456_xc'.
VideoId string `json:"videoId,omitempty"`
}
ExperienceLocale: An ExperienceLocale tracks the fulfillment of a Title in a country using a specific language, when delivered using component-based delivery. For example, a Title in Switzerland might have 3 ExperienceLocales: they both share the same country ("CH"), but each has different languages ("de", "fr", and "it"). Each ExperienceLocale is uniquely identified by an `el_id`, which is generated by Google. Externally, an ExperienceLocale can also be identified by partners using its EIDR IDs, AltCutID or `custom_id` (when provided).
type ListAvailsResponse ¶
type ListAvailsResponse struct {
// Avails: List of Avails that match the request criteria.
Avails []*Avail `json:"avails,omitempty"`
// NextPageToken: See _List methods rules_ for info about this field.
NextPageToken string `json:"nextPageToken,omitempty"`
}
ListAvailsResponse: Response to the 'ListAvails' method.
type ListExperienceLocalesResponse ¶
type ListExperienceLocalesResponse struct {
// ExperienceLocales: List of ExperienceLocales that match the request
// criteria.
ExperienceLocales []*ExperienceLocale `json:"experienceLocales,omitempty"`
// NextPageToken: See _List methods rules_ for info about this field.
NextPageToken string `json:"nextPageToken,omitempty"`
}
ListExperienceLocalesResponse: Response to the 'ListExperienceLocales' method.
type ListOrdersResponse ¶
type ListOrdersResponse struct {
// NextPageToken: See _List methods rules_ for info about this field.
NextPageToken string `json:"nextPageToken,omitempty"`
// Orders: List of Orders that match the request criteria.
Orders []*Order `json:"orders,omitempty"`
}
ListOrdersResponse: Response to the 'ListOrders' method.
type ListStoreInfosResponse ¶
type ListStoreInfosResponse struct {
// NextPageToken: See 'List methods rules' for info about this field.
NextPageToken string `json:"nextPageToken,omitempty"`
// StoreInfos: List of StoreInfos that match the request criteria.
StoreInfos []*StoreInfo `json:"storeInfos,omitempty"`
}
ListStoreInfosResponse: Response to the 'ListStoreInfos' method.
type Order ¶
type Order struct {
// ApprovedTime: Timestamp when the Order was approved.
ApprovedTime string `json:"approvedTime,omitempty"`
// ChannelId: YouTube Channel ID that should be used to fulfill the
// Order. Example: "UCRG64darCZhb".
ChannelId string `json:"channelId,omitempty"`
// ChannelName: YouTube Channel Name that should be used to fulfill the
// Order. Example: "Google_channel".
ChannelName string `json:"channelName,omitempty"`
// Countries: Countries where the Order is available, using the "ISO
// 3166-1 alpha-2" format (example: "US").
Countries []string `json:"countries,omitempty"`
// CustomId: ID that can be used to externally identify an Order. This
// ID is provided by partners when submitting the Avails. Example:
// 'GOOGLER_2006'
CustomId string `json:"customId,omitempty"`
// EarliestAvailStartTime: Timestamp of the earliest start date of the
// Avails linked to this Order.
EarliestAvailStartTime string `json:"earliestAvailStartTime,omitempty"`
// EpisodeName: Default Episode name, usually in the language of the
// country of origin. Only available for TV Edits Example: "Googlers,
// The - Pilot".
EpisodeName string `json:"episodeName,omitempty"`
// LegacyPriority: Legacy Order priority, as defined by Google. Example:
// 'P0'
LegacyPriority string `json:"legacyPriority,omitempty"`
// Name: Default Edit name, usually in the language of the country of
// origin. Example: "Googlers, The".
Name string `json:"name,omitempty"`
// NormalizedPriority: A simpler representation of the priority.
//
// Possible values:
// "NORMALIZED_PRIORITY_UNSPECIFIED"
// "LOW_PRIORITY"
// "HIGH_PRIORITY"
NormalizedPriority string `json:"normalizedPriority,omitempty"`
// OrderId: ID internally generated by Google to uniquely identify an
// Order. Example: 'abcde12_x'
OrderId string `json:"orderId,omitempty"`
// OrderedTime: Timestamp when the Order was created.
OrderedTime string `json:"orderedTime,omitempty"`
// PphName: Name of the post-production house that manages the Edit
// ordered.
PphName string `json:"pphName,omitempty"`
// Priority: Order priority, as defined by Google. The higher the value,
// the higher the priority. Example: 90
Priority float64 `json:"priority,omitempty"`
// ReceivedTime: Timestamp when the Order was fulfilled.
ReceivedTime string `json:"receivedTime,omitempty"`
// RejectionNote: Field explaining why an Order has been rejected.
// Example: "Trailer audio is 2ch mono, please re-deliver in stereo".
RejectionNote string `json:"rejectionNote,omitempty"`
// SeasonName: Default Season name, usually in the language of the
// country of origin. Only available for TV Edits Example: "Googlers,
// The - A Brave New World".
SeasonName string `json:"seasonName,omitempty"`
// ShowName: Default Show name, usually in the language of the country
// of origin. Only available for TV Edits Example: "Googlers, The".
ShowName string `json:"showName,omitempty"`
// Status: High-level status of the order.
//
// Possible values:
// "STATUS_UNSPECIFIED"
// "STATUS_APPROVED"
// "STATUS_FAILED"
// "STATUS_PROCESSING"
// "STATUS_UNFULFILLED"
// "STATUS_NOT_AVAILABLE"
Status string `json:"status,omitempty"`
// StatusDetail: Detailed status of the order
//
// Possible values:
// "ORDER_STATUS_UNSPECIFIED"
// "ORDER_STATUS_QC_APPROVED"
// "ORDER_STATUS_QC_REJECTION"
// "ORDER_STATUS_INTERNAL_FIX"
// "ORDER_STATUS_OPEN_ORDER"
// "ORDER_STATUS_NOT_AVAILABLE"
// "ORDER_STATUS_AWAITING_REDELIVERY"
// "ORDER_STATUS_READY_FOR_QC"
StatusDetail string `json:"statusDetail,omitempty"`
// StudioName: Name of the studio that owns the Edit ordered.
StudioName string `json:"studioName,omitempty"`
// Type: Type of the Edit linked to the Order.
//
// Possible values:
// "TITLE_TYPE_UNSPECIFIED"
// "MOVIE"
// "SEASON"
// "EPISODE"
Type string `json:"type,omitempty"`
// VideoId: Google-generated ID identifying the video linked to this
// Order, once delivered. Example: 'gtry456_xc'.
VideoId string `json:"videoId,omitempty"`
}
Order: An Order tracks the fulfillment of an Edit when delivered using the legacy, non-component-based delivery. Each Order is uniquely identified by an `order_id`, which is generated by Google. Externally, Orders can also be identified by partners using its `custom_id` (when provided).
type Service ¶
type Service struct {
BasePath string // API endpoint base URL
UserAgent string // optional additional User-Agent fragment
Accounts *AccountsService
// contains filtered or unexported fields
}
type StoreInfo ¶
type StoreInfo struct {
// AudioTracks: Audio tracks available for this Edit.
AudioTracks []string `json:"audioTracks,omitempty"`
// Country: Country where Edit is available in ISO 3166-1 alpha-2
// country code. Example: "US".
Country string `json:"country,omitempty"`
// EditLevelEidr: Edit-level EIDR ID. Example:
// "10.5240/1489-49A2-3956-4B2D-FE16-6".
EditLevelEidr string `json:"editLevelEidr,omitempty"`
// EpisodeNumber: The number assigned to the episode within a season.
// Only available on TV Edits. Example: "1".
EpisodeNumber string `json:"episodeNumber,omitempty"`
// HasAudio51: Whether the Edit has a 5.1 channel audio track.
HasAudio51 bool `json:"hasAudio51,omitempty"`
// HasEstOffer: Whether the Edit has a EST offer.
HasEstOffer bool `json:"hasEstOffer,omitempty"`
// HasHdOffer: Whether the Edit has a HD offer.
HasHdOffer bool `json:"hasHdOffer,omitempty"`
// HasInfoCards: Whether the Edit has info cards.
HasInfoCards bool `json:"hasInfoCards,omitempty"`
// HasSdOffer: Whether the Edit has a SD offer.
HasSdOffer bool `json:"hasSdOffer,omitempty"`
// HasVodOffer: Whether the Edit has a VOD offer.
HasVodOffer bool `json:"hasVodOffer,omitempty"`
// LiveTime: Timestamp when the Edit went live on the Store.
LiveTime string `json:"liveTime,omitempty"`
// Mid: Knowledge Graph ID associated to this Edit, if available. This
// ID links the Edit to its knowledge entity, externally accessible at
// http://freebase.com. In the absense of Title EIDR or Edit EIDR, this
// ID helps link together multiple Edits across countries. Example:
// '/m/0ffx29'
Mid string `json:"mid,omitempty"`
// Name: Default Edit name, usually in the language of the country of
// origin. Example: "Googlers, The".
Name string `json:"name,omitempty"`
// PphNames: Name of the post-production houses that manage the Edit.
PphNames []string `json:"pphNames,omitempty"`
// SeasonId: Google-generated ID identifying the season linked to the
// Edit. Only available for TV Edits. Example: 'ster23ex'
SeasonId string `json:"seasonId,omitempty"`
// SeasonName: Default Season name, usually in the language of the
// country of origin. Only available for TV Edits Example: "Googlers,
// The - A Brave New World".
SeasonName string `json:"seasonName,omitempty"`
// SeasonNumber: The number assigned to the season within a show. Only
// available on TV Edits. Example: "1".
SeasonNumber string `json:"seasonNumber,omitempty"`
// ShowId: Google-generated ID identifying the show linked to the Edit.
// Only available for TV Edits. Example: 'et2hsue_x'
ShowId string `json:"showId,omitempty"`
// ShowName: Default Show name, usually in the language of the country
// of origin. Only available for TV Edits Example: "Googlers, The".
ShowName string `json:"showName,omitempty"`
// StudioName: Name of the studio that owns the Edit ordered.
StudioName string `json:"studioName,omitempty"`
// Subtitles: Subtitles available for this Edit.
Subtitles []string `json:"subtitles,omitempty"`
// TitleLevelEidr: Title-level EIDR ID. Example:
// "10.5240/1489-49A2-3956-4B2D-FE16-5".
TitleLevelEidr string `json:"titleLevelEidr,omitempty"`
// TrailerId: Google-generated ID identifying the trailer linked to the
// Edit. Example: 'bhd_4e_cx'
TrailerId string `json:"trailerId,omitempty"`
// Type: Edit type, like Movie, Episode or Season.
//
// Possible values:
// "TITLE_TYPE_UNSPECIFIED"
// "MOVIE"
// "SEASON"
// "EPISODE"
Type string `json:"type,omitempty"`
// VideoId: Google-generated ID identifying the video linked to the
// Edit. Example: 'gtry456_xc'
VideoId string `json:"videoId,omitempty"`
}
StoreInfo: Information about a playable sequence (video) associated with an Edit and available at the Google Play Store. Internally, each StoreInfo is uniquely identified by a `video_id` and `country`. Externally, Title-level EIDR or Edit-level EIDR, if provided, can also be used to identify a specific title or edit in a country.